Class: Aws::SSM::Types::AddTagsToResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::AddTagsToResourceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_id ⇒ String
The resource ID you want to tag.
-
#resource_type ⇒ String
Specifies the type of resource you are tagging.
-
#tags ⇒ Array<Types::Tag>
One or more tags.
Instance Attribute Details
#resource_id ⇒ String
The resource ID you want to tag.
Use the ID of the resource. Here are some examples:
MaintenanceWindow: mw-012345abcde
PatchBaseline: pb-012345abcde
Automation: example-c160-4567-8519-012345abcde
OpsMetadata object: ResourceID for tagging is created from the Amazon Resource Name (ARN) for the object. Specifically, ResourceID is created from the strings that come after the word opsmetadata in the ARN. For example, an OpsMetadata object with an ARN of arn:aws:ssm:us-east-2:1234567890:opsmetadata/aws/ssm/MyGroup/appmanager has a ResourceID of either aws/ssm/MyGroup/appmanager or /aws/ssm/MyGroup/appmanager.
For the Document and Parameter values, use the name of the resource. If you’re tagging a shared document, you must use the full ARN of the document.
ManagedInstance: mi-012345abcde
<note markdown=“1”> The ManagedInstance type for this API operation is only for on-premises managed nodes. You must specify the name of the managed node in the following format: ‘mi-ID_number `. For example, mi-1a2b3c4d5e6f.
</note>
166 167 168 169 170 171 172 |
# File 'lib/aws-sdk-ssm/types.rb', line 166 class AddTagsToResourceRequest < Struct.new( :resource_type, :resource_id, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Specifies the type of resource you are tagging.
<note markdown=“1”> The ManagedInstance type for this API operation is for on-premises managed nodes. You must specify the name of the managed node in the following format: ‘mi-ID_number `. For example, mi-1a2b3c4d5e6f.
</note>
166 167 168 169 170 171 172 |
# File 'lib/aws-sdk-ssm/types.rb', line 166 class AddTagsToResourceRequest < Struct.new( :resource_type, :resource_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
One or more tags. The value parameter is required.
Don’t enter personally identifiable information in this field.
166 167 168 169 170 171 172 |
# File 'lib/aws-sdk-ssm/types.rb', line 166 class AddTagsToResourceRequest < Struct.new( :resource_type, :resource_id, :tags) SENSITIVE = [] include Aws::Structure end |