Class: Aws::SSM::Types::AutomationExecution
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::AutomationExecution
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Detailed information about the current state of an individual Automation execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_configuration ⇒ Types::AlarmConfiguration
The details for the CloudWatch alarm applied to your automation.
-
#association_id ⇒ String
The ID of a State Manager association used in the Automation operation.
-
#automation_execution_id ⇒ String
The execution ID.
-
#automation_execution_status ⇒ String
The execution status of the Automation.
-
#automation_subtype ⇒ String
The subtype of the Automation operation.
-
#change_request_name ⇒ String
The name of the Change Manager change request.
-
#current_action ⇒ String
The action of the step that is currently running.
-
#current_step_name ⇒ String
The name of the step that is currently running.
-
#document_name ⇒ String
The name of the Automation runbook used during the execution.
-
#document_version ⇒ String
The version of the document to use during execution.
-
#executed_by ⇒ String
The Amazon Resource Name (ARN) of the user who ran the automation.
-
#execution_end_time ⇒ Time
The time the execution finished.
-
#execution_start_time ⇒ Time
The time the execution started.
-
#failure_message ⇒ String
A message describing why an execution has failed, if the status is set to Failed.
-
#max_concurrency ⇒ String
The
MaxConcurrencyvalue specified by the user when the execution started. -
#max_errors ⇒ String
The MaxErrors value specified by the user when the execution started.
-
#mode ⇒ String
The automation execution mode.
-
#ops_item_id ⇒ String
The ID of an OpsItem that is created to represent a Change Manager change request.
-
#outputs ⇒ Hash<String,Array<String>>
The list of execution outputs as defined in the Automation runbook.
-
#parameters ⇒ Hash<String,Array<String>>
The key-value map of execution parameters, which were supplied when calling StartAutomationExecution.
-
#parent_automation_execution_id ⇒ String
The AutomationExecutionId of the parent automation.
-
#progress_counters ⇒ Types::ProgressCounters
An aggregate of step execution statuses displayed in the Amazon Web Services Systems Manager console for a multi-Region and multi-account Automation execution.
-
#resolved_targets ⇒ Types::ResolvedTargets
A list of resolved targets in the rate control execution.
-
#runbooks ⇒ Array<Types::Runbook>
Information about the Automation runbooks that are run as part of a runbook workflow.
-
#scheduled_time ⇒ Time
The date and time the Automation operation is scheduled to start.
-
#step_executions ⇒ Array<Types::StepExecution>
A list of details about the current state of all steps that comprise an execution.
-
#step_executions_truncated ⇒ Boolean
A boolean value that indicates if the response contains the full list of the Automation step executions.
-
#target ⇒ String
The target of the execution.
-
#target_locations ⇒ Array<Types::TargetLocation>
The combination of Amazon Web Services Regions and/or Amazon Web Services accounts where you want to run the Automation.
-
#target_locations_url ⇒ String
A publicly accessible URL for a file that contains the
TargetLocationsbody. -
#target_maps ⇒ Array<Hash<String,Array<String>>>
The specified key-value mapping of document parameters to target resources.
-
#target_parameter_name ⇒ String
The parameter name.
-
#targets ⇒ Array<Types::Target>
The specified targets.
-
#triggered_alarms ⇒ Array<Types::AlarmStateInformation>
The CloudWatch alarm that was invoked by the automation.
-
#variables ⇒ Hash<String,Array<String>>
Variables defined for the automation.
Instance Attribute Details
#alarm_configuration ⇒ Types::AlarmConfiguration
The details for the CloudWatch alarm applied to your automation.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#association_id ⇒ String
The ID of a State Manager association used in the Automation operation.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#automation_execution_id ⇒ String
The execution ID.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#automation_execution_status ⇒ String
The execution status of the Automation.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#automation_subtype ⇒ String
The subtype of the Automation operation. Currently, the only supported value is ChangeRequest.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#change_request_name ⇒ String
The name of the Change Manager change request.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#current_action ⇒ String
The action of the step that is currently running.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#current_step_name ⇒ String
The name of the step that is currently running.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#document_name ⇒ String
The name of the Automation runbook used during the execution.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The version of the document to use during execution.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#executed_by ⇒ String
The Amazon Resource Name (ARN) of the user who ran the automation.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#execution_end_time ⇒ Time
The time the execution finished.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#execution_start_time ⇒ Time
The time the execution started.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
A message describing why an execution has failed, if the status is set to Failed.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#max_concurrency ⇒ String
The MaxConcurrency value specified by the user when the execution started.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#max_errors ⇒ String
The MaxErrors value specified by the user when the execution started.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The automation execution mode.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#ops_item_id ⇒ String
The ID of an OpsItem that is created to represent a Change Manager change request.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Hash<String,Array<String>>
The list of execution outputs as defined in the Automation runbook.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Array<String>>
The key-value map of execution parameters, which were supplied when calling StartAutomationExecution.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#parent_automation_execution_id ⇒ String
The AutomationExecutionId of the parent automation.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#progress_counters ⇒ Types::ProgressCounters
An aggregate of step execution statuses displayed in the Amazon Web Services Systems Manager console for a multi-Region and multi-account Automation execution.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#resolved_targets ⇒ Types::ResolvedTargets
A list of resolved targets in the rate control execution.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#runbooks ⇒ Array<Types::Runbook>
Information about the Automation runbooks that are run as part of a runbook workflow.
<note markdown=“1”> The Automation runbooks specified for the runbook workflow can’t run until all required approvals for the change request have been received.
</note>
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#scheduled_time ⇒ Time
The date and time the Automation operation is scheduled to start.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#step_executions ⇒ Array<Types::StepExecution>
A list of details about the current state of all steps that comprise an execution. An Automation runbook contains a list of steps that are run in order.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#step_executions_truncated ⇒ Boolean
A boolean value that indicates if the response contains the full list of the Automation step executions. If true, use the DescribeAutomationStepExecutions API operation to get the full list of step executions.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#target ⇒ String
The target of the execution.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#target_locations ⇒ Array<Types::TargetLocation>
The combination of Amazon Web Services Regions and/or Amazon Web Services accounts where you want to run the Automation.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#target_locations_url ⇒ String
A publicly accessible URL for a file that contains the TargetLocations body. Currently, only files in presigned Amazon S3 buckets are supported
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#target_maps ⇒ Array<Hash<String,Array<String>>>
The specified key-value mapping of document parameters to target resources.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#target_parameter_name ⇒ String
The parameter name.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<Types::Target>
The specified targets.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#triggered_alarms ⇒ Array<Types::AlarmStateInformation>
The CloudWatch alarm that was invoked by the automation.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |
#variables ⇒ Hash<String,Array<String>>
Variables defined for the automation.
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/aws-sdk-ssm/types.rb', line 1415 class AutomationExecution < Struct.new( :automation_execution_id, :document_name, :document_version, :execution_start_time, :execution_end_time, :automation_execution_status, :step_executions, :step_executions_truncated, :parameters, :outputs, :failure_message, :mode, :parent_automation_execution_id, :executed_by, :current_step_name, :current_action, :target_parameter_name, :targets, :target_maps, :resolved_targets, :max_concurrency, :max_errors, :target, :target_locations, :progress_counters, :alarm_configuration, :triggered_alarms, :target_locations_url, :automation_subtype, :scheduled_time, :runbooks, :ops_item_id, :association_id, :change_request_name, :variables) SENSITIVE = [] include Aws::Structure end |