Class: Aws::SSM::Types::AutomationExecutionInputs

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Information about the optional inputs that can be specified for an automation execution preview.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#parametersHash<String,Array<String>>

Information about parameters that can be specified for the preview operation.



1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-ssm/types.rb', line 1520

class AutomationExecutionInputs < Struct.new(
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :target_locations,
  :target_locations_url)
  SENSITIVE = []
  include Aws::Structure
end

#target_locationsArray<Types::TargetLocation>

Information about the Amazon Web Services Regions and Amazon Web Services accounts targeted by the Automation execution preview operation.



1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-ssm/types.rb', line 1520

class AutomationExecutionInputs < Struct.new(
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :target_locations,
  :target_locations_url)
  SENSITIVE = []
  include Aws::Structure
end

#target_locations_urlString

A publicly accessible URL for a file that contains the TargetLocations body. Currently, only files in presigned Amazon S3 buckets are supported.



1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-ssm/types.rb', line 1520

class AutomationExecutionInputs < Struct.new(
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :target_locations,
  :target_locations_url)
  SENSITIVE = []
  include Aws::Structure
end

#target_mapsArray<Hash<String,Array<String>>>

A key-value mapping of document parameters to target resources. Both Targets and TargetMaps can't be specified together.



1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-ssm/types.rb', line 1520

class AutomationExecutionInputs < Struct.new(
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :target_locations,
  :target_locations_url)
  SENSITIVE = []
  include Aws::Structure
end

#target_parameter_nameString

The name of the parameter used as the target resource for the rate-controlled execution. Required if you specify targets.



1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-ssm/types.rb', line 1520

class AutomationExecutionInputs < Struct.new(
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :target_locations,
  :target_locations_url)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<Types::Target>

Information about the resources that would be included in the actual runbook execution, if it were to be run. Both Targets and TargetMaps can't be specified together.



1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-ssm/types.rb', line 1520

class AutomationExecutionInputs < Struct.new(
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :target_locations,
  :target_locations_url)
  SENSITIVE = []
  include Aws::Structure
end