Class: Aws::SSM::Types::AzureConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

The access details and targets for connecting to a Microsoft Azure tenant, including the application registration used for authentication and the subscriptions to target.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_display_nameString

The display name of the Azure application registration.

Returns:

  • (String)


1832
1833
1834
1835
1836
1837
1838
1839
1840
# File 'lib/aws-sdk-ssm/types.rb', line 1832

class AzureConfiguration < Struct.new(
  :tenant_id,
  :tenant_display_name,
  :application_id,
  :application_display_name,
  :targets)
  SENSITIVE = []
  include Aws::Structure
end

#application_idString

The ID of the Azure application registration used for authentication.

Returns:

  • (String)


1832
1833
1834
1835
1836
1837
1838
1839
1840
# File 'lib/aws-sdk-ssm/types.rb', line 1832

class AzureConfiguration < Struct.new(
  :tenant_id,
  :tenant_display_name,
  :application_id,
  :application_display_name,
  :targets)
  SENSITIVE = []
  include Aws::Structure
end

#targetsTypes::ConfigurationTargets

The target Azure subscriptions for the cloud connector.



1832
1833
1834
1835
1836
1837
1838
1839
1840
# File 'lib/aws-sdk-ssm/types.rb', line 1832

class AzureConfiguration < Struct.new(
  :tenant_id,
  :tenant_display_name,
  :application_id,
  :application_display_name,
  :targets)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_display_nameString

The display name of the Azure tenant.

Returns:

  • (String)


1832
1833
1834
1835
1836
1837
1838
1839
1840
# File 'lib/aws-sdk-ssm/types.rb', line 1832

class AzureConfiguration < Struct.new(
  :tenant_id,
  :tenant_display_name,
  :application_id,
  :application_display_name,
  :targets)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_idString

The ID of the Azure tenant.

Returns:

  • (String)


1832
1833
1834
1835
1836
1837
1838
1839
1840
# File 'lib/aws-sdk-ssm/types.rb', line 1832

class AzureConfiguration < Struct.new(
  :tenant_id,
  :tenant_display_name,
  :application_id,
  :application_display_name,
  :targets)
  SENSITIVE = []
  include Aws::Structure
end