Class: Aws::SSM::Types::BaselineOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::BaselineOverride
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Defines the basic information about a patch baseline override.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approval_rules ⇒ Types::PatchRuleGroup
A set of rules defining the approval rules for a patch baseline.
-
#approved_patches ⇒ Array<String>
A list of explicitly approved patches for the baseline.
-
#approved_patches_compliance_level ⇒ String
Defines the compliance level for approved patches.
-
#approved_patches_enable_non_security ⇒ Boolean
Indicates whether the list of approved patches includes non-security updates that should be applied to the managed nodes.
-
#available_security_updates_compliance_status ⇒ String
Indicates whether managed nodes for which there are available security-related patches that have not been approved by the baseline are being defined as
COMPLIANTorNON_COMPLIANT. -
#global_filters ⇒ Types::PatchFilterGroup
A set of patch filters, typically used for approval rules.
-
#operating_system ⇒ String
The operating system rule used by the patch baseline override.
-
#rejected_patches ⇒ Array<String>
A list of explicitly rejected patches for the baseline.
-
#rejected_patches_action ⇒ String
The action for Patch Manager to take on patches included in the
RejectedPackageslist. -
#sources ⇒ Array<Types::PatchSource>
Information about the patches to use to update the managed nodes, including target operating systems and source repositories.
Instance Attribute Details
#approval_rules ⇒ Types::PatchRuleGroup
A set of rules defining the approval rules for a patch baseline.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#approved_patches ⇒ Array<String>
A list of explicitly approved patches for the baseline.
For information about accepted formats for lists of approved patches and rejected patches, see [Package name formats for approved and rejected patch lists] in the *Amazon Web Services Systems Manager User Guide*.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#approved_patches_compliance_level ⇒ String
Defines the compliance level for approved patches. When an approved patch is reported as missing, this value describes the severity of the compliance violation.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#approved_patches_enable_non_security ⇒ Boolean
Indicates whether the list of approved patches includes non-security updates that should be applied to the managed nodes. The default value is false. Applies to Linux managed nodes only.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#available_security_updates_compliance_status ⇒ String
Indicates whether managed nodes for which there are available security-related patches that have not been approved by the baseline are being defined as COMPLIANT or NON_COMPLIANT. This option is specified when the CreatePatchBaseline or UpdatePatchBaseline commands are run.
Applies to Windows Server managed nodes only.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#global_filters ⇒ Types::PatchFilterGroup
A set of patch filters, typically used for approval rules.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#operating_system ⇒ String
The operating system rule used by the patch baseline override.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#rejected_patches ⇒ Array<String>
A list of explicitly rejected patches for the baseline.
For information about accepted formats for lists of approved patches and rejected patches, see [Package name formats for approved and rejected patch lists] in the *Amazon Web Services Systems Manager User Guide*.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#rejected_patches_action ⇒ String
The action for Patch Manager to take on patches included in the RejectedPackages list. A patch can be allowed only if it is a dependency of another package, or blocked entirely along with packages that include it as a dependency.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::PatchSource>
Information about the patches to use to update the managed nodes, including target operating systems and source repositories. Applies to Linux managed nodes only.
1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-ssm/types.rb', line 1882 class BaselineOverride < Struct.new( :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :rejected_patches, :rejected_patches_action, :approved_patches_enable_non_security, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |