Class: Aws::SSM::Types::CloudConnectorSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::CloudConnectorSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Summary information about a cloud connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_connector_id ⇒ String
The ID of the cloud connector.
-
#created_at ⇒ Time
The date and time the cloud connector was created.
-
#description ⇒ String
The description of the cloud connector.
-
#display_name ⇒ String
The friendly name of the cloud connector.
-
#role_arn ⇒ String
The ARN of the IAM role used by the cloud connector.
-
#updated_at ⇒ Time
The date and time the cloud connector was last updated.
Instance Attribute Details
#cloud_connector_id ⇒ String
The ID of the cloud connector.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-ssm/types.rb', line 2086 class CloudConnectorSummary < Struct.new( :cloud_connector_id, :display_name, :description, :role_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the cloud connector was created.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-ssm/types.rb', line 2086 class CloudConnectorSummary < Struct.new( :cloud_connector_id, :display_name, :description, :role_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the cloud connector.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-ssm/types.rb', line 2086 class CloudConnectorSummary < Struct.new( :cloud_connector_id, :display_name, :description, :role_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The friendly name of the cloud connector.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-ssm/types.rb', line 2086 class CloudConnectorSummary < Struct.new( :cloud_connector_id, :display_name, :description, :role_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role used by the cloud connector.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-ssm/types.rb', line 2086 class CloudConnectorSummary < Struct.new( :cloud_connector_id, :display_name, :description, :role_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the cloud connector was last updated.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-ssm/types.rb', line 2086 class CloudConnectorSummary < Struct.new( :cloud_connector_id, :display_name, :description, :role_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |