Class: Aws::SSM::Types::ComplianceItem

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Information about the compliance as defined by the resource type. For example, for a patch resource type, Items includes information about the PatchSeverity, Classification, and so on.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compliance_typeString

The compliance type. For example, Association (for a State Manager association), Patch, or Custom:string are all valid compliance types.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#detailsHash<String,String>

A "Key": "Value" tag combination for the compliance item.

Returns:

  • (Hash<String,String>)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#execution_summaryTypes::ComplianceExecutionSummary

A summary for the compliance item. The summary includes an execution ID, the execution type (for example, command), and the execution time.

For State Manager associations, the ExecutionTime value represents when the compliance status was captured and aggregated by the Systems Manager service, not necessarily when the underlying association was executed on the managed node. State Manager updates compliance status for all associations on an instance whenever any association executes, which means multiple associations may show the same execution time even if they were executed at different times.



2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#idString

An ID for the compliance item. For example, if the compliance item is a Windows patch, the ID could be the number of the KB article; for example: KB4010320.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

An ID for the resource. For a managed node, this is the node ID.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource. ManagedInstance is currently the only supported resource type.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The severity of the compliance status. Severity can be one of the following: Critical, High, Medium, Low, Informational, Unspecified.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the compliance item. An item is either COMPLIANT, NON_COMPLIANT, or an empty string (for Windows patches that aren't applicable).

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

A title for the compliance item. For example, if the compliance item is a Windows patch, the title could be the title of the KB article for the patch; for example: Security Update for Active Directory Federation Services.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-ssm/types.rb', line 2874

class ComplianceItem < Struct.new(
  :compliance_type,
  :resource_type,
  :resource_id,
  :id,
  :title,
  :status,
  :severity,
  :execution_summary,
  :details)
  SENSITIVE = []
  include Aws::Structure
end