Class: Aws::SSM::Types::ConfigurationTargets

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Note:

ConfigurationTargets is a union - when making an API calls you must set exactly one of the members.

Note:

ConfigurationTargets is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConfigurationTargets corresponding to the set member.

The target resources in the third-party cloud environment.

Defined Under Namespace

Classes: Subscriptions, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#subscriptionsArray<Types::AzureSubscription>

A list of Azure subscriptions to target.

Returns:



3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
# File 'lib/aws-sdk-ssm/types.rb', line 3025

class ConfigurationTargets < Struct.new(
  :subscriptions,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Subscriptions < ConfigurationTargets; end
  class Unknown < ConfigurationTargets; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3025
3026
3027
# File 'lib/aws-sdk-ssm/types.rb', line 3025

def unknown
  @unknown
end