Class: Aws::SSM::Types::ConflictException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

An error occurred because of a conflict with a concurrent request or the current state of the resource. Retry your request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3044
3045
3046
3047
3048
# File 'lib/aws-sdk-ssm/types.rb', line 3044

class ConflictException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end