Class: Aws::SSM::Types::CreateAssociationBatchRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_dispatch_assume_roleString

A role used by association to take actions on your behalf. State Manager will assume this role and call required APIs when dispatching configurations to nodes. If not specified, [ service-linked role for Systems Manager] will be used by default.

<note markdown=“1”> It is recommended that you define a custom IAM role so that you have full control of the permissions that State Manager has when taking actions on your behalf.

Service-linked role support in State Manager is being phased out.

Associations relying on service-linked role may require updates in the future to continue functioning properly.

</note>

[1]: docs.aws.amazon.com/systems-manager/latest/userguide/using-service-linked-roles.html

Returns:

  • (String)


3002
3003
3004
3005
3006
3007
# File 'lib/aws-sdk-ssm/types.rb', line 3002

class CreateAssociationBatchRequest < Struct.new(
  :entries,
  :association_dispatch_assume_role)
  SENSITIVE = []
  include Aws::Structure
end

#entriesArray<Types::CreateAssociationBatchRequestEntry>

One or more associations.



3002
3003
3004
3005
3006
3007
# File 'lib/aws-sdk-ssm/types.rb', line 3002

class CreateAssociationBatchRequest < Struct.new(
  :entries,
  :association_dispatch_assume_role)
  SENSITIVE = []
  include Aws::Structure
end