Class: Aws::SSM::Types::CreateCloudConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::CreateCloudConnectorRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config_connector_arn ⇒ String
The ARN of the Amazon Web Services Config connector associated with this cloud connector.
-
#configuration ⇒ Types::CloudConnectorConfiguration
The configuration details for connecting to the third-party cloud environment.
-
#description ⇒ String
A description for the cloud connector.
-
#display_name ⇒ String
A friendly name for the cloud connector.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that the cloud connector uses to communicate with the third-party cloud environment.
-
#tags ⇒ Array<Types::Tag>
Optional metadata that you assign to a resource.
Instance Attribute Details
#config_connector_arn ⇒ String
The ARN of the Amazon Web Services Config connector associated with this cloud connector.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 |
# File 'lib/aws-sdk-ssm/types.rb', line 3776 class CreateCloudConnectorRequest < Struct.new( :display_name, :role_arn, :description, :configuration, :config_connector_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::CloudConnectorConfiguration
The configuration details for connecting to the third-party cloud environment.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 |
# File 'lib/aws-sdk-ssm/types.rb', line 3776 class CreateCloudConnectorRequest < Struct.new( :display_name, :role_arn, :description, :configuration, :config_connector_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the cloud connector.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 |
# File 'lib/aws-sdk-ssm/types.rb', line 3776 class CreateCloudConnectorRequest < Struct.new( :display_name, :role_arn, :description, :configuration, :config_connector_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
A friendly name for the cloud connector.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 |
# File 'lib/aws-sdk-ssm/types.rb', line 3776 class CreateCloudConnectorRequest < Struct.new( :display_name, :role_arn, :description, :configuration, :config_connector_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that the cloud connector uses to communicate with the third-party cloud environment.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 |
# File 'lib/aws-sdk-ssm/types.rb', line 3776 class CreateCloudConnectorRequest < Struct.new( :display_name, :role_arn, :description, :configuration, :config_connector_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Optional metadata that you assign to a resource. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 |
# File 'lib/aws-sdk-ssm/types.rb', line 3776 class CreateCloudConnectorRequest < Struct.new( :display_name, :role_arn, :description, :configuration, :config_connector_arn, :tags) SENSITIVE = [] include Aws::Structure end |