Class: Aws::SSM::Types::CreatePatchBaselineRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::CreatePatchBaselineRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approval_rules ⇒ Types::PatchRuleGroup
A set of rules used to include patches in the baseline.
-
#approved_patches ⇒ Array<String>
A list of explicitly approved patches for the baseline.
-
#approved_patches_compliance_level ⇒ String
Defines the compliance level for approved patches.
-
#approved_patches_enable_non_security ⇒ Boolean
Indicates whether the list of approved patches includes non-security updates that should be applied to the managed nodes.
-
#available_security_updates_compliance_status ⇒ String
Indicates the status you want to assign to security patches that are available but not approved because they don't meet the installation criteria specified in the patch baseline.
-
#client_token ⇒ String
User-provided idempotency token.
-
#description ⇒ String
A description of the patch baseline.
-
#global_filters ⇒ Types::PatchFilterGroup
A set of global filters used to include patches in the baseline.
-
#name ⇒ String
The name of the patch baseline.
-
#operating_system ⇒ String
Defines the operating system the patch baseline applies to.
-
#rejected_patches ⇒ Array<String>
A list of explicitly rejected patches for the baseline.
-
#rejected_patches_action ⇒ String
The action for Patch Manager to take on patches included in the
RejectedPackageslist. -
#sources ⇒ Array<Types::PatchSource>
Information about the patches to use to update the managed nodes, including target operating systems and source repositories.
-
#tags ⇒ Array<Types::Tag>
Optional metadata that you assign to a resource.
Instance Attribute Details
#approval_rules ⇒ Types::PatchRuleGroup
A set of rules used to include patches in the baseline.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#approved_patches ⇒ Array<String>
A list of explicitly approved patches for the baseline.
For information about accepted formats for lists of approved patches and rejected patches, see Package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#approved_patches_compliance_level ⇒ String
Defines the compliance level for approved patches. When an approved
patch is reported as missing, this value describes the severity of
the compliance violation. The default value is UNSPECIFIED.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#approved_patches_enable_non_security ⇒ Boolean
Indicates whether the list of approved patches includes non-security
updates that should be applied to the managed nodes. The default
value is false. Applies to Linux managed nodes only.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#available_security_updates_compliance_status ⇒ String
Indicates the status you want to assign to security patches that are available but not approved because they don't meet the installation criteria specified in the patch baseline.
Example scenario: Security patches that you might want installed can be skipped if you have specified a long period to wait after a patch is released before installation. If an update to the patch is released during your specified waiting period, the waiting period for installing the patch starts over. If the waiting period is too long, multiple versions of the patch could be released but never installed.
Supported for Windows Server managed nodes only.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
User-provided idempotency token.
A suitable default value is auto-generated. You should normally not need to pass this option.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the patch baseline.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#global_filters ⇒ Types::PatchFilterGroup
A set of global filters used to include patches in the baseline.
The GlobalFilters parameter can be configured only by using the
CLI or an Amazon Web Services SDK. It can't be configured from the
Patch Manager console, and its value isn't displayed in the
console.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the patch baseline.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#operating_system ⇒ String
Defines the operating system the patch baseline applies to. The
default value is WINDOWS.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#rejected_patches ⇒ Array<String>
A list of explicitly rejected patches for the baseline.
For information about accepted formats for lists of approved patches and rejected patches, see Package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#rejected_patches_action ⇒ String
The action for Patch Manager to take on patches included in the
RejectedPackages list.
ALLOW_AS_DEPENDENCY
: Linux and macOS: A package in the rejected patches list is
installed only if it is a dependency of another package. It is
considered compliant with the patch baseline, and its status is
reported as INSTALLED_OTHER. This is the default action if no
option is specified.
**Windows Server**: Windows Server doesn't support the concept of
package dependencies. If a package in the rejected patches list
and already installed on the node, its status is reported as
`INSTALLED_OTHER`. Any package not already installed on the node
is skipped. This is the default action if no option is specified.
BLOCK
: All OSs: Packages in the rejected patches list, and packages that include them as dependencies, aren't installed by Patch Manager under any circumstances.
State value assignment for patch compliance:
* If a package was installed before it was added to the rejected
patches list, or is installed outside of Patch Manager
afterward, it's considered noncompliant with the patch baseline
and its status is reported as `INSTALLED_REJECTED`.
* If an update attempts to install a dependency package that is
now rejected by the baseline, when previous versions of the
package were not rejected, the package being updated is reported
as `MISSING` for `SCAN` operations and as `FAILED` for `INSTALL`
operations.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::PatchSource>
Information about the patches to use to update the managed nodes, including target operating systems and source repositories. Applies to Linux managed nodes only.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Optional metadata that you assign to a resource. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag a patch baseline to identify the severity level of patches it specifies and the operating system family it applies to. In this case, you could specify the following key-value pairs:
-
Key=PatchSeverity,Value=Critical -
Key=OS,Value=Windows
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/aws-sdk-ssm/types.rb', line 4480 class CreatePatchBaselineRequest < Struct.new( :operating_system, :name, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :description, :sources, :available_security_updates_compliance_status, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |