Class: Aws::SSM::Types::DeleteInventoryResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletion_idString

Every DeleteInventory operation is assigned a unique ID. This option returns a unique ID. You can use this ID to query the status of a delete operation. This option is useful for ensuring that a delete operation has completed before you begin other operations.

Returns:

  • (String)


4793
4794
4795
4796
4797
4798
4799
# File 'lib/aws-sdk-ssm/types.rb', line 4793

class DeleteInventoryResult < Struct.new(
  :deletion_id,
  :type_name,
  :deletion_summary)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_summaryTypes::InventoryDeletionSummary

A summary of the delete operation. For more information about this summary, see Deleting custom inventory in the Amazon Web Services Systems Manager User Guide.



4793
4794
4795
4796
4797
4798
4799
# File 'lib/aws-sdk-ssm/types.rb', line 4793

class DeleteInventoryResult < Struct.new(
  :deletion_id,
  :type_name,
  :deletion_summary)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the inventory data type specified in the request.

Returns:

  • (String)


4793
4794
4795
4796
4797
4798
4799
# File 'lib/aws-sdk-ssm/types.rb', line 4793

class DeleteInventoryResult < Struct.new(
  :deletion_id,
  :type_name,
  :deletion_summary)
  SENSITIVE = []
  include Aws::Structure
end