Class: Aws::SSM::Types::DescribeInstanceInformationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DescribeInstanceInformationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::InstanceInformationStringFilter>
One or more filters.
-
#instance_information_filter_list ⇒ Array<Types::InstanceInformationFilter>
This is a legacy method.
-
#max_results ⇒ Integer
The maximum number of items to return for this call.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#filters ⇒ Array<Types::InstanceInformationStringFilter>
One or more filters. Use a filter to return a more specific list of managed nodes. You can filter based on tags applied to your managed nodes. Tag filters can’t be combined with other filter types. Use this Filters data type instead of InstanceInformationFilterList, which is deprecated.
5553 5554 5555 5556 5557 5558 5559 5560 |
# File 'lib/aws-sdk-ssm/types.rb', line 5553 class DescribeInstanceInformationRequest < Struct.new( :instance_information_filter_list, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_information_filter_list ⇒ Array<Types::InstanceInformationFilter>
This is a legacy method. We recommend that you don’t use this method. Instead, use the Filters data type. Filters enables you to return node information by filtering based on tags applied to managed nodes.
<note markdown=“1”> Attempting to use InstanceInformationFilterList and Filters leads to an exception error.
</note>
5553 5554 5555 5556 5557 5558 5559 5560 |
# File 'lib/aws-sdk-ssm/types.rb', line 5553 class DescribeInstanceInformationRequest < Struct.new( :instance_information_filter_list, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. The default value is 10 items.
5553 5554 5555 5556 5557 5558 5559 5560 |
# File 'lib/aws-sdk-ssm/types.rb', line 5553 class DescribeInstanceInformationRequest < Struct.new( :instance_information_filter_list, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5553 5554 5555 5556 5557 5558 5559 5560 |
# File 'lib/aws-sdk-ssm/types.rb', line 5553 class DescribeInstanceInformationRequest < Struct.new( :instance_information_filter_list, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |