Class: Aws::SSM::Types::DescribeMaintenanceWindowsForTargetResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token for the next set of items to return. (You use this token in the next call.)

Returns:

  • (String)


6493
6494
6495
6496
6497
6498
# File 'lib/aws-sdk-ssm/types.rb', line 6493

class DescribeMaintenanceWindowsForTargetResult < Struct.new(
  :window_identities,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#window_identitiesArray<Types::MaintenanceWindowIdentityForTarget>

Information about the maintenance window targets and tasks a managed node is associated with.



6493
6494
6495
6496
6497
6498
# File 'lib/aws-sdk-ssm/types.rb', line 6493

class DescribeMaintenanceWindowsForTargetResult < Struct.new(
  :window_identities,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end