Class: Aws::SSM::Types::DocumentDescription

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Describes an Amazon Web Services Systems Manager document (SSM document).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approved_versionString

The version of the document currently approved for use in the organization.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#attachments_informationArray<Types::AttachmentInformation>

Details about the document attachments, including names, locations, sizes, and so on.

Returns:



7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#authorString

The user in your organization who created the document.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#categoryArray<String>

The classification of a document to help you identify and categorize its use.

Returns:

  • (Array<String>)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#category_enumArray<String>

The value that identifies a document’s category.

Returns:

  • (Array<String>)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateTime

The date when the document was created.

Returns:

  • (Time)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#default_versionString

The default version.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the document.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The friendly name of the SSM document. This value can differ for each version of the document. If you want to update this value, see UpdateDocument.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#document_formatString

The document format, either JSON or YAML.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#document_typeString

The type of document.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#document_versionString

The document version.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#hashString

The Sha256 or Sha1 hash created by the system when the document was created.

<note markdown=“1”> Sha1 hashes have been deprecated.

</note>

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#hash_typeString

The hash type of the document. Valid values include Sha256 or Sha1.

<note markdown=“1”> Sha1 hashes have been deprecated.

</note>

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#latest_versionString

The latest version of the document.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the SSM document.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

The Amazon Web Services user that created the document.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#parametersArray<Types::DocumentParameter>

A description of the parameters for a document.

Returns:



7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#pending_review_versionString

The version of the document that is currently under review.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#platform_typesArray<String>

The list of operating system (OS) platforms compatible with this SSM document.

Returns:

  • (Array<String>)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#requiresArray<Types::DocumentRequires>

A list of SSM documents required by a document. For example, an ApplicationConfiguration document requires an ApplicationConfigurationSchema document.

Returns:



7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#review_informationArray<Types::ReviewInformation>

Details about the review of a document.

Returns:



7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#review_statusString

The current status of the review.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#schema_versionString

The schema version.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#sha_1String

The SHA1 hash of the document, which you can use for verification.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SSM document.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#status_informationString

A message returned by Amazon Web Services Systems Manager that explains the Status value. For example, a Failed status might be explained by the StatusInformation message, “The specified S3 bucket doesn’t exist. Verify that the URL of the S3 bucket is correct.”

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags, or metadata, that have been applied to the document.

Returns:



7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#target_typeString

The target type which defines the kinds of resources the document can run on. For example, /AWS::EC2::Instance. For a list of valid resource types, see [Amazon Web Services resource and property types reference] in the *CloudFormation User Guide*.

[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end

#version_nameString

The version of the artifact associated with the document.

Returns:

  • (String)


7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/aws-sdk-ssm/types.rb', line 7008

class DocumentDescription < Struct.new(
  :sha_1,
  :hash,
  :hash_type,
  :name,
  :display_name,
  :version_name,
  :owner,
  :created_date,
  :status,
  :status_information,
  :document_version,
  :description,
  :parameters,
  :platform_types,
  :document_type,
  :schema_version,
  :latest_version,
  :default_version,
  :document_format,
  :target_type,
  :tags,
  :attachments_information,
  :requires,
  :author,
  :review_information,
  :approved_version,
  :pending_review_version,
  :review_status,
  :category,
  :category_enum)
  SENSITIVE = []
  include Aws::Structure
end