Class: Aws::SSM::Types::DocumentIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DocumentIdentifier
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Describes the name of a SSM document.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#author ⇒ String
The user in your organization who created the document.
-
#created_date ⇒ Time
The date the SSM document was created.
-
#display_name ⇒ String
An optional field where you can specify a friendly name for the SSM document.
-
#document_format ⇒ String
The document format, either JSON or YAML.
-
#document_type ⇒ String
The document type.
-
#document_version ⇒ String
The document version.
-
#name ⇒ String
The name of the SSM document.
-
#owner ⇒ String
The Amazon Web Services user that created the document.
-
#platform_types ⇒ Array<String>
The operating system platform.
-
#requires ⇒ Array<Types::DocumentRequires>
A list of SSM documents required by a document.
-
#review_status ⇒ String
The current status of a document review.
-
#schema_version ⇒ String
The schema version.
-
#tags ⇒ Array<Types::Tag>
The tags, or metadata, that have been applied to the document.
-
#target_type ⇒ String
The target type which defines the kinds of resources the document can run on.
-
#version_name ⇒ String
An optional field specifying the version of the artifact associated with the document.
Instance Attribute Details
#author ⇒ String
The user in your organization who created the document.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date the SSM document was created.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
An optional field where you can specify a friendly name for the SSM document. This value can differ for each version of the document. If you want to update this value, see UpdateDocument.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#document_format ⇒ String
The document format, either JSON or YAML.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#document_type ⇒ String
The document type.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The document version.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SSM document.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The Amazon Web Services user that created the document.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#platform_types ⇒ Array<String>
The operating system platform.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#requires ⇒ Array<Types::DocumentRequires>
A list of SSM documents required by a document. For example, an ApplicationConfiguration document requires an ApplicationConfigurationSchema document.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#review_status ⇒ String
The current status of a document review.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#schema_version ⇒ String
The schema version.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags, or metadata, that have been applied to the document.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
The target type which defines the kinds of resources the document can run on. For example, /AWS::EC2::Instance. For a list of valid resource types, see [Amazon Web Services resource and property types reference] in the *CloudFormation User Guide*.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
An optional field specifying the version of the artifact associated with the document. For example, 12.6. This value is unique across all versions of a document, and can’t be changed.
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 |
# File 'lib/aws-sdk-ssm/types.rb', line 7139 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |