Class: Aws::SSM::Types::DocumentPermissionLimit
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DocumentPermissionLimit
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The document can't be shared with more Amazon Web Services accounts. You can specify a maximum of 20 accounts per API operation to share a private document.
By default, you can share a private document with a maximum of 1,000 accounts and publicly share up to five documents.
If you need to increase the quota for privately or publicly shared Systems Manager documents, contact Amazon Web Services Support.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
7607 7608 7609 7610 7611 |
# File 'lib/aws-sdk-ssm/types.rb', line 7607 class DocumentPermissionLimit < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |