Class: Aws::SSM::Types::DocumentRequires
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DocumentRequires
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
An SSM document required by the current document.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the required SSM document.
-
#require_type ⇒ String
The document type of the required SSM document.
-
#version ⇒ String
The document version required by the current document.
-
#version_name ⇒ String
An optional field specifying the version of the artifact associated with the document.
Instance Attribute Details
#name ⇒ String
The name of the required SSM document. The name can be an Amazon Resource Name (ARN).
7357 7358 7359 7360 7361 7362 7363 7364 |
# File 'lib/aws-sdk-ssm/types.rb', line 7357 class DocumentRequires < Struct.new( :name, :version, :require_type, :version_name) SENSITIVE = [] include Aws::Structure end |
#require_type ⇒ String
The document type of the required SSM document.
7357 7358 7359 7360 7361 7362 7363 7364 |
# File 'lib/aws-sdk-ssm/types.rb', line 7357 class DocumentRequires < Struct.new( :name, :version, :require_type, :version_name) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The document version required by the current document.
7357 7358 7359 7360 7361 7362 7363 7364 |
# File 'lib/aws-sdk-ssm/types.rb', line 7357 class DocumentRequires < Struct.new( :name, :version, :require_type, :version_name) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
An optional field specifying the version of the artifact associated with the document. For example, 12.6. This value is unique across all versions of a document, and can’t be changed.
7357 7358 7359 7360 7361 7362 7363 7364 |
# File 'lib/aws-sdk-ssm/types.rb', line 7357 class DocumentRequires < Struct.new( :name, :version, :require_type, :version_name) SENSITIVE = [] include Aws::Structure end |