Class: Aws::SSM::Types::DocumentVersionInfo

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Version information about the document.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_dateTime

The date the document was created.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The friendly name of the SSM document. This value can differ for each version of the document. If you want to update this value, see UpdateDocument.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#document_formatString

The document format, either JSON or YAML.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#document_versionString

The document version.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#is_default_versionBoolean

An identifier for the default version of the document.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The document name.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#review_statusString

The current status of the approval review for the latest version of the document.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SSM document, such as Creating, Active, Failed, and Deleting.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#status_informationString

A message returned by Amazon Web Services Systems Manager that explains the Status value. For example, a Failed status might be explained by the StatusInformation message, "The specified S3 bucket doesn't exist. Verify that the URL of the S3 bucket is correct."



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#version_nameString

The version of the artifact associated with the document. For example, 12.6. This value is unique across all versions of a document, and can't be changed.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/aws-sdk-ssm/types.rb', line 7786

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end