Method: Aws::SSM::Types::DocumentVersionInfo#status_information

Defined in:
lib/aws-sdk-ssm/types.rb

#status_informationString

A message returned by Amazon Web Services Systems Manager that explains the Status value. For example, a Failed status might be explained by the StatusInformation message, “The specified S3 bucket doesn’t exist. Verify that the URL of the S3 bucket is correct.”

Returns:

  • (String)


7507
7508
7509
7510
7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
# File 'lib/aws-sdk-ssm/types.rb', line 7507

class DocumentVersionInfo < Struct.new(
  :name,
  :display_name,
  :document_version,
  :version_name,
  :created_date,
  :is_default_version,
  :document_format,
  :status,
  :status_information,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end