Class: Aws::SSM::Types::DoesNotExistException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Error returned when the ID specified for a resource, such as a maintenance window or patch baseline, doesn't exist.

For information about resource quotas in Amazon Web Services Systems Manager, see Systems Manager service quotas in the Amazon Web Services General Reference.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


7831
7832
7833
7834
7835
# File 'lib/aws-sdk-ssm/types.rb', line 7831

class DoesNotExistException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end