Class: Aws::SSM::Types::ExecutionPreview
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ExecutionPreview
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Note:
ExecutionPreview is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ExecutionPreview corresponding to the set member.
Information about the changes that would be made if an execution were run.
Direct Known Subclasses
Defined Under Namespace
Classes: Automation, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automation ⇒ Types::AutomationExecutionPreview
Information about the changes that would be made if an Automation workflow were run.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#automation ⇒ Types::AutomationExecutionPreview
Information about the changes that would be made if an Automation workflow were run.
7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 |
# File 'lib/aws-sdk-ssm/types.rb', line 7654 class ExecutionPreview < Struct.new( :automation, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Automation < ExecutionPreview; end class Unknown < ExecutionPreview; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7654 7655 7656 |
# File 'lib/aws-sdk-ssm/types.rb', line 7654 def unknown @unknown end |