Class: Aws::SSM::Types::GetCalendarStateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetCalendarStateRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#at_time ⇒ String
(Optional) The specific time for which you want to get calendar state information, in [ISO 8601] format.
-
#calendar_names ⇒ Array<String>
The names of Amazon Resource Names (ARNs) of the Systems Manager documents (SSM documents) that represent the calendar entries for which you want to get the state.
Instance Attribute Details
#at_time ⇒ String
(Optional) The specific time for which you want to get calendar state information, in [ISO 8601] format. If you don’t specify a value or AtTime, the current time is used.
7805 7806 7807 7808 7809 7810 |
# File 'lib/aws-sdk-ssm/types.rb', line 7805 class GetCalendarStateRequest < Struct.new( :calendar_names, :at_time) SENSITIVE = [] include Aws::Structure end |
#calendar_names ⇒ Array<String>
The names of Amazon Resource Names (ARNs) of the Systems Manager documents (SSM documents) that represent the calendar entries for which you want to get the state.
7805 7806 7807 7808 7809 7810 |
# File 'lib/aws-sdk-ssm/types.rb', line 7805 class GetCalendarStateRequest < Struct.new( :calendar_names, :at_time) SENSITIVE = [] include Aws::Structure end |