Class: Aws::SSM::Types::GetCalendarStateResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#at_timeString

The time, as an ISO 8601 string, that you specified in your command. If you don't specify a time, GetCalendarState uses the current time.

Returns:

  • (String)


8107
8108
8109
8110
8111
8112
8113
# File 'lib/aws-sdk-ssm/types.rb', line 8107

class GetCalendarStateResponse < Struct.new(
  :state,
  :at_time,
  :next_transition_time)
  SENSITIVE = []
  include Aws::Structure
end

#next_transition_timeString

The time, as an ISO 8601 string, that the calendar state will change. If the current calendar state is OPEN, NextTransitionTime indicates when the calendar state changes to CLOSED, and vice-versa.

Returns:

  • (String)


8107
8108
8109
8110
8111
8112
8113
# File 'lib/aws-sdk-ssm/types.rb', line 8107

class GetCalendarStateResponse < Struct.new(
  :state,
  :at_time,
  :next_transition_time)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the calendar. An OPEN calendar indicates that actions are allowed to proceed, and a CLOSED calendar indicates that actions aren't allowed to proceed.

Returns:

  • (String)


8107
8108
8109
8110
8111
8112
8113
# File 'lib/aws-sdk-ssm/types.rb', line 8107

class GetCalendarStateResponse < Struct.new(
  :state,
  :at_time,
  :next_transition_time)
  SENSITIVE = []
  include Aws::Structure
end