Class: Aws::SSM::Types::GetCloudConnectorResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_connector_arnString

The ARN of the cloud connector.

Returns:

  • (String)


8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
# File 'lib/aws-sdk-ssm/types.rb', line 8163

class GetCloudConnectorResult < Struct.new(
  :cloud_connector_arn,
  :display_name,
  :description,
  :role_arn,
  :configuration,
  :config_connector_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#config_connector_arnString

The ARN of the Amazon Web Services Config connector associated with this cloud connector.

Returns:

  • (String)


8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
# File 'lib/aws-sdk-ssm/types.rb', line 8163

class GetCloudConnectorResult < Struct.new(
  :cloud_connector_arn,
  :display_name,
  :description,
  :role_arn,
  :configuration,
  :config_connector_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::CloudConnectorConfiguration

The configuration details for the third-party cloud environment connection.



8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
# File 'lib/aws-sdk-ssm/types.rb', line 8163

class GetCloudConnectorResult < Struct.new(
  :cloud_connector_arn,
  :display_name,
  :description,
  :role_arn,
  :configuration,
  :config_connector_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the cloud connector was created.

Returns:

  • (Time)


8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
# File 'lib/aws-sdk-ssm/types.rb', line 8163

class GetCloudConnectorResult < Struct.new(
  :cloud_connector_arn,
  :display_name,
  :description,
  :role_arn,
  :configuration,
  :config_connector_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the cloud connector.

Returns:

  • (String)


8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
# File 'lib/aws-sdk-ssm/types.rb', line 8163

class GetCloudConnectorResult < Struct.new(
  :cloud_connector_arn,
  :display_name,
  :description,
  :role_arn,
  :configuration,
  :config_connector_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The friendly name of the cloud connector.

Returns:

  • (String)


8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
# File 'lib/aws-sdk-ssm/types.rb', line 8163

class GetCloudConnectorResult < Struct.new(
  :cloud_connector_arn,
  :display_name,
  :description,
  :role_arn,
  :configuration,
  :config_connector_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role used by the cloud connector.

Returns:

  • (String)


8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
# File 'lib/aws-sdk-ssm/types.rb', line 8163

class GetCloudConnectorResult < Struct.new(
  :cloud_connector_arn,
  :display_name,
  :description,
  :role_arn,
  :configuration,
  :config_connector_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the cloud connector was last updated.

Returns:

  • (Time)


8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
# File 'lib/aws-sdk-ssm/types.rb', line 8163

class GetCloudConnectorResult < Struct.new(
  :cloud_connector_arn,
  :display_name,
  :description,
  :role_arn,
  :configuration,
  :config_connector_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end