Class: Aws::SSM::Types::GetDocumentResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachments_contentArray<Types::AttachmentContent>

A description of the document attachments, including names, locations, sizes, and so on.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#contentString

The contents of the SSM document.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateTime

The date the SSM document was created.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The friendly name of the SSM document. This value can differ for each version of the document. If you want to update this value, see UpdateDocument.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#document_formatString

The document format, either JSON or YAML.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#document_typeString

The document type.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#document_versionString

The document version.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the SSM document.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#requiresArray<Types::DocumentRequires>

A list of SSM documents required by a document. For example, an ApplicationConfiguration document requires an ApplicationConfigurationSchema document.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#review_statusString

The current review status of a new custom Systems Manager document (SSM document) created by a member of your organization, or of the latest version of an existing SSM document.

Only one version of an SSM document can be in the APPROVED state at a time. When a new version is approved, the status of the previous version changes to REJECTED.

Only one version of an SSM document can be in review, or PENDING, at a time.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SSM document, such as Creating, Active, Updating, Failed, and Deleting.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#status_informationString

A message returned by Amazon Web Services Systems Manager that explains the Status value. For example, a Failed status might be explained by the StatusInformation message, “The specified S3 bucket doesn’t exist. Verify that the URL of the S3 bucket is correct.”



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end

#version_nameString

The version of the artifact associated with the document. For example, 12.6. This value is unique across all versions of a document, and can’t be changed.



8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/aws-sdk-ssm/types.rb', line 8294

class GetDocumentResult < Struct.new(
  :name,
  :created_date,
  :display_name,
  :version_name,
  :document_version,
  :status,
  :status_information,
  :content,
  :document_type,
  :document_format,
  :requires,
  :attachments_content,
  :review_status)
  SENSITIVE = []
  include Aws::Structure
end