Class: Aws::SSM::Types::GetInventorySchemaRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetInventorySchemaRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregator ⇒ Boolean
Returns inventory schemas that support aggregation.
-
#max_results ⇒ Integer
The maximum number of items to return for this call.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#sub_type ⇒ Boolean
Returns the sub-type schema for a specified inventory type.
-
#type_name ⇒ String
The type of inventory item to return.
Instance Attribute Details
#aggregator ⇒ Boolean
Returns inventory schemas that support aggregation. For example, this call returns the AWS:InstanceInformation type, because it supports aggregation based on the PlatformName, PlatformType, and PlatformVersion attributes.
8446 8447 8448 8449 8450 8451 8452 8453 8454 |
# File 'lib/aws-sdk-ssm/types.rb', line 8446 class GetInventorySchemaRequest < Struct.new( :type_name, :next_token, :max_results, :aggregator, :sub_type) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
8446 8447 8448 8449 8450 8451 8452 8453 8454 |
# File 'lib/aws-sdk-ssm/types.rb', line 8446 class GetInventorySchemaRequest < Struct.new( :type_name, :next_token, :max_results, :aggregator, :sub_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
8446 8447 8448 8449 8450 8451 8452 8453 8454 |
# File 'lib/aws-sdk-ssm/types.rb', line 8446 class GetInventorySchemaRequest < Struct.new( :type_name, :next_token, :max_results, :aggregator, :sub_type) SENSITIVE = [] include Aws::Structure end |
#sub_type ⇒ Boolean
Returns the sub-type schema for a specified inventory type.
8446 8447 8448 8449 8450 8451 8452 8453 8454 |
# File 'lib/aws-sdk-ssm/types.rb', line 8446 class GetInventorySchemaRequest < Struct.new( :type_name, :next_token, :max_results, :aggregator, :sub_type) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The type of inventory item to return.
8446 8447 8448 8449 8450 8451 8452 8453 8454 |
# File 'lib/aws-sdk-ssm/types.rb', line 8446 class GetInventorySchemaRequest < Struct.new( :type_name, :next_token, :max_results, :aggregator, :sub_type) SENSITIVE = [] include Aws::Structure end |