Class: Aws::SSM::Types::GetParameterHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetParameterHistoryRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return for this call.
-
#name ⇒ String
The name or Amazon Resource Name (ARN) of the parameter for which you want to review history.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#with_decryption ⇒ Boolean
Return decrypted values for secure string parameters.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
9522 9523 9524 9525 9526 9527 9528 9529 |
# File 'lib/aws-sdk-ssm/types.rb', line 9522 class GetParameterHistoryRequest < Struct.new( :name, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name or Amazon Resource Name (ARN) of the parameter for which you want to review history. For parameters shared with you from another account, you must use the full ARN.
9522 9523 9524 9525 9526 9527 9528 9529 |
# File 'lib/aws-sdk-ssm/types.rb', line 9522 class GetParameterHistoryRequest < Struct.new( :name, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
9522 9523 9524 9525 9526 9527 9528 9529 |
# File 'lib/aws-sdk-ssm/types.rb', line 9522 class GetParameterHistoryRequest < Struct.new( :name, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#with_decryption ⇒ Boolean
Return decrypted values for secure string parameters. This flag is
ignored for String and StringList parameter types.
9522 9523 9524 9525 9526 9527 9528 9529 |
# File 'lib/aws-sdk-ssm/types.rb', line 9522 class GetParameterHistoryRequest < Struct.new( :name, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |