Method: Aws::SSM::Types::GetParameterHistoryRequest#name

Defined in:
lib/aws-sdk-ssm/types.rb

#nameString

The name or Amazon Resource Name (ARN) of the parameter for which you want to review history. For parameters shared with you from another account, you must use the full ARN.

Returns:

  • (String)


9182
9183
9184
9185
9186
9187
9188
9189
# File 'lib/aws-sdk-ssm/types.rb', line 9182

class GetParameterHistoryRequest < Struct.new(
  :name,
  :with_decryption,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end