Class: Aws::SSM::Types::GetParametersByPathRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetParametersByPathRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return for this call.
-
#next_token ⇒ String
A token to start the list.
-
#parameter_filters ⇒ Array<Types::ParameterStringFilter>
Filters to limit the request results.
-
#path ⇒ String
The hierarchy for the parameter.
-
#recursive ⇒ Boolean
Retrieve all parameters within a hierarchy.
-
#with_decryption ⇒ Boolean
Retrieve all parameters in a hierarchy with their value decrypted.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 |
# File 'lib/aws-sdk-ssm/types.rb', line 9302 class GetParametersByPathRequest < Struct.new( :path, :recursive, :parameter_filters, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to start the list. Use this token to get the next set of results.
9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 |
# File 'lib/aws-sdk-ssm/types.rb', line 9302 class GetParametersByPathRequest < Struct.new( :path, :recursive, :parameter_filters, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#parameter_filters ⇒ Array<Types::ParameterStringFilter>
Filters to limit the request results.
<note markdown=“1”> The following Key values are supported for GetParametersByPath: Type, KeyId, and Label.
The following `Key` values aren't supported for
GetParametersByPath: tag, DataType, Name, Path, and Tier.
</note>
9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 |
# File 'lib/aws-sdk-ssm/types.rb', line 9302 class GetParametersByPathRequest < Struct.new( :path, :recursive, :parameter_filters, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The hierarchy for the parameter. Hierarchies start with a forward slash (/). The hierarchy is the parameter name except the last part of the parameter. For the API call to succeed, the last part of the parameter name can’t be in the path. A parameter name hierarchy can have a maximum of 15 levels. Here is an example of a hierarchy: ‘/Finance/Prod/IAD/WinServ2016/license33 `
9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 |
# File 'lib/aws-sdk-ssm/types.rb', line 9302 class GetParametersByPathRequest < Struct.new( :path, :recursive, :parameter_filters, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#recursive ⇒ Boolean
Retrieve all parameters within a hierarchy.
If a user has access to a path, then the user can access all levels of that path. For example, if a user has permission to access path /a, then the user can also access /a/b. Even if a user has explicitly been denied access in IAM for parameter /a/b, they can still call the GetParametersByPath API operation recursively for /a and view /a/b.
9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 |
# File 'lib/aws-sdk-ssm/types.rb', line 9302 class GetParametersByPathRequest < Struct.new( :path, :recursive, :parameter_filters, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#with_decryption ⇒ Boolean
Retrieve all parameters in a hierarchy with their value decrypted.
9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 |
# File 'lib/aws-sdk-ssm/types.rb', line 9302 class GetParametersByPathRequest < Struct.new( :path, :recursive, :parameter_filters, :with_decryption, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |