Method: Aws::SSM::Types::GetParametersRequest#names
- Defined in:
- lib/aws-sdk-ssm/types.rb
#names ⇒ Array<String>
The names or Amazon Resource Names (ARNs) of the parameters that you want to query. For parameters shared with you from another account, you must use the full ARNs.
To query by parameter label, use ‘“Name”: “name:label”`. To query by parameter version, use `“Name”: “name:version”`.
<note markdown=“1”> The results for GetParameters requests are listed in alphabetical order in query responses.
</note>
For information about shared parameters, see [Working with shared parameters] in the *Amazon Web Services Systems Manager User Guide*.
[1]: docs.aws.amazon.com/systems-manager/latest/userguide/parameter-store-shared-parameters.html
9361 9362 9363 9364 9365 9366 |
# File 'lib/aws-sdk-ssm/types.rb', line 9361 class GetParametersRequest < Struct.new( :names, :with_decryption) SENSITIVE = [] include Aws::Structure end |