Class: Aws::SSM::Types::GetPatchBaselineForPatchGroupResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetPatchBaselineForPatchGroupResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#baseline_id ⇒ String
The ID of the patch baseline that should be used for the patch group.
-
#operating_system ⇒ String
The operating system rule specified for patch groups using the patch baseline.
-
#patch_group ⇒ String
The name of the patch group.
Instance Attribute Details
#baseline_id ⇒ String
The ID of the patch baseline that should be used for the patch group.
9748 9749 9750 9751 9752 9753 9754 |
# File 'lib/aws-sdk-ssm/types.rb', line 9748 class GetPatchBaselineForPatchGroupResult < Struct.new( :baseline_id, :patch_group, :operating_system) SENSITIVE = [] include Aws::Structure end |
#operating_system ⇒ String
The operating system rule specified for patch groups using the patch baseline.
9748 9749 9750 9751 9752 9753 9754 |
# File 'lib/aws-sdk-ssm/types.rb', line 9748 class GetPatchBaselineForPatchGroupResult < Struct.new( :baseline_id, :patch_group, :operating_system) SENSITIVE = [] include Aws::Structure end |
#patch_group ⇒ String
The name of the patch group.
9748 9749 9750 9751 9752 9753 9754 |
# File 'lib/aws-sdk-ssm/types.rb', line 9748 class GetPatchBaselineForPatchGroupResult < Struct.new( :baseline_id, :patch_group, :operating_system) SENSITIVE = [] include Aws::Structure end |