Class: Aws::SSM::Types::GetPatchBaselineRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#baseline_idString

The ID of the patch baseline to retrieve.

To retrieve information about an Amazon Web Services managed patch baseline, specify the full Amazon Resource Name (ARN) of the baseline. For example, for the baseline AWS-AmazonLinuxDefaultPatchBaseline, specify arn:aws:ssm:us-east-2:733109147000:patchbaseline/pb-0e392de35e7c563b7 instead of pb-0e392de35e7c563b7.

Returns:

  • (String)


9784
9785
9786
9787
9788
# File 'lib/aws-sdk-ssm/types.rb', line 9784

class GetPatchBaselineRequest < Struct.new(
  :baseline_id)
  SENSITIVE = []
  include Aws::Structure
end