Class: Aws::SSM::Types::InstanceAssociationOutputLocation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

An S3 bucket where you want to store the results of this request.

For the minimal permissions required to enable Amazon S3 output for an association, see Create an association (console) in the Systems Manager User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_locationTypes::S3OutputLocation

An S3 bucket where you want to store the results of this request.



10146
10147
10148
10149
10150
# File 'lib/aws-sdk-ssm/types.rb', line 10146

class InstanceAssociationOutputLocation < Struct.new(
  :s3_location)
  SENSITIVE = []
  include Aws::Structure
end