Class: Aws::SSM::Types::InstanceInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InstanceInfo
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Details about a specific managed node.
Constant Summary collapse
- SENSITIVE =
[:ip_address]
Instance Attribute Summary collapse
-
#agent_type ⇒ String
The type of agent installed on the node.
-
#agent_version ⇒ String
The version number of the agent installed on the node.
-
#availability_zone ⇒ String
The Availability Zone where the managed node is located.
-
#availability_zone_id ⇒ String
The Availability Zone ID where the managed node is located.
-
#computer_name ⇒ String
The fully qualified host name of the managed node.
-
#instance_status ⇒ String
The current status of the managed node.
-
#ip_address ⇒ String
The IP address of the managed node.
-
#managed_status ⇒ String
Indicates whether the node is managed by Systems Manager.
-
#name ⇒ String
The name assigned to the managed node.
-
#platform_name ⇒ String
The name of the operating system platform running on your managed node.
-
#platform_type ⇒ String
The operating system platform type of the managed node.
-
#platform_version ⇒ String
The version of the OS platform running on your managed node.
-
#resource_type ⇒ String
The type of instance, either an EC2 instance or another supported machine type in a hybrid fleet.
-
#source_id ⇒ String
The ID of the source resource.
-
#source_location ⇒ String
The location of the source resource in the third-party cloud environment.
-
#source_type ⇒ String
The type of the source resource.
Instance Attribute Details
#agent_type ⇒ String
The type of agent installed on the node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#agent_version ⇒ String
The version number of the agent installed on the node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone where the managed node is located.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#availability_zone_id ⇒ String
The Availability Zone ID where the managed node is located.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#computer_name ⇒ String
The fully qualified host name of the managed node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#instance_status ⇒ String
The current status of the managed node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#ip_address ⇒ String
The IP address of the managed node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#managed_status ⇒ String
Indicates whether the node is managed by Systems Manager.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#name ⇒ String
The name assigned to the managed node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_name ⇒ String
The name of the operating system platform running on your managed node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_type ⇒ String
The operating system platform type of the managed node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_version ⇒ String
The version of the OS platform running on your managed node.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#resource_type ⇒ String
The type of instance, either an EC2 instance or another supported machine type in a hybrid fleet.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#source_id ⇒ String
The ID of the source resource. For IoT Greengrass devices,
SourceId is the Thing name.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#source_location ⇒ String
The location of the source resource in the third-party cloud environment.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |
#source_type ⇒ String
The type of the source resource. For IoT Greengrass devices,
SourceType is AWS::IoT::Thing.
10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-ssm/types.rb', line 10324 class InstanceInfo < Struct.new( :agent_type, :agent_version, :computer_name, :instance_status, :ip_address, :managed_status, :name, :platform_type, :platform_name, :platform_version, :resource_type, :source_type, :source_id, :source_location, :availability_zone, :availability_zone_id) SENSITIVE = [:ip_address] include Aws::Structure end |