Class: Aws::SSM::Types::InstanceInformationStringFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InstanceInformationStringFilter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The filters to describe or get information about your managed nodes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The filter key name to describe your managed nodes.
-
#values ⇒ Array<String>
The filter values.
Instance Attribute Details
#key ⇒ String
The filter key name to describe your managed nodes.
Valid filter key values: ActivationIds | AgentVersion | AssociationStatus | IamRole | InstanceIds | PingStatus | PlatformType | ResourceType | SourceIds | SourceTypes | “tag-key” | “tag:‘keyname`
-
Valid values for the
AssociationStatusfilter key: Success | Pending | Failed -
Valid values for the
PingStatusfilter key: Online | ConnectionLost | Inactive (deprecated) -
Valid values for the
PlatformTypefilter key: Windows | Linux | MacOS -
Valid values for the
ResourceTypefilter key: EC2Instance | ManagedInstance -
Valid values for the
SourceTypefilter key: AWS::EC2::Instance | AWS::SSM::ManagedInstance | AWS::IoT::Thing -
Valid tag examples: ‘Key=tag-key,Values=Purpose` | `Key=tag:Purpose,Values=Test`.
10195 10196 10197 10198 10199 10200 |
# File 'lib/aws-sdk-ssm/types.rb', line 10195 class InstanceInformationStringFilter < Struct.new( :key, :values) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
The filter values.
10195 10196 10197 10198 10199 10200 |
# File 'lib/aws-sdk-ssm/types.rb', line 10195 class InstanceInformationStringFilter < Struct.new( :key, :values) SENSITIVE = [] include Aws::Structure end |