Class: Aws::SSM::Types::InstancePatchStateFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InstancePatchStateFilter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Defines a filter used in DescribeInstancePatchStatesForPatchGroup to scope down the information returned by the API.
Example: To filter for all managed nodes in a patch group having more than three patches with a FailedCount status, use the following for the filter:
-
Value for
Key:FailedCount -
Value for
Type:GreaterThan -
Value for
Values:3
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The key for the filter.
-
#type ⇒ String
The type of comparison that should be performed for the value.
-
#values ⇒ Array<String>
The value for the filter.
Instance Attribute Details
#key ⇒ String
The key for the filter. Supported values include the following:
-
InstalledCount -
InstalledOtherCount -
InstalledPendingRebootCount -
InstalledRejectedCount -
MissingCount -
FailedCount -
UnreportedNotApplicableCount -
NotApplicableCount
10379 10380 10381 10382 10383 10384 10385 |
# File 'lib/aws-sdk-ssm/types.rb', line 10379 class InstancePatchStateFilter < Struct.new( :key, :values, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of comparison that should be performed for the value.
10379 10380 10381 10382 10383 10384 10385 |
# File 'lib/aws-sdk-ssm/types.rb', line 10379 class InstancePatchStateFilter < Struct.new( :key, :values, :type) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
The value for the filter. Must be an integer greater than or equal to 0.
10379 10380 10381 10382 10383 10384 10385 |
# File 'lib/aws-sdk-ssm/types.rb', line 10379 class InstancePatchStateFilter < Struct.new( :key, :values, :type) SENSITIVE = [] include Aws::Structure end |