Class: Aws::SSM::Types::InstanceProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InstanceProperty
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
An object containing various properties of a managed node.
Constant Summary collapse
- SENSITIVE =
[:ip_address]
Instance Attribute Summary collapse
-
#activation_id ⇒ String
The activation ID created by Systems Manager when the server or virtual machine (VM) was registered.
-
#agent_version ⇒ String
The version of SSM Agent running on your managed node.
-
#architecture ⇒ String
The CPU architecture of the node.
-
#association_overview ⇒ Types::InstanceAggregatedAssociationOverview
Status information about the aggregated associations.
-
#association_status ⇒ String
The status of the State Manager association applied to the managed node.
-
#availability_zone ⇒ String
The Availability Zone where the managed node is located.
-
#computer_name ⇒ String
The fully qualified host name of the managed node.
-
#iam_role ⇒ String
The IAM role used in the hybrid activation to register the node with Systems Manager.
-
#instance_id ⇒ String
The ID of the managed node.
-
#instance_role ⇒ String
The instance profile attached to the node.
-
#instance_state ⇒ String
The current state of the node.
-
#instance_type ⇒ String
The instance type of the managed node.
-
#ip_address ⇒ String
The public IPv4 address assigned to the node.
-
#key_name ⇒ String
The name of the key pair associated with the node.
-
#last_association_execution_date ⇒ Time
The date the association was last run.
-
#last_ping_date_time ⇒ Time
The date and time when the SSM Agent last pinged the Systems Manager service.
-
#last_successful_association_execution_date ⇒ Time
The last date the association was successfully run.
-
#launch_time ⇒ Time
The timestamp for when the node was launched.
-
#name ⇒ String
The value of the EC2
Nametag associated with the node. -
#ping_status ⇒ String
Connection status of the SSM Agent on the managed node.
-
#platform_name ⇒ String
The name of the operating system platform running on your managed node.
-
#platform_type ⇒ String
The operating system platform type of the managed node.
-
#platform_version ⇒ String
The version of the OS platform running on your managed node.
-
#registration_date ⇒ Time
The date the node was registered with Systems Manager.
-
#resource_type ⇒ String
The type of managed node.
-
#source_id ⇒ String
The ID of the source resource.
-
#source_location ⇒ String
The location of the source resource in the third-party cloud environment.
-
#source_type ⇒ String
The type of the source resource.
Instance Attribute Details
#activation_id ⇒ String
The activation ID created by Systems Manager when the server or virtual machine (VM) was registered
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#agent_version ⇒ String
The version of SSM Agent running on your managed node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#architecture ⇒ String
The CPU architecture of the node. For example, x86_64.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#association_overview ⇒ Types::InstanceAggregatedAssociationOverview
Status information about the aggregated associations.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#association_status ⇒ String
The status of the State Manager association applied to the managed node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone where the managed node is located.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#computer_name ⇒ String
The fully qualified host name of the managed node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#iam_role ⇒ String
The IAM role used in the hybrid activation to register the node with Systems Manager.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#instance_id ⇒ String
The ID of the managed node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#instance_role ⇒ String
The instance profile attached to the node. If an instance profile isn't attached to the node, this value is blank.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#instance_state ⇒ String
The current state of the node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#instance_type ⇒ String
The instance type of the managed node. For example, t3.large.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#ip_address ⇒ String
The public IPv4 address assigned to the node. If a public IPv4 address isn't assigned to the node, this value is blank.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#key_name ⇒ String
The name of the key pair associated with the node. If a key pair isnt't associated with the node, this value is blank.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#last_association_execution_date ⇒ Time
The date the association was last run.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#last_ping_date_time ⇒ Time
The date and time when the SSM Agent last pinged the Systems Manager service.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#last_successful_association_execution_date ⇒ Time
The last date the association was successfully run.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#launch_time ⇒ Time
The timestamp for when the node was launched.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#name ⇒ String
The value of the EC2 Name tag associated with the node. If a
Name tag hasn't been applied to the node, this value is blank.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#ping_status ⇒ String
Connection status of the SSM Agent on the managed node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_name ⇒ String
The name of the operating system platform running on your managed node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_type ⇒ String
The operating system platform type of the managed node. For example, Windows Server or Amazon Linux 2.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_version ⇒ String
The version of the OS platform running on your managed node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#registration_date ⇒ Time
The date the node was registered with Systems Manager.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#resource_type ⇒ String
The type of managed node.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#source_id ⇒ String
The ID of the source resource.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#source_location ⇒ String
The location of the source resource in the third-party cloud environment.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |
#source_type ⇒ String
The type of the source resource. Valid values: AWS::EC2::Instance
| AWS::SSM::ManagedInstance | AWS::IoT::Thing |
Microsoft.Compute/virtualMachines.
10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 |
# File 'lib/aws-sdk-ssm/types.rb', line 10950 class InstanceProperty < Struct.new( :name, :instance_id, :instance_type, :instance_role, :key_name, :instance_state, :architecture, :ip_address, :launch_time, :ping_status, :last_ping_date_time, :agent_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type, :source_location, :availability_zone) SENSITIVE = [:ip_address] include Aws::Structure end |