Class: Aws::SSM::Types::InvalidAutomationExecutionParametersException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

The supplied parameters for invoking the specified Automation runbook are incorrect. For example, they may not match the set of parameters permitted for the specified Automation document.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


10754
10755
10756
10757
10758
# File 'lib/aws-sdk-ssm/types.rb', line 10754

class InvalidAutomationExecutionParametersException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end