Class: Aws::SSM::Types::InvalidRole

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

The role name can't contain invalid characters. Also verify that you specified an IAM role for notifications that includes the required trust policy. For information about configuring the IAM role for Run Command notifications, see Monitoring Systems Manager status changes using Amazon SNS notifications in the Amazon Web Services Systems Manager User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


11615
11616
11617
11618
11619
# File 'lib/aws-sdk-ssm/types.rb', line 11615

class InvalidRole < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end