Class: Aws::SSM::Types::InventoryDeletionStatusItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InventoryDeletionStatusItem
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Status information returned by the DeleteInventory operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deletion_id ⇒ String
The deletion ID returned by the
DeleteInventoryoperation. -
#deletion_start_time ⇒ Time
The UTC timestamp when the delete operation started.
-
#deletion_summary ⇒ Types::InventoryDeletionSummary
Information about the delete operation.
-
#last_status ⇒ String
The status of the operation.
-
#last_status_message ⇒ String
Information about the status.
-
#last_status_update_time ⇒ Time
The UTC timestamp of when the last status report.
-
#type_name ⇒ String
The name of the inventory data type.
Instance Attribute Details
#deletion_id ⇒ String
The deletion ID returned by the DeleteInventory operation.
11782 11783 11784 11785 11786 11787 11788 11789 11790 11791 11792 |
# File 'lib/aws-sdk-ssm/types.rb', line 11782 class InventoryDeletionStatusItem < Struct.new( :deletion_id, :type_name, :deletion_start_time, :last_status, :last_status_message, :deletion_summary, :last_status_update_time) SENSITIVE = [] include Aws::Structure end |
#deletion_start_time ⇒ Time
The UTC timestamp when the delete operation started.
11782 11783 11784 11785 11786 11787 11788 11789 11790 11791 11792 |
# File 'lib/aws-sdk-ssm/types.rb', line 11782 class InventoryDeletionStatusItem < Struct.new( :deletion_id, :type_name, :deletion_start_time, :last_status, :last_status_message, :deletion_summary, :last_status_update_time) SENSITIVE = [] include Aws::Structure end |
#deletion_summary ⇒ Types::InventoryDeletionSummary
Information about the delete operation. For more information about this summary, see Understanding the delete inventory summary in the Amazon Web Services Systems Manager User Guide.
11782 11783 11784 11785 11786 11787 11788 11789 11790 11791 11792 |
# File 'lib/aws-sdk-ssm/types.rb', line 11782 class InventoryDeletionStatusItem < Struct.new( :deletion_id, :type_name, :deletion_start_time, :last_status, :last_status_message, :deletion_summary, :last_status_update_time) SENSITIVE = [] include Aws::Structure end |
#last_status ⇒ String
The status of the operation. Possible values are InProgress and Complete.
11782 11783 11784 11785 11786 11787 11788 11789 11790 11791 11792 |
# File 'lib/aws-sdk-ssm/types.rb', line 11782 class InventoryDeletionStatusItem < Struct.new( :deletion_id, :type_name, :deletion_start_time, :last_status, :last_status_message, :deletion_summary, :last_status_update_time) SENSITIVE = [] include Aws::Structure end |
#last_status_message ⇒ String
Information about the status.
11782 11783 11784 11785 11786 11787 11788 11789 11790 11791 11792 |
# File 'lib/aws-sdk-ssm/types.rb', line 11782 class InventoryDeletionStatusItem < Struct.new( :deletion_id, :type_name, :deletion_start_time, :last_status, :last_status_message, :deletion_summary, :last_status_update_time) SENSITIVE = [] include Aws::Structure end |
#last_status_update_time ⇒ Time
The UTC timestamp of when the last status report.
11782 11783 11784 11785 11786 11787 11788 11789 11790 11791 11792 |
# File 'lib/aws-sdk-ssm/types.rb', line 11782 class InventoryDeletionStatusItem < Struct.new( :deletion_id, :type_name, :deletion_start_time, :last_status, :last_status_message, :deletion_summary, :last_status_update_time) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the inventory data type.
11782 11783 11784 11785 11786 11787 11788 11789 11790 11791 11792 |
# File 'lib/aws-sdk-ssm/types.rb', line 11782 class InventoryDeletionStatusItem < Struct.new( :deletion_id, :type_name, :deletion_start_time, :last_status, :last_status_message, :deletion_summary, :last_status_update_time) SENSITIVE = [] include Aws::Structure end |