Class: Aws::SSM::Types::InventoryItemSchema

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

The inventory item schema definition. Users can use this to compose inventory query filters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesArray<Types::InventoryItemAttribute>

The schema attributes for inventory. This contains data type and attribute name.

Returns:



11638
11639
11640
11641
11642
11643
11644
11645
# File 'lib/aws-sdk-ssm/types.rb', line 11638

class InventoryItemSchema < Struct.new(
  :type_name,
  :version,
  :attributes,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The alias name of the inventory type. The alias name is used for display purposes.

Returns:

  • (String)


11638
11639
11640
11641
11642
11643
11644
11645
# File 'lib/aws-sdk-ssm/types.rb', line 11638

class InventoryItemSchema < Struct.new(
  :type_name,
  :version,
  :attributes,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the inventory type. Default inventory item type names start with Amazon Web Services. Custom inventory type names will start with Custom. Default inventory item types include the following: AWS:AWSComponent, AWS:Application, AWS:InstanceInformation, AWS:Network, and AWS:WindowsUpdate.

Returns:

  • (String)


11638
11639
11640
11641
11642
11643
11644
11645
# File 'lib/aws-sdk-ssm/types.rb', line 11638

class InventoryItemSchema < Struct.new(
  :type_name,
  :version,
  :attributes,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The schema version for the inventory item.

Returns:

  • (String)


11638
11639
11640
11641
11642
11643
11644
11645
# File 'lib/aws-sdk-ssm/types.rb', line 11638

class InventoryItemSchema < Struct.new(
  :type_name,
  :version,
  :attributes,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end