Class: Aws::SSM::Types::InventoryResultEntity

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Inventory query results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dataHash<String,Types::InventoryResultItem>

The data section in the inventory result entity JSON.

Returns:



11661
11662
11663
11664
11665
11666
# File 'lib/aws-sdk-ssm/types.rb', line 11661

class InventoryResultEntity < Struct.new(
  :id,
  :data)
  SENSITIVE = []
  include Aws::Structure
end

#idString

ID of the inventory result entity. For example, for managed node inventory the result will be the managed node ID. For EC2 instance inventory, the result will be the instance ID.

Returns:

  • (String)


11661
11662
11663
11664
11665
11666
# File 'lib/aws-sdk-ssm/types.rb', line 11661

class InventoryResultEntity < Struct.new(
  :id,
  :data)
  SENSITIVE = []
  include Aws::Structure
end