Class: Aws::SSM::Types::InventoryResultItem

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

The inventory result item.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capture_timeString

The time inventory item data was captured.

Returns:

  • (String)


11696
11697
11698
11699
11700
11701
11702
11703
11704
# File 'lib/aws-sdk-ssm/types.rb', line 11696

class InventoryResultItem < Struct.new(
  :type_name,
  :schema_version,
  :capture_time,
  :content_hash,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#contentArray<Hash<String,String>>

Contains all the inventory data of the item type. Results include attribute names and values.

Returns:

  • (Array<Hash<String,String>>)


11696
11697
11698
11699
11700
11701
11702
11703
11704
# File 'lib/aws-sdk-ssm/types.rb', line 11696

class InventoryResultItem < Struct.new(
  :type_name,
  :schema_version,
  :capture_time,
  :content_hash,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#content_hashString

MD5 hash of the inventory item type contents. The content hash is used to determine whether to update inventory information. The PutInventory API doesn’t update the inventory item type contents if the MD5 hash hasn’t changed since last update.

Returns:

  • (String)


11696
11697
11698
11699
11700
11701
11702
11703
11704
# File 'lib/aws-sdk-ssm/types.rb', line 11696

class InventoryResultItem < Struct.new(
  :type_name,
  :schema_version,
  :capture_time,
  :content_hash,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#schema_versionString

The schema version for the inventory result item/

Returns:

  • (String)


11696
11697
11698
11699
11700
11701
11702
11703
11704
# File 'lib/aws-sdk-ssm/types.rb', line 11696

class InventoryResultItem < Struct.new(
  :type_name,
  :schema_version,
  :capture_time,
  :content_hash,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the inventory result item type.

Returns:

  • (String)


11696
11697
11698
11699
11700
11701
11702
11703
11704
# File 'lib/aws-sdk-ssm/types.rb', line 11696

class InventoryResultItem < Struct.new(
  :type_name,
  :schema_version,
  :capture_time,
  :content_hash,
  :content)
  SENSITIVE = []
  include Aws::Structure
end