Class: Aws::SSM::Types::LabelParameterVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#labelsArray<String>

One or more labels to attach to the specified parameter version.

Returns:

  • (Array<String>)


12163
12164
12165
12166
12167
12168
12169
# File 'lib/aws-sdk-ssm/types.rb', line 12163

class LabelParameterVersionRequest < Struct.new(
  :name,
  :parameter_version,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The parameter name on which you want to attach one or more labels.

You can't enter the Amazon Resource Name (ARN) for a parameter, only the parameter name itself.

Returns:

  • (String)


12163
12164
12165
12166
12167
12168
12169
# File 'lib/aws-sdk-ssm/types.rb', line 12163

class LabelParameterVersionRequest < Struct.new(
  :name,
  :parameter_version,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_versionInteger

The specific version of the parameter on which you want to attach one or more labels. If no version is specified, the system attaches the label to the latest version.

Returns:

  • (Integer)


12163
12164
12165
12166
12167
12168
12169
# File 'lib/aws-sdk-ssm/types.rb', line 12163

class LabelParameterVersionRequest < Struct.new(
  :name,
  :parameter_version,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end