Class: Aws::SSM::Types::LabelParameterVersionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::LabelParameterVersionResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invalid_labels ⇒ Array<String>
The label doesn't meet the requirements.
-
#parameter_version ⇒ Integer
The version of the parameter that has been labeled.
Instance Attribute Details
#invalid_labels ⇒ Array<String>
The label doesn't meet the requirements. For information about parameter label requirements, see Working with parameter labels in the Amazon Web Services Systems Manager User Guide.
12187 12188 12189 12190 12191 12192 |
# File 'lib/aws-sdk-ssm/types.rb', line 12187 class LabelParameterVersionResult < Struct.new( :invalid_labels, :parameter_version) SENSITIVE = [] include Aws::Structure end |
#parameter_version ⇒ Integer
The version of the parameter that has been labeled.
12187 12188 12189 12190 12191 12192 |
# File 'lib/aws-sdk-ssm/types.rb', line 12187 class LabelParameterVersionResult < Struct.new( :invalid_labels, :parameter_version) SENSITIVE = [] include Aws::Structure end |