Class: Aws::SSM::Types::ListAssociationVersionsResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_versionsArray<Types::AssociationVersionInfo>

Information about all versions of the association for the specified association ID.



11771
11772
11773
11774
11775
11776
# File 'lib/aws-sdk-ssm/types.rb', line 11771

class ListAssociationVersionsResult < Struct.new(
  :association_versions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. Use this token to get the next set of results.



11771
11772
11773
11774
11775
11776
# File 'lib/aws-sdk-ssm/types.rb', line 11771

class ListAssociationVersionsResult < Struct.new(
  :association_versions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end