Class: Aws::SSM::Types::ListComplianceSummariesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ListComplianceSummariesResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compliance_summary_items ⇒ Array<Types::ComplianceSummaryItem>
A list of compliant and non-compliant summary counts based on compliance types.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#compliance_summary_items ⇒ Array<Types::ComplianceSummaryItem>
A list of compliant and non-compliant summary counts based on compliance types. For example, this call returns State Manager associations, patches, or custom compliance types according to the filter criteria that you specified.
12547 12548 12549 12550 12551 12552 |
# File 'lib/aws-sdk-ssm/types.rb', line 12547 class ListComplianceSummariesResult < Struct.new( :compliance_summary_items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. Use this token to get the next set of results.
12547 12548 12549 12550 12551 12552 |
# File 'lib/aws-sdk-ssm/types.rb', line 12547 class ListComplianceSummariesResult < Struct.new( :compliance_summary_items, :next_token) SENSITIVE = [] include Aws::Structure end |