Class: Aws::SSM::Types::ListNodesResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.

Returns:



12856
12857
12858
12859
12860
12861
# File 'lib/aws-sdk-ssm/types.rb', line 12856

class ListNodesResult < Struct.new(
  :nodes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#nodesArray<Types::Node>

A list of managed nodes that match the specified filter criteria.

Returns:



12856
12857
12858
12859
12860
12861
# File 'lib/aws-sdk-ssm/types.rb', line 12856

class ListNodesResult < Struct.new(
  :nodes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end