Class: Aws::SSM::Types::ListResourceDataSyncRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

Returns:

  • (Integer)


13135
13136
13137
13138
13139
13140
13141
# File 'lib/aws-sdk-ssm/types.rb', line 13135

class ListResourceDataSyncRequest < Struct.new(
  :sync_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to start the list. Use this token to get the next set of results.

Returns:

  • (String)


13135
13136
13137
13138
13139
13140
13141
# File 'lib/aws-sdk-ssm/types.rb', line 13135

class ListResourceDataSyncRequest < Struct.new(
  :sync_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sync_typeString

View a list of resource data syncs according to the sync type. Specify SyncToDestination to view resource data syncs that synchronize data to an Amazon S3 bucket. Specify SyncFromSource to view resource data syncs from Organizations or from multiple Amazon Web Services Regions.

Returns:

  • (String)


13135
13136
13137
13138
13139
13140
13141
# File 'lib/aws-sdk-ssm/types.rb', line 13135

class ListResourceDataSyncRequest < Struct.new(
  :sync_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end