Class: Aws::SSM::Types::LoggingInfo

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Information about an Amazon Simple Storage Service (Amazon S3) bucket to write managed node-level logs to.

LoggingInfo has been deprecated. To specify an Amazon Simple Storage Service (Amazon S3) bucket to contain logs, instead use the OutputS3BucketName and OutputS3KeyPrefix options in the TaskInvocationParameters structure. For information about how Amazon Web Services Systems Manager handles these options for the supported maintenance window task types, see MaintenanceWindowTaskInvocationParameters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_bucket_nameString

The name of an S3 bucket where execution logs are stored.

Returns:

  • (String)


13205
13206
13207
13208
13209
13210
13211
# File 'lib/aws-sdk-ssm/types.rb', line 13205

class LoggingInfo < Struct.new(
  :s3_bucket_name,
  :s3_key_prefix,
  :s3_region)
  SENSITIVE = []
  include Aws::Structure
end

#s3_key_prefixString

(Optional) The S3 bucket subfolder.

Returns:

  • (String)


13205
13206
13207
13208
13209
13210
13211
# File 'lib/aws-sdk-ssm/types.rb', line 13205

class LoggingInfo < Struct.new(
  :s3_bucket_name,
  :s3_key_prefix,
  :s3_region)
  SENSITIVE = []
  include Aws::Structure
end

#s3_regionString

The Amazon Web Services Region where the S3 bucket is located.

Returns:

  • (String)


13205
13206
13207
13208
13209
13210
13211
# File 'lib/aws-sdk-ssm/types.rb', line 13205

class LoggingInfo < Struct.new(
  :s3_bucket_name,
  :s3_key_prefix,
  :s3_region)
  SENSITIVE = []
  include Aws::Structure
end