Class: Aws::SSM::Types::MaintenanceWindowIdentity
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::MaintenanceWindowIdentity
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about the maintenance window.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#cutoff ⇒ Integer
The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.
-
#description ⇒ String
A description of the maintenance window.
-
#duration ⇒ Integer
The duration of the maintenance window in hours.
-
#enabled ⇒ Boolean
Indicates whether the maintenance window is enabled.
-
#end_date ⇒ String
The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become inactive.
-
#name ⇒ String
The name of the maintenance window.
-
#next_execution_time ⇒ String
The next time the maintenance window will actually run, taking into account any specified times for the maintenance window to become active or inactive.
-
#schedule ⇒ String
The schedule of the maintenance window in the form of a cron or rate expression.
-
#schedule_offset ⇒ Integer
The number of days to wait to run a maintenance window after the scheduled cron expression date and time.
-
#schedule_timezone ⇒ String
The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format.
-
#start_date ⇒ String
The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become active.
-
#window_id ⇒ String
The ID of the maintenance window.
Instance Attribute Details
#cutoff ⇒ Integer
The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A description of the maintenance window.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#duration ⇒ Integer
The duration of the maintenance window in hours.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#enabled ⇒ Boolean
Indicates whether the maintenance window is enabled.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#end_date ⇒ String
The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become inactive.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the maintenance window.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#next_execution_time ⇒ String
The next time the maintenance window will actually run, taking into account any specified times for the maintenance window to become active or inactive.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#schedule ⇒ String
The schedule of the maintenance window in the form of a cron or rate expression.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#schedule_offset ⇒ Integer
The number of days to wait to run a maintenance window after the scheduled cron expression date and time.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#schedule_timezone ⇒ String
The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#start_date ⇒ String
The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become active.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |
#window_id ⇒ String
The ID of the maintenance window.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 |
# File 'lib/aws-sdk-ssm/types.rb', line 13532 class MaintenanceWindowIdentity < Struct.new( :window_id, :name, :description, :enabled, :duration, :cutoff, :schedule, :schedule_timezone, :schedule_offset, :end_date, :start_date, :next_execution_time) SENSITIVE = [:description] include Aws::Structure end |