Class: Aws::SSM::Types::MaintenanceWindowTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::MaintenanceWindowTarget
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The target registered with the maintenance window.
Constant Summary collapse
- SENSITIVE =
[:owner_information, :description]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the target.
-
#name ⇒ String
The name for the maintenance window target.
-
#owner_information ⇒ String
A user-provided value that will be included in any Amazon CloudWatch Events events that are raised while running tasks for these targets in this maintenance window.
-
#resource_type ⇒ String
The type of target that is being registered with the maintenance window.
-
#targets ⇒ Array<Types::Target>
The targets, either managed nodes or tags.
-
#window_id ⇒ String
The ID of the maintenance window to register the target with.
-
#window_target_id ⇒ String
The ID of the target.
Instance Attribute Details
#description ⇒ String
A description for the target.
13823 13824 13825 13826 13827 13828 13829 13830 13831 13832 13833 |
# File 'lib/aws-sdk-ssm/types.rb', line 13823 class MaintenanceWindowTarget < Struct.new( :window_id, :window_target_id, :resource_type, :targets, :owner_information, :name, :description) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#name ⇒ String
The name for the maintenance window target.
13823 13824 13825 13826 13827 13828 13829 13830 13831 13832 13833 |
# File 'lib/aws-sdk-ssm/types.rb', line 13823 class MaintenanceWindowTarget < Struct.new( :window_id, :window_target_id, :resource_type, :targets, :owner_information, :name, :description) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#owner_information ⇒ String
A user-provided value that will be included in any Amazon CloudWatch Events events that are raised while running tasks for these targets in this maintenance window.
13823 13824 13825 13826 13827 13828 13829 13830 13831 13832 13833 |
# File 'lib/aws-sdk-ssm/types.rb', line 13823 class MaintenanceWindowTarget < Struct.new( :window_id, :window_target_id, :resource_type, :targets, :owner_information, :name, :description) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#resource_type ⇒ String
The type of target that is being registered with the maintenance window.
13823 13824 13825 13826 13827 13828 13829 13830 13831 13832 13833 |
# File 'lib/aws-sdk-ssm/types.rb', line 13823 class MaintenanceWindowTarget < Struct.new( :window_id, :window_target_id, :resource_type, :targets, :owner_information, :name, :description) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#targets ⇒ Array<Types::Target>
The targets, either managed nodes or tags.
Specify managed nodes using the following format:
Key=instanceids,Values=<instanceid1>,<instanceid2>
Tags are specified using the following format:
Key=<tag name>,Values=<tag value>.
13823 13824 13825 13826 13827 13828 13829 13830 13831 13832 13833 |
# File 'lib/aws-sdk-ssm/types.rb', line 13823 class MaintenanceWindowTarget < Struct.new( :window_id, :window_target_id, :resource_type, :targets, :owner_information, :name, :description) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#window_id ⇒ String
The ID of the maintenance window to register the target with.
13823 13824 13825 13826 13827 13828 13829 13830 13831 13832 13833 |
# File 'lib/aws-sdk-ssm/types.rb', line 13823 class MaintenanceWindowTarget < Struct.new( :window_id, :window_target_id, :resource_type, :targets, :owner_information, :name, :description) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#window_target_id ⇒ String
The ID of the target.
13823 13824 13825 13826 13827 13828 13829 13830 13831 13832 13833 |
# File 'lib/aws-sdk-ssm/types.rb', line 13823 class MaintenanceWindowTarget < Struct.new( :window_id, :window_target_id, :resource_type, :targets, :owner_information, :name, :description) SENSITIVE = [:owner_information, :description] include Aws::Structure end |