Class: Aws::SSM::Types::ModifyDocumentPermissionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_ids_to_addArray<String>

The Amazon Web Services users that should have access to the document. The account IDs can either be a group of account IDs or All.



12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-ssm/types.rb', line 12993

class ModifyDocumentPermissionRequest < Struct.new(
  :name,
  :permission_type,
  :account_ids_to_add,
  :account_ids_to_remove,
  :shared_document_version)
  SENSITIVE = []
  include Aws::Structure
end

#account_ids_to_removeArray<String>

The Amazon Web Services users that should no longer have access to the document. The Amazon Web Services user can either be a group of account IDs or All. This action has a higher priority than AccountIdsToAdd. If you specify an ID to add and the same ID to remove, the system removes access to the document.



12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-ssm/types.rb', line 12993

class ModifyDocumentPermissionRequest < Struct.new(
  :name,
  :permission_type,
  :account_ids_to_add,
  :account_ids_to_remove,
  :shared_document_version)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the document that you want to share.



12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-ssm/types.rb', line 12993

class ModifyDocumentPermissionRequest < Struct.new(
  :name,
  :permission_type,
  :account_ids_to_add,
  :account_ids_to_remove,
  :shared_document_version)
  SENSITIVE = []
  include Aws::Structure
end

#permission_typeString

The permission type for the document. The permission type can be Share.



12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-ssm/types.rb', line 12993

class ModifyDocumentPermissionRequest < Struct.new(
  :name,
  :permission_type,
  :account_ids_to_add,
  :account_ids_to_remove,
  :shared_document_version)
  SENSITIVE = []
  include Aws::Structure
end

#shared_document_versionString

(Optional) The version of the document to share. If it isn’t specified, the system choose the Default version to share.



12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-ssm/types.rb', line 12993

class ModifyDocumentPermissionRequest < Struct.new(
  :name,
  :permission_type,
  :account_ids_to_add,
  :account_ids_to_remove,
  :shared_document_version)
  SENSITIVE = []
  include Aws::Structure
end