Class: Aws::SSM::Types::Node

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Details about an individual managed node.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capture_timeTime

The UTC timestamp for when the managed node data was last captured.

Returns:

  • (Time)


14184
14185
14186
14187
14188
14189
14190
14191
14192
# File 'lib/aws-sdk-ssm/types.rb', line 14184

class Node < Struct.new(
  :capture_time,
  :id,
  :owner,
  :region,
  :node_type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the managed node.

Returns:

  • (String)


14184
14185
14186
14187
14188
14189
14190
14191
14192
# File 'lib/aws-sdk-ssm/types.rb', line 14184

class Node < Struct.new(
  :capture_time,
  :id,
  :owner,
  :region,
  :node_type)
  SENSITIVE = []
  include Aws::Structure
end

#node_typeTypes::NodeType

Information about the type of node.

Returns:



14184
14185
14186
14187
14188
14189
14190
14191
14192
# File 'lib/aws-sdk-ssm/types.rb', line 14184

class Node < Struct.new(
  :capture_time,
  :id,
  :owner,
  :region,
  :node_type)
  SENSITIVE = []
  include Aws::Structure
end

#ownerTypes::NodeOwnerInfo

Information about the ownership of the managed node.



14184
14185
14186
14187
14188
14189
14190
14191
14192
# File 'lib/aws-sdk-ssm/types.rb', line 14184

class Node < Struct.new(
  :capture_time,
  :id,
  :owner,
  :region,
  :node_type)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region that a managed node was created in or assigned to.

Returns:

  • (String)


14184
14185
14186
14187
14188
14189
14190
14191
14192
# File 'lib/aws-sdk-ssm/types.rb', line 14184

class Node < Struct.new(
  :capture_time,
  :id,
  :owner,
  :region,
  :node_type)
  SENSITIVE = []
  include Aws::Structure
end