Class: Aws::SSM::Types::NodeType
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::NodeType
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Note:
NodeType is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of NodeType corresponding to the set member.
Information about a managed node's type.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance ⇒ Types::InstanceInfo
Information about a specific managed node.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#instance ⇒ Types::InstanceInfo
Information about a specific managed node.
14291 14292 14293 14294 14295 14296 14297 14298 14299 14300 |
# File 'lib/aws-sdk-ssm/types.rb', line 14291 class NodeType < Struct.new( :instance, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Instance < NodeType; end class Unknown < NodeType; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
14291 14292 14293 |
# File 'lib/aws-sdk-ssm/types.rb', line 14291 def unknown @unknown end |