Class: Aws::SSM::Types::NotificationConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Configurations for sending notifications.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#notification_arnString

An Amazon Resource Name (ARN) for an Amazon Simple Notification Service (Amazon SNS) topic. Run Command pushes notifications about command status changes to this topic.



13913
13914
13915
13916
13917
13918
13919
# File 'lib/aws-sdk-ssm/types.rb', line 13913

class NotificationConfig < Struct.new(
  :notification_arn,
  :notification_events,
  :notification_type)
  SENSITIVE = []
  include Aws::Structure
end

#notification_eventsArray<String>

The different events for which you can receive notifications. To learn more about these events, see [Monitoring Systems Manager status changes using Amazon SNS notifications] in the *Amazon Web Services Systems Manager User Guide*.

[1]: docs.aws.amazon.com/systems-manager/latest/userguide/monitoring-sns-notifications.html



13913
13914
13915
13916
13917
13918
13919
# File 'lib/aws-sdk-ssm/types.rb', line 13913

class NotificationConfig < Struct.new(
  :notification_arn,
  :notification_events,
  :notification_type)
  SENSITIVE = []
  include Aws::Structure
end

#notification_typeString

The type of notification.

  • Command: Receive notification when the status of a command changes.

  • Invocation: For commands sent to multiple managed nodes, receive notification on a per-node basis when the status of a command changes.



13913
13914
13915
13916
13917
13918
13919
# File 'lib/aws-sdk-ssm/types.rb', line 13913

class NotificationConfig < Struct.new(
  :notification_arn,
  :notification_events,
  :notification_type)
  SENSITIVE = []
  include Aws::Structure
end