Class: Aws::SSM::Types::OpsAggregator
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::OpsAggregator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
One or more aggregators for viewing counts of OpsData using different
dimensions such as Source, CreatedTime, or Source and CreatedTime, to name a few.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregator_type ⇒ String
Either a
RangeorCountaggregator for limiting an OpsData summary. -
#aggregators ⇒ Array<Types::OpsAggregator>
A nested aggregator for viewing counts of OpsData.
-
#attribute_name ⇒ String
The name of an OpsData attribute on which to limit the count of OpsData.
-
#filters ⇒ Array<Types::OpsFilter>
The aggregator filters.
-
#type_name ⇒ String
The data type name to use for viewing counts of OpsData.
-
#values ⇒ Hash<String,String>
The aggregator value.
Instance Attribute Details
#aggregator_type ⇒ String
Either a Range or Count aggregator for limiting an OpsData
summary.
14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 |
# File 'lib/aws-sdk-ssm/types.rb', line 14394 class OpsAggregator < Struct.new( :aggregator_type, :type_name, :attribute_name, :values, :filters, :aggregators) SENSITIVE = [] include Aws::Structure end |
#aggregators ⇒ Array<Types::OpsAggregator>
A nested aggregator for viewing counts of OpsData.
14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 |
# File 'lib/aws-sdk-ssm/types.rb', line 14394 class OpsAggregator < Struct.new( :aggregator_type, :type_name, :attribute_name, :values, :filters, :aggregators) SENSITIVE = [] include Aws::Structure end |
#attribute_name ⇒ String
The name of an OpsData attribute on which to limit the count of OpsData.
14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 |
# File 'lib/aws-sdk-ssm/types.rb', line 14394 class OpsAggregator < Struct.new( :aggregator_type, :type_name, :attribute_name, :values, :filters, :aggregators) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::OpsFilter>
The aggregator filters.
14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 |
# File 'lib/aws-sdk-ssm/types.rb', line 14394 class OpsAggregator < Struct.new( :aggregator_type, :type_name, :attribute_name, :values, :filters, :aggregators) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The data type name to use for viewing counts of OpsData.
14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 |
# File 'lib/aws-sdk-ssm/types.rb', line 14394 class OpsAggregator < Struct.new( :aggregator_type, :type_name, :attribute_name, :values, :filters, :aggregators) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Hash<String,String>
The aggregator value.
14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 |
# File 'lib/aws-sdk-ssm/types.rb', line 14394 class OpsAggregator < Struct.new( :aggregator_type, :type_name, :attribute_name, :values, :filters, :aggregators) SENSITIVE = [] include Aws::Structure end |