Class: Aws::SSM::Types::Parameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::Parameter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
An Amazon Web Services Systems Manager parameter in Parameter Store.
Constant Summary collapse
- SENSITIVE =
[:value]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the parameter.
-
#data_type ⇒ String
The data type of the parameter, such as
textoraws:ec2:image. -
#last_modified_date ⇒ Time
Date the parameter was last changed or updated and the parameter version was created.
-
#name ⇒ String
The name of the parameter.
-
#selector ⇒ String
Either the version number or the label used to retrieve the parameter value.
-
#source_result ⇒ String
Applies to parameters that reference information in other Amazon Web Services services.
-
#type ⇒ String
The type of parameter.
-
#value ⇒ String
The parameter value.
-
#version ⇒ Integer
The parameter version.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the parameter.
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#data_type ⇒ String
The data type of the parameter, such as text or aws:ec2:image.
The default is text.
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#last_modified_date ⇒ Time
Date the parameter was last changed or updated and the parameter version was created.
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#name ⇒ String
The name of the parameter.
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#selector ⇒ String
Either the version number or the label used to retrieve the parameter value. Specify selectors by using one of the following formats:
parameter_name:version
parameter_name:label
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#source_result ⇒ String
Applies to parameters that reference information in other Amazon Web
Services services. SourceResult is the raw result or response from
the source.
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#type ⇒ String
The type of parameter. Valid values include the following: String,
StringList, and SecureString.
StringList, the system returns a comma-separated string
with no spaces between commas in the Value field.
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#value ⇒ String
The parameter value.
StringList, the system returns a comma-separated string
with no spaces between commas in the Value field.
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#version ⇒ Integer
The parameter version.
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 |
# File 'lib/aws-sdk-ssm/types.rb', line 15399 class Parameter < Struct.new( :name, :type, :value, :version, :selector, :source_result, :last_modified_date, :arn, :data_type) SENSITIVE = [:value] include Aws::Structure end |