Class: Aws::SSM::Types::ParameterHistory

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Information about parameter usage.

Constant Summary collapse

SENSITIVE =
[:value]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_patternString

Parameter names can include the following letters and symbols.

a-zA-Z0-9_.-



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#data_typeString

The data type of the parameter, such as text or aws:ec2:image. The default is text.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#descriptionString

Information about the parameter.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#key_idString

The alias of the Key Management Service (KMS) key used to encrypt the parameter. Applies to SecureString parameters only



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#labelsArray<String>

Labels assigned to the parameter version.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#last_modified_dateTime

Date the parameter was last changed or updated.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#last_modified_userString

Amazon Resource Name (ARN) of the Amazon Web Services user who last changed the parameter.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#nameString

The name of the parameter.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#policiesArray<Types::ParameterInlinePolicy>

Information about the policies assigned to a parameter.

Assigning parameter policies][1

in the *Amazon Web Services

Systems Manager User Guide*.

[1]: docs.aws.amazon.com/systems-manager/latest/userguide/parameter-store-policies.html



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#tierString

The parameter tier.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#typeString

The type of parameter used.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#valueString

The parameter value.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end

#versionInteger

The parameter version.



15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
# File 'lib/aws-sdk-ssm/types.rb', line 15053

class ParameterHistory < Struct.new(
  :name,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :value,
  :allowed_pattern,
  :version,
  :labels,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = [:value]
  include Aws::Structure
end