Class: Aws::SSM::Types::Patch

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Represents metadata about a patch.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#advisory_idsArray<String>

The Advisory ID of the patch. For example, RHSA-2020:3779. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#archString

The architecture of the patch. For example, in example-pkg-0.710.10-2.7.abcd.x86_64, the architecture is indicated by x86_64. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#bugzilla_idsArray<String>

The Bugzilla ID of the patch. For example, 1600646. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#classificationString

The classification of the patch. For example, SecurityUpdates, Updates, or CriticalUpdates.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#content_urlString

The URL where more information can be obtained about the patch.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#cve_idsArray<String>

The Common Vulnerabilities and Exposures (CVE) ID of the patch. For example, CVE-2011-3192. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the patch.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#epochInteger

The epoch of the patch. For example in pkg-example-EE-20180914-2.2.amzn1.noarch, the epoch value is 20180914-2. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the patch. Applies to Windows patches only.

This ID isn't the same as the Microsoft Knowledge Base ID.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#kb_numberString

The Microsoft Knowledge Base ID of the patch. Applies to Windows patches only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#languageString

The language of the patch if it's language-specific.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#msrc_numberString

The ID of the Microsoft Security Response Center (MSRC) bulletin the patch is related to. For example, MS14-045. Applies to Windows patches only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#msrc_severityString

The severity of the patch, such as Critical, Important, or Moderate. Applies to Windows patches only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the patch. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#productString

The specific product the patch is applicable for. For example, WindowsServer2016 or AmazonLinux2018.03.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#product_familyString

The product family the patch is applicable for. For example, Windows or Amazon Linux 2.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#releaseString

The particular release of a patch. For example, in pkg-example-EE-20180914-2.2.amzn1.noarch, the release is 2.amaz1. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#release_dateTime

The date the patch was released.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#repositoryString

The source patch repository for the operating system and version, such as trusty-security for Ubuntu Server 14.04 LTE and focal-security for Ubuntu Server 20.04 LTE. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The severity level of the patch. For example, CRITICAL or MODERATE.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the patch.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#vendorString

The name of the vendor providing the patch.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version number of the patch. For example, in example-pkg-1.710.10-2.7.abcd.x86_64, the version number is indicated by -1. Applies to Linux-based managed nodes only.



15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
# File 'lib/aws-sdk-ssm/types.rb', line 15955

class Patch < Struct.new(
  :id,
  :release_date,
  :title,
  :description,
  :content_url,
  :vendor,
  :product_family,
  :product,
  :classification,
  :msrc_severity,
  :kb_number,
  :msrc_number,
  :language,
  :advisory_ids,
  :bugzilla_ids,
  :cve_ids,
  :name,
  :epoch,
  :version,
  :release,
  :arch,
  :severity,
  :repository)
  SENSITIVE = []
  include Aws::Structure
end