Class: Aws::SSM::Types::PatchComplianceData

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Information about the state of a patch on a particular managed node as it relates to the patch baseline used to patch the node.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#classificationString

The classification of the patch, such as SecurityUpdates, Updates, and CriticalUpdates.

Returns:

  • (String)


16072
16073
16074
16075
16076
16077
16078
16079
16080
16081
16082
# File 'lib/aws-sdk-ssm/types.rb', line 16072

class PatchComplianceData < Struct.new(
  :title,
  :kb_id,
  :classification,
  :severity,
  :state,
  :installed_time,
  :cve_ids)
  SENSITIVE = []
  include Aws::Structure
end

#cve_idsString

The IDs of one or more Common Vulnerabilities and Exposure (CVE) issues that are resolved by the patch.

Currently, CVE ID values are reported only for patches with a status of Missing or Failed.

Returns:

  • (String)


16072
16073
16074
16075
16076
16077
16078
16079
16080
16081
16082
# File 'lib/aws-sdk-ssm/types.rb', line 16072

class PatchComplianceData < Struct.new(
  :title,
  :kb_id,
  :classification,
  :severity,
  :state,
  :installed_time,
  :cve_ids)
  SENSITIVE = []
  include Aws::Structure
end

#installed_timeTime

The date/time the patch was installed on the managed node. Not all operating systems provide this level of information.

Returns:

  • (Time)


16072
16073
16074
16075
16076
16077
16078
16079
16080
16081
16082
# File 'lib/aws-sdk-ssm/types.rb', line 16072

class PatchComplianceData < Struct.new(
  :title,
  :kb_id,
  :classification,
  :severity,
  :state,
  :installed_time,
  :cve_ids)
  SENSITIVE = []
  include Aws::Structure
end

#kb_idString

The operating system-specific ID of the patch.

Returns:

  • (String)


16072
16073
16074
16075
16076
16077
16078
16079
16080
16081
16082
# File 'lib/aws-sdk-ssm/types.rb', line 16072

class PatchComplianceData < Struct.new(
  :title,
  :kb_id,
  :classification,
  :severity,
  :state,
  :installed_time,
  :cve_ids)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The severity of the patch such as Critical, Important, and Moderate.

Returns:

  • (String)


16072
16073
16074
16075
16076
16077
16078
16079
16080
16081
16082
# File 'lib/aws-sdk-ssm/types.rb', line 16072

class PatchComplianceData < Struct.new(
  :title,
  :kb_id,
  :classification,
  :severity,
  :state,
  :installed_time,
  :cve_ids)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the patch on the managed node, such as INSTALLED or FAILED.

For descriptions of each patch state, see About patch compliance in the Amazon Web Services Systems Manager User Guide.

Returns:

  • (String)


16072
16073
16074
16075
16076
16077
16078
16079
16080
16081
16082
# File 'lib/aws-sdk-ssm/types.rb', line 16072

class PatchComplianceData < Struct.new(
  :title,
  :kb_id,
  :classification,
  :severity,
  :state,
  :installed_time,
  :cve_ids)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the patch.

Returns:

  • (String)


16072
16073
16074
16075
16076
16077
16078
16079
16080
16081
16082
# File 'lib/aws-sdk-ssm/types.rb', line 16072

class PatchComplianceData < Struct.new(
  :title,
  :kb_id,
  :classification,
  :severity,
  :state,
  :installed_time,
  :cve_ids)
  SENSITIVE = []
  include Aws::Structure
end