Method: Aws::SSM::Types::PatchSource#configuration

Defined in:
lib/aws-sdk-ssm/types.rb

#configurationString

The value of the repo configuration.

**Example for yum repositories**

[main]

‘name=MyCustomRepository`

‘baseurl=my-custom-repository`

‘enabled=1`

For information about other options available for your yum repository configuration, see [dnf.conf(5)] on the man7.org website.

**Examples for Ubuntu Server and Debian Server**

‘deb security.ubuntu.com/ubuntu jammy main`

‘deb site.example.com/debian distribution component1 component2 component3`

Repo information for Ubuntu Server repositories must be specifed in a single line. For more examples and information, see [jammy (5) sources.list.5.gz] on the *Ubuntu Server Manuals* website and

sources.list format][3

on the *Debian Wiki*.

[1]: man7.org/linux/man-pages/man5/dnf.conf.5.html [2]: manpages.ubuntu.com/manpages/jammy/man5/sources.list.5.html [3]: wiki.debian.org/SourcesList#sources.list_format

Returns:

  • (String)


15905
15906
15907
15908
15909
15910
15911
# File 'lib/aws-sdk-ssm/types.rb', line 15905

class PatchSource < Struct.new(
  :name,
  :products,
  :configuration)
  SENSITIVE = [:configuration]
  include Aws::Structure
end