Class: Aws::SSM::Types::ProgressCounters

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

An aggregate of step execution statuses displayed in the Amazon Web Services Systems Manager console for a multi-Region and multi-account Automation execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cancelled_stepsInteger

The total number of steps that the system cancelled in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.



16429
16430
16431
16432
16433
16434
16435
16436
16437
# File 'lib/aws-sdk-ssm/types.rb', line 16429

class ProgressCounters < Struct.new(
  :total_steps,
  :success_steps,
  :failed_steps,
  :cancelled_steps,
  :timed_out_steps)
  SENSITIVE = []
  include Aws::Structure
end

#failed_stepsInteger

The total number of steps that failed to run in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.



16429
16430
16431
16432
16433
16434
16435
16436
16437
# File 'lib/aws-sdk-ssm/types.rb', line 16429

class ProgressCounters < Struct.new(
  :total_steps,
  :success_steps,
  :failed_steps,
  :cancelled_steps,
  :timed_out_steps)
  SENSITIVE = []
  include Aws::Structure
end

#success_stepsInteger

The total number of steps that successfully completed in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.



16429
16430
16431
16432
16433
16434
16435
16436
16437
# File 'lib/aws-sdk-ssm/types.rb', line 16429

class ProgressCounters < Struct.new(
  :total_steps,
  :success_steps,
  :failed_steps,
  :cancelled_steps,
  :timed_out_steps)
  SENSITIVE = []
  include Aws::Structure
end

#timed_out_stepsInteger

The total number of steps that timed out in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.



16429
16430
16431
16432
16433
16434
16435
16436
16437
# File 'lib/aws-sdk-ssm/types.rb', line 16429

class ProgressCounters < Struct.new(
  :total_steps,
  :success_steps,
  :failed_steps,
  :cancelled_steps,
  :timed_out_steps)
  SENSITIVE = []
  include Aws::Structure
end

#total_stepsInteger

The total number of steps run in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.



16429
16430
16431
16432
16433
16434
16435
16436
16437
# File 'lib/aws-sdk-ssm/types.rb', line 16429

class ProgressCounters < Struct.new(
  :total_steps,
  :success_steps,
  :failed_steps,
  :cancelled_steps,
  :timed_out_steps)
  SENSITIVE = []
  include Aws::Structure
end