Class: Aws::SSM::Types::PutComplianceItemsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::PutComplianceItemsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compliance_type ⇒ String
Specify the compliance type.
-
#execution_summary ⇒ Types::ComplianceExecutionSummary
A summary of the call execution that includes an execution ID, the type of execution (for example,
Command), and the date/time of the execution using a datetime object that is saved in the following format: ‘yyyy-MM-dd’T’HH:mm:ss’Z’‘. -
#item_content_hash ⇒ String
MD5 or SHA-256 content hash.
-
#items ⇒ Array<Types::ComplianceItemEntry>
Information about the compliance as defined by the resource type.
-
#resource_id ⇒ String
Specify an ID for this resource.
-
#resource_type ⇒ String
Specify the type of resource.
-
#upload_type ⇒ String
The mode for uploading compliance items.
Instance Attribute Details
#compliance_type ⇒ String
Specify the compliance type. For example, specify Association (for a State Manager association), Patch, or Custom:string.
16051 16052 16053 16054 16055 16056 16057 16058 16059 16060 16061 |
# File 'lib/aws-sdk-ssm/types.rb', line 16051 class PutComplianceItemsRequest < Struct.new( :resource_id, :resource_type, :compliance_type, :execution_summary, :items, :item_content_hash, :upload_type) SENSITIVE = [] include Aws::Structure end |
#execution_summary ⇒ Types::ComplianceExecutionSummary
A summary of the call execution that includes an execution ID, the type of execution (for example, Command), and the date/time of the execution using a datetime object that is saved in the following format: ‘yyyy-MM-dd’T’HH:mm:ss’Z’‘
16051 16052 16053 16054 16055 16056 16057 16058 16059 16060 16061 |
# File 'lib/aws-sdk-ssm/types.rb', line 16051 class PutComplianceItemsRequest < Struct.new( :resource_id, :resource_type, :compliance_type, :execution_summary, :items, :item_content_hash, :upload_type) SENSITIVE = [] include Aws::Structure end |
#item_content_hash ⇒ String
MD5 or SHA-256 content hash. The content hash is used to determine if existing information should be overwritten or ignored. If the content hashes match, the request to put compliance information is ignored.
16051 16052 16053 16054 16055 16056 16057 16058 16059 16060 16061 |
# File 'lib/aws-sdk-ssm/types.rb', line 16051 class PutComplianceItemsRequest < Struct.new( :resource_id, :resource_type, :compliance_type, :execution_summary, :items, :item_content_hash, :upload_type) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::ComplianceItemEntry>
Information about the compliance as defined by the resource type. For example, for a patch compliance type, Items includes information about the PatchSeverity, Classification, and so on.
16051 16052 16053 16054 16055 16056 16057 16058 16059 16060 16061 |
# File 'lib/aws-sdk-ssm/types.rb', line 16051 class PutComplianceItemsRequest < Struct.new( :resource_id, :resource_type, :compliance_type, :execution_summary, :items, :item_content_hash, :upload_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
Specify an ID for this resource. For a managed node, this is the node ID.
16051 16052 16053 16054 16055 16056 16057 16058 16059 16060 16061 |
# File 'lib/aws-sdk-ssm/types.rb', line 16051 class PutComplianceItemsRequest < Struct.new( :resource_id, :resource_type, :compliance_type, :execution_summary, :items, :item_content_hash, :upload_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Specify the type of resource. ManagedInstance is currently the only supported resource type.
16051 16052 16053 16054 16055 16056 16057 16058 16059 16060 16061 |
# File 'lib/aws-sdk-ssm/types.rb', line 16051 class PutComplianceItemsRequest < Struct.new( :resource_id, :resource_type, :compliance_type, :execution_summary, :items, :item_content_hash, :upload_type) SENSITIVE = [] include Aws::Structure end |
#upload_type ⇒ String
The mode for uploading compliance items. You can specify COMPLETE or PARTIAL. In COMPLETE mode, the system overwrites all existing compliance information for the resource. You must provide a full list of compliance items each time you send the request.
In PARTIAL mode, the system overwrites compliance information for a specific association. The association must be configured with SyncCompliance set to MANUAL. By default, all requests use COMPLETE mode.
<note markdown=“1”> This attribute is only valid for association compliance.
</note>
16051 16052 16053 16054 16055 16056 16057 16058 16059 16060 16061 |
# File 'lib/aws-sdk-ssm/types.rb', line 16051 class PutComplianceItemsRequest < Struct.new( :resource_id, :resource_type, :compliance_type, :execution_summary, :items, :item_content_hash, :upload_type) SENSITIVE = [] include Aws::Structure end |