Method: Aws::SSM::Types::PutComplianceItemsRequest#items

Defined in:
lib/aws-sdk-ssm/types.rb

#itemsArray<Types::ComplianceItemEntry>

Information about the compliance as defined by the resource type. For example, for a patch compliance type, Items includes information about the PatchSeverity, Classification, and so on.

Returns:



16051
16052
16053
16054
16055
16056
16057
16058
16059
16060
16061
# File 'lib/aws-sdk-ssm/types.rb', line 16051

class PutComplianceItemsRequest < Struct.new(
  :resource_id,
  :resource_type,
  :compliance_type,
  :execution_summary,
  :items,
  :item_content_hash,
  :upload_type)
  SENSITIVE = []
  include Aws::Structure
end