Method: Aws::SSM::Types::RegisterTaskWithMaintenanceWindowRequest#max_concurrency

Defined in:
lib/aws-sdk-ssm/types.rb

#max_concurrencyString

The maximum number of targets this task can be run for, in parallel.

<note markdown=“1”> Although this element is listed as “Required: No”, a value can be omitted only when you are registering or updating a [targetless task] You must provide a value in all other cases.

For maintenance window tasks without a target specified, you can't

supply a value for this option. Instead, the system inserts a placeholder value of 1. This value doesn’t affect the running of your task.

</note>

[1]: docs.aws.amazon.com/systems-manager/latest/userguide/maintenance-windows-targetless-tasks.html

Returns:

  • (String)


16830
16831
16832
16833
16834
16835
16836
16837
16838
16839
16840
16841
16842
16843
16844
16845
16846
16847
16848
16849
# File 'lib/aws-sdk-ssm/types.rb', line 16830

class RegisterTaskWithMaintenanceWindowRequest < Struct.new(
  :window_id,
  :targets,
  :task_arn,
  :service_role_arn,
  :task_type,
  :task_parameters,
  :task_invocation_parameters,
  :priority,
  :max_concurrency,
  :max_errors,
  :logging_info,
  :name,
  :description,
  :client_token,
  :cutoff_behavior,
  :alarm_configuration)
  SENSITIVE = [:task_parameters, :description]
  include Aws::Structure
end