Class: Aws::SSM::Types::RelatedOpsItem

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

An OpsItems that shares something in common with the current OpsItem. For example, related OpsItems can include OpsItems with similar error messages, impacted resources, or statuses for the impacted resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ops_item_idString

The ID of an OpsItem related to the current OpsItem.

Returns:

  • (String)


16892
16893
16894
16895
16896
# File 'lib/aws-sdk-ssm/types.rb', line 16892

class RelatedOpsItem < Struct.new(
  :ops_item_id)
  SENSITIVE = []
  include Aws::Structure
end