Class: Aws::SSM::Types::ResourceLimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ResourceLimitExceededException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Error returned when the caller has exceeded the default resource quotas. For example, too many maintenance windows or patch baselines have been created.
For information about resource quotas in Systems Manager, see [Systems Manager service quotas] in the *Amazon Web Services General Reference*.
[1]: docs.aws.amazon.com/general/latest/gr/ssm.html#limits_ssm
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
17480 17481 17482 17483 17484 |
# File 'lib/aws-sdk-ssm/types.rb', line 17480 class ResourceLimitExceededException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |