Class: Aws::SSM::Types::Runbook

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Information about an Automation runbook used in a runbook workflow in Change Manager.

The Automation runbooks specified for the runbook workflow can't run until all required approvals for the change request have been received.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#document_nameString

The name of the Automation runbook used in a runbook workflow.

Returns:

  • (String)


18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end

#document_versionString

The version of the Automation runbook used in a runbook workflow.

Returns:

  • (String)


18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end

#max_concurrencyString

The MaxConcurrency value specified by the user when the operation started, indicating the maximum number of resources that the runbook operation can run on at the same time.

Returns:

  • (String)


18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end

#max_errorsString

The MaxErrors value specified by the user when the execution started, indicating the maximum number of errors that can occur during the operation before the updates are stopped or rolled back.

Returns:

  • (String)


18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Array<String>>

The key-value map of execution parameters, which were supplied when calling StartChangeRequestExecution.

Returns:

  • (Hash<String,Array<String>>)


18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end

#target_locationsArray<Types::TargetLocation>

Information about the Amazon Web Services Regions and Amazon Web Services accounts targeted by the current Runbook operation.

Returns:



18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end

#target_mapsArray<Hash<String,Array<String>>>

A key-value mapping of runbook parameters to target resources. Both Targets and TargetMaps can't be specified together.

Returns:

  • (Array<Hash<String,Array<String>>>)


18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end

#target_parameter_nameString

The name of the parameter used as the target resource for the rate-controlled runbook workflow. Required if you specify Targets.

Returns:

  • (String)


18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<Types::Target>

A key-value mapping to target resources that the runbook operation performs tasks on. Required if you specify TargetParameterName.

Returns:



18144
18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
# File 'lib/aws-sdk-ssm/types.rb', line 18144

class Runbook < Struct.new(
  :document_name,
  :document_version,
  :parameters,
  :target_parameter_name,
  :targets,
  :target_maps,
  :max_concurrency,
  :max_errors,
  :target_locations)
  SENSITIVE = []
  include Aws::Structure
end