Class: Aws::SSM::Types::SendAutomationSignalRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#automation_execution_idString

The unique identifier for an existing Automation execution that you want to send the signal to.

Returns:

  • (String)


18267
18268
18269
18270
18271
18272
18273
# File 'lib/aws-sdk-ssm/types.rb', line 18267

class SendAutomationSignalRequest < Struct.new(
  :automation_execution_id,
  :signal_type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end

#payloadHash<String,Array<String>>

The data sent with the signal. The data schema depends on the type of signal used in the request.

For Approve and Reject signal types, the payload is an optional comment that you can send with the signal type. For example:

Comment="Looks good"

For StartStep and Resume signal types, you must send the name of the Automation step to start or resume as the payload. For example:

StepName="step1"

For the StopStep signal type, you must send the step execution ID as the payload. For example:

StepExecutionId="97fff367-fc5a-4299-aed8-0123456789ab"

Returns:

  • (Hash<String,Array<String>>)


18267
18268
18269
18270
18271
18272
18273
# File 'lib/aws-sdk-ssm/types.rb', line 18267

class SendAutomationSignalRequest < Struct.new(
  :automation_execution_id,
  :signal_type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end

#signal_typeString

The type of signal to send to an Automation execution.

Returns:

  • (String)


18267
18268
18269
18270
18271
18272
18273
# File 'lib/aws-sdk-ssm/types.rb', line 18267

class SendAutomationSignalRequest < Struct.new(
  :automation_execution_id,
  :signal_type,
  :payload)
  SENSITIVE = []
  include Aws::Structure
end