Class: Aws::SSM::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ServiceQuotaExceededException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The request exceeds the service quota. Service quotas, also referred to as limits, are the maximum number of service resources or operations for your Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#quota_code ⇒ String
The quota code recognized by the Amazon Web Services Service Quotas service.
-
#resource_id ⇒ String
The unique ID of the resource referenced in the failed request.
-
#resource_type ⇒ String
The resource type of the resource referenced in the failed request.
-
#service_code ⇒ String
The code for the Amazon Web Services service that owns the quota.
Instance Attribute Details
#message ⇒ String
18080 18081 18082 18083 18084 18085 18086 18087 18088 |
# File 'lib/aws-sdk-ssm/types.rb', line 18080 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :quota_code, :service_code) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
The quota code recognized by the Amazon Web Services Service Quotas service.
18080 18081 18082 18083 18084 18085 18086 18087 18088 |
# File 'lib/aws-sdk-ssm/types.rb', line 18080 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :quota_code, :service_code) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The unique ID of the resource referenced in the failed request.
18080 18081 18082 18083 18084 18085 18086 18087 18088 |
# File 'lib/aws-sdk-ssm/types.rb', line 18080 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :quota_code, :service_code) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type of the resource referenced in the failed request.
18080 18081 18082 18083 18084 18085 18086 18087 18088 |
# File 'lib/aws-sdk-ssm/types.rb', line 18080 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :quota_code, :service_code) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The code for the Amazon Web Services service that owns the quota.
18080 18081 18082 18083 18084 18085 18086 18087 18088 |
# File 'lib/aws-sdk-ssm/types.rb', line 18080 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :quota_code, :service_code) SENSITIVE = [] include Aws::Structure end |