Class: Aws::SSM::Types::Session
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::Session
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about a Session Manager connection to a managed node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_type ⇒ String
Standardaccess type is the default for Session Manager sessions. -
#details ⇒ String
Reserved for future use.
-
#document_name ⇒ String
The name of the Session Manager SSM document used to define the parameters and plugin settings for the session.
-
#end_date ⇒ Time
The date and time, in ISO-8601 Extended format, when the session was terminated.
-
#max_session_duration ⇒ String
The maximum duration of a session before it terminates.
-
#output_url ⇒ Types::SessionManagerOutputUrl
Reserved for future use.
-
#owner ⇒ String
The ID of the Amazon Web Services user that started the session.
-
#reason ⇒ String
The reason for connecting to the instance.
-
#session_id ⇒ String
The ID of the session.
-
#start_date ⇒ Time
The date and time, in ISO-8601 Extended format, when the session began.
-
#status ⇒ String
The status of the session.
-
#target ⇒ String
The managed node that the Session Manager session connected to.
Instance Attribute Details
#access_type ⇒ String
Standard access type is the default for Session Manager sessions.
JustInTime is the access type for Just-in-time node access.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#details ⇒ String
Reserved for future use.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#document_name ⇒ String
The name of the Session Manager SSM document used to define the
parameters and plugin settings for the session. For example,
SSM-SessionManagerRunShell.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#end_date ⇒ Time
The date and time, in ISO-8601 Extended format, when the session was terminated.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#max_session_duration ⇒ String
The maximum duration of a session before it terminates.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#output_url ⇒ Types::SessionManagerOutputUrl
Reserved for future use.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The ID of the Amazon Web Services user that started the session.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason for connecting to the instance.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The date and time, in ISO-8601 Extended format, when the session began.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the session. For example, "Connected" or "Terminated".
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |
#target ⇒ String
The managed node that the Session Manager session connected to.
18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 |
# File 'lib/aws-sdk-ssm/types.rb', line 18663 class Session < Struct.new( :session_id, :target, :status, :start_date, :end_date, :document_name, :owner, :reason, :details, :output_url, :max_session_duration, :access_type) SENSITIVE = [] include Aws::Structure end |