Class: Aws::SSM::Types::StartAccessRequestRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#reasonString

A brief description explaining why you are requesting access to the node.

Returns:

  • (String)


18817
18818
18819
18820
18821
18822
18823
# File 'lib/aws-sdk-ssm/types.rb', line 18817

class StartAccessRequestRequest < Struct.new(
  :reason,
  :targets,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Key-value pairs of metadata you want to assign to the access request.

Returns:



18817
18818
18819
18820
18821
18822
18823
# File 'lib/aws-sdk-ssm/types.rb', line 18817

class StartAccessRequestRequest < Struct.new(
  :reason,
  :targets,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<Types::Target>

The node you are requesting access to.

Returns:



18817
18818
18819
18820
18821
18822
18823
# File 'lib/aws-sdk-ssm/types.rb', line 18817

class StartAccessRequestRequest < Struct.new(
  :reason,
  :targets,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end