Class: Aws::SSM::Types::StartSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#document_nameString

The name of the SSM document you want to use to define the type of session, input parameters, or preferences for the session. For example, SSM-SessionManagerRunShell. You can call the GetDocument API to verify the document exists before attempting to start a session. If no document name is provided, a shell to the managed node is launched by default. For more information, see Start a session in the Amazon Web Services Systems Manager User Guide.

Returns:

  • (String)


19217
19218
19219
19220
19221
19222
19223
19224
# File 'lib/aws-sdk-ssm/types.rb', line 19217

class StartSessionRequest < Struct.new(
  :target,
  :document_name,
  :reason,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Array<String>>

The values you want to specify for the parameters defined in the Session document. For more information about these parameters, see Create a Session Manager preferences document in the Amazon Web Services Systems Manager User Guide.

Returns:

  • (Hash<String,Array<String>>)


19217
19218
19219
19220
19221
19222
19223
19224
# File 'lib/aws-sdk-ssm/types.rb', line 19217

class StartSessionRequest < Struct.new(
  :target,
  :document_name,
  :reason,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason for connecting to the instance. This value is included in the details for the Amazon CloudWatch Events event created when you start the session.

Returns:

  • (String)


19217
19218
19219
19220
19221
19222
19223
19224
# File 'lib/aws-sdk-ssm/types.rb', line 19217

class StartSessionRequest < Struct.new(
  :target,
  :document_name,
  :reason,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#targetString

The managed node to connect to for the session.

Returns:

  • (String)


19217
19218
19219
19220
19221
19222
19223
19224
# File 'lib/aws-sdk-ssm/types.rb', line 19217

class StartSessionRequest < Struct.new(
  :target,
  :document_name,
  :reason,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end