Class: Aws::SSM::Types::TargetLocation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

The combination of Amazon Web Services Regions and Amazon Web Services accounts targeted by the current Automation execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountsArray<String>

The Amazon Web Services accounts targeted by the current Automation execution.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_accountsArray<String>

Amazon Web Services accounts or organizational units to exclude as expanded targets.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_nameString

The Automation execution role used by the currently running Automation. If not specified, the default value is AWS-SystemsManager-AutomationExecutionRole.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#include_child_organization_unitsBoolean

Indicates whether to include child organizational units (OUs) that are children of the targeted OUs. The default is false.

<note markdown=“1”> This parameter is not supported by State Manager.

</note>

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#regionsArray<String>

The Amazon Web Services Regions targeted by the current Automation execution.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#target_location_alarm_configurationTypes::AlarmConfiguration

The details for the CloudWatch alarm you want to apply to an automation or command.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#target_location_max_concurrencyString

The maximum number of Amazon Web Services Regions and Amazon Web Services accounts allowed to run the Automation concurrently. TargetLocationMaxConcurrency has a default value of 1.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#target_location_max_errorsString

The maximum number of errors allowed before the system stops queueing additional Automation executions for the currently running Automation. TargetLocationMaxErrors has a default value of 0.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<Types::Target>

A list of key-value mappings to target resources. If you specify values for this data type, you must also specify a value for TargetParameterName.

This Targets parameter takes precedence over the StartAutomationExecution:Targets parameter if both are supplied.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#targets_max_concurrencyString

The maximum number of targets allowed to run this task in parallel. This TargetsMaxConcurrency takes precedence over the StartAutomationExecution:MaxConcurrency parameter if both are supplied.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end

#targets_max_errorsString

The maximum number of errors that are allowed before the system stops running the automation on additional targets. This TargetsMaxErrors parameter takes precedence over the StartAutomationExecution:MaxErrors parameter if both are supplied.

Returns:



19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
# File 'lib/aws-sdk-ssm/types.rb', line 19251

class TargetLocation < Struct.new(
  :accounts,
  :regions,
  :target_location_max_concurrency,
  :target_location_max_errors,
  :execution_role_name,
  :target_location_alarm_configuration,
  :include_child_organization_units,
  :exclude_accounts,
  :targets,
  :targets_max_concurrency,
  :targets_max_errors)
  SENSITIVE = []
  include Aws::Structure
end