Class: Aws::SSM::Types::TargetNotConnected
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::TargetNotConnected
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The specified target managed node for the session isn't fully configured for use with Session Manager. For more information, see Setting up Session Manager in the Amazon Web Services Systems Manager User Guide. This error is also returned if you attempt to start a session on a managed node that is located in a different account or Region
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
19727 19728 19729 19730 19731 |
# File 'lib/aws-sdk-ssm/types.rb', line 19727 class TargetNotConnected < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |