Class: Aws::SSM::Types::UnsupportedOperatingSystem
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::UnsupportedOperatingSystem
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The operating systems you specified is not supported, or the operation is not supported for the operating system. Valid operating systems include: Windows, AmazonLinux, RedhatEnterpriseLinux, and Ubuntu.
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
15862 15863 15864 15865 |
# File 'lib/aws-sdk-ssm/types.rb', line 15862 class UnsupportedOperatingSystem < Struct.new( :message) include Aws::Structure end |