Method: Aws::SSM::Types::UpdateAssociationRequest#parameters

Defined in:
lib/aws-sdk-ssm/types.rb

#parametersHash<String,Array<String>>

The parameters you want to update for the association. If you create a parameter using Parameter Store, a tool in Amazon Web Services Systems Manager, you can reference the parameter using ‘{ssm:parameter-name}`.

Returns:

  • (Hash<String,Array<String>>)


19831
19832
19833
19834
19835
19836
19837
19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
# File 'lib/aws-sdk-ssm/types.rb', line 19831

class UpdateAssociationRequest < Struct.new(
  :association_id,
  :parameters,
  :document_version,
  :schedule_expression,
  :output_location,
  :name,
  :targets,
  :association_name,
  :association_version,
  :automation_target_parameter_name,
  :max_errors,
  :max_concurrency,
  :compliance_severity,
  :sync_compliance,
  :apply_only_at_cron_interval,
  :calendar_names,
  :target_locations,
  :schedule_offset,
  :duration,
  :target_maps,
  :alarm_configuration,
  :association_dispatch_assume_role)
  SENSITIVE = [:parameters]
  include Aws::Structure
end