Class: Aws::SSM::Types::UpdateDocumentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::UpdateDocumentRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Types::AttachmentsSource>
A list of key-value pairs that describe attachments to a version of a document.
-
#content ⇒ String
A valid JSON or YAML string.
-
#display_name ⇒ String
The friendly name of the SSM document that you want to update.
-
#document_format ⇒ String
Specify the document format for the new document version.
-
#document_version ⇒ String
The version of the document that you want to update.
-
#name ⇒ String
The name of the SSM document that you want to update.
-
#target_type ⇒ String
Specify a new target type for the document.
-
#version_name ⇒ String
An optional field specifying the version of the artifact you are updating with the document.
Instance Attribute Details
#attachments ⇒ Array<Types::AttachmentsSource>
A list of key-value pairs that describe attachments to a version of a document.
20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 20490 |
# File 'lib/aws-sdk-ssm/types.rb', line 20479 class UpdateDocumentRequest < Struct.new( :content, :attachments, :name, :display_name, :version_name, :document_version, :document_format, :target_type) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
A valid JSON or YAML string.
20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 20490 |
# File 'lib/aws-sdk-ssm/types.rb', line 20479 class UpdateDocumentRequest < Struct.new( :content, :attachments, :name, :display_name, :version_name, :document_version, :document_format, :target_type) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The friendly name of the SSM document that you want to update. This value can differ for each version of the document. If you don't specify a value for this parameter in your request, the existing value is applied to the new document version.
20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 20490 |
# File 'lib/aws-sdk-ssm/types.rb', line 20479 class UpdateDocumentRequest < Struct.new( :content, :attachments, :name, :display_name, :version_name, :document_version, :document_format, :target_type) SENSITIVE = [] include Aws::Structure end |
#document_format ⇒ String
Specify the document format for the new document version. Systems Manager supports JSON and YAML documents. JSON is the default format.
20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 20490 |
# File 'lib/aws-sdk-ssm/types.rb', line 20479 class UpdateDocumentRequest < Struct.new( :content, :attachments, :name, :display_name, :version_name, :document_version, :document_format, :target_type) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The version of the document that you want to update. Currently,
Systems Manager supports updating only the latest version of the
document. You can specify the version number of the latest version
or use the $LATEST variable.
apply-only-at-cron-interval parameter.
20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 20490 |
# File 'lib/aws-sdk-ssm/types.rb', line 20479 class UpdateDocumentRequest < Struct.new( :content, :attachments, :name, :display_name, :version_name, :document_version, :document_format, :target_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SSM document that you want to update.
20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 20490 |
# File 'lib/aws-sdk-ssm/types.rb', line 20479 class UpdateDocumentRequest < Struct.new( :content, :attachments, :name, :display_name, :version_name, :document_version, :document_format, :target_type) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
Specify a new target type for the document.
20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 20490 |
# File 'lib/aws-sdk-ssm/types.rb', line 20479 class UpdateDocumentRequest < Struct.new( :content, :attachments, :name, :display_name, :version_name, :document_version, :document_format, :target_type) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
An optional field specifying the version of the artifact you are updating with the document. For example, 12.6. This value is unique across all versions of a document, and can't be changed.
20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 20490 |
# File 'lib/aws-sdk-ssm/types.rb', line 20479 class UpdateDocumentRequest < Struct.new( :content, :attachments, :name, :display_name, :version_name, :document_version, :document_format, :target_type) SENSITIVE = [] include Aws::Structure end |