Class: Aws::SSM::Types::UpdateMaintenanceWindowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::UpdateMaintenanceWindowRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#allow_unassociated_targets ⇒ Boolean
Whether targets must be registered with the maintenance window before tasks can be defined for those targets.
-
#cutoff ⇒ Integer
The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.
-
#description ⇒ String
An optional description for the update request.
-
#duration ⇒ Integer
The duration of the maintenance window in hours.
-
#enabled ⇒ Boolean
Whether the maintenance window is enabled.
-
#end_date ⇒ String
The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become inactive.
-
#name ⇒ String
The name of the maintenance window.
-
#replace ⇒ Boolean
If
True, then all fields that are required by the CreateMaintenanceWindow operation are also required for this API request. -
#schedule ⇒ String
The schedule of the maintenance window in the form of a cron or rate expression.
-
#schedule_offset ⇒ Integer
The number of days to wait after the date and time specified by a cron expression before running the maintenance window.
-
#schedule_timezone ⇒ String
The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format.
-
#start_date ⇒ String
The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become active.
-
#window_id ⇒ String
The ID of the maintenance window to update.
Instance Attribute Details
#allow_unassociated_targets ⇒ Boolean
Whether targets must be registered with the maintenance window before tasks can be defined for those targets.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#cutoff ⇒ Integer
The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
An optional description for the update request.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#duration ⇒ Integer
The duration of the maintenance window in hours.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#enabled ⇒ Boolean
Whether the maintenance window is enabled.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#end_date ⇒ String
The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become inactive. EndDate allows you to set a date and time in the future when the maintenance window will no longer run.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the maintenance window.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#replace ⇒ Boolean
If True, then all fields that are required by the CreateMaintenanceWindow operation are also required for this API request. Optional fields that aren’t specified are set to null.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#schedule ⇒ String
The schedule of the maintenance window in the form of a cron or rate expression.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#schedule_offset ⇒ Integer
The number of days to wait after the date and time specified by a cron expression before running the maintenance window.
For example, the following cron expression schedules a maintenance window to run the third Tuesday of every month at 11:30 PM.
‘cron(30 23 ? * TUE#3 *)`
If the schedule offset is 2, the maintenance window won’t run until two days later.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#schedule_timezone ⇒ String
The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format. For example: “America/Los_Angeles”, “UTC”, or “Asia/Seoul”. For more information, see the [Time Zone Database] on the IANA website.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#start_date ⇒ String
The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become active. StartDate allows you to delay activation of the maintenance window until the specified future date.
<note markdown=“1”> When using a rate schedule, if you provide a start date that occurs in the past, the current date and time are used as the start date.
</note>
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |
#window_id ⇒ String
The ID of the maintenance window to update.
20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 |
# File 'lib/aws-sdk-ssm/types.rb', line 20128 class UpdateMaintenanceWindowRequest < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :duration, :cutoff, :allow_unassociated_targets, :enabled, :replace) SENSITIVE = [:description] include Aws::Structure end |