Method: Aws::SSM::Types::UpdateMaintenanceWindowRequest#end_date

Defined in:
lib/aws-sdk-ssm/types.rb

#end_dateString

The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become inactive. EndDate allows you to set a date and time in the future when the maintenance window will no longer run.

Returns:

  • (String)


20128
20129
20130
20131
20132
20133
20134
20135
20136
20137
20138
20139
20140
20141
20142
20143
20144
# File 'lib/aws-sdk-ssm/types.rb', line 20128

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end