Method: Aws::SSM::Types::UpdateMaintenanceWindowRequest#schedule_timezone

Defined in:
lib/aws-sdk-ssm/types.rb

#schedule_timezoneString

The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format. For example: “America/Los_Angeles”, “UTC”, or “Asia/Seoul”. For more information, see the [Time Zone Database] on the IANA website.

[1]: www.iana.org/time-zones

Returns:

  • (String)


20128
20129
20130
20131
20132
20133
20134
20135
20136
20137
20138
20139
20140
20141
20142
20143
20144
# File 'lib/aws-sdk-ssm/types.rb', line 20128

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end