Class: Aws::SSM::Types::UpdateMaintenanceWindowResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_unassociated_targetsBoolean

Whether targets must be registered with the maintenance window before tasks can be defined for those targets.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#cutoffInteger

The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

An optional description of the update.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#durationInteger

The duration of the maintenance window in hours.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#enabledBoolean

Whether the maintenance window is enabled.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#end_dateString

The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become inactive. The maintenance window won’t run after this specified time.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the maintenance window.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#scheduleString

The schedule of the maintenance window in the form of a cron or rate expression.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#schedule_offsetInteger

The number of days to wait to run a maintenance window after the scheduled cron expression date and time.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#schedule_timezoneString

The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format. For example: “America/Los_Angeles”, “UTC”, or “Asia/Seoul”. For more information, see the [Time Zone Database] on the IANA website.

[1]: www.iana.org/time-zones



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#start_dateString

The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become active. The maintenance window won’t run before this specified time.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end

#window_idString

The ID of the created maintenance window.



20213
20214
20215
20216
20217
20218
20219
20220
20221
20222
20223
20224
20225
20226
20227
20228
# File 'lib/aws-sdk-ssm/types.rb', line 20213

class UpdateMaintenanceWindowResult < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled)
  SENSITIVE = [:description]
  include Aws::Structure
end