Class: Aws::SSM::Types::UpdateMaintenanceWindowTargetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::UpdateMaintenanceWindowTargetRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:owner_information, :description]
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description for the update.
-
#name ⇒ String
A name for the update.
-
#owner_information ⇒ String
User-provided value that will be included in any Amazon CloudWatch Events events raised while running tasks for these targets in this maintenance window.
-
#replace ⇒ Boolean
If
True, then all fields that are required by the RegisterTargetWithMaintenanceWindow operation are also required for this API request. -
#targets ⇒ Array<Types::Target>
The targets to add or replace.
-
#window_id ⇒ String
The maintenance window ID with which to modify the target.
-
#window_target_id ⇒ String
The target ID to modify.
Instance Attribute Details
#description ⇒ String
An optional description for the update.
20265 20266 20267 20268 20269 20270 20271 20272 20273 20274 20275 |
# File 'lib/aws-sdk-ssm/types.rb', line 20265 class UpdateMaintenanceWindowTargetRequest < Struct.new( :window_id, :window_target_id, :targets, :owner_information, :name, :description, :replace) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#name ⇒ String
A name for the update.
20265 20266 20267 20268 20269 20270 20271 20272 20273 20274 20275 |
# File 'lib/aws-sdk-ssm/types.rb', line 20265 class UpdateMaintenanceWindowTargetRequest < Struct.new( :window_id, :window_target_id, :targets, :owner_information, :name, :description, :replace) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#owner_information ⇒ String
User-provided value that will be included in any Amazon CloudWatch Events events raised while running tasks for these targets in this maintenance window.
20265 20266 20267 20268 20269 20270 20271 20272 20273 20274 20275 |
# File 'lib/aws-sdk-ssm/types.rb', line 20265 class UpdateMaintenanceWindowTargetRequest < Struct.new( :window_id, :window_target_id, :targets, :owner_information, :name, :description, :replace) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#replace ⇒ Boolean
If True, then all fields that are required by the RegisterTargetWithMaintenanceWindow operation are also required for this API request. Optional fields that aren’t specified are set to null.
20265 20266 20267 20268 20269 20270 20271 20272 20273 20274 20275 |
# File 'lib/aws-sdk-ssm/types.rb', line 20265 class UpdateMaintenanceWindowTargetRequest < Struct.new( :window_id, :window_target_id, :targets, :owner_information, :name, :description, :replace) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#targets ⇒ Array<Types::Target>
The targets to add or replace.
20265 20266 20267 20268 20269 20270 20271 20272 20273 20274 20275 |
# File 'lib/aws-sdk-ssm/types.rb', line 20265 class UpdateMaintenanceWindowTargetRequest < Struct.new( :window_id, :window_target_id, :targets, :owner_information, :name, :description, :replace) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#window_id ⇒ String
The maintenance window ID with which to modify the target.
20265 20266 20267 20268 20269 20270 20271 20272 20273 20274 20275 |
# File 'lib/aws-sdk-ssm/types.rb', line 20265 class UpdateMaintenanceWindowTargetRequest < Struct.new( :window_id, :window_target_id, :targets, :owner_information, :name, :description, :replace) SENSITIVE = [:owner_information, :description] include Aws::Structure end |
#window_target_id ⇒ String
The target ID to modify.
20265 20266 20267 20268 20269 20270 20271 20272 20273 20274 20275 |
# File 'lib/aws-sdk-ssm/types.rb', line 20265 class UpdateMaintenanceWindowTargetRequest < Struct.new( :window_id, :window_target_id, :targets, :owner_information, :name, :description, :replace) SENSITIVE = [:owner_information, :description] include Aws::Structure end |