Class: Aws::SSM::Types::UpdateOpsItemRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actual_end_timeTime

The time a runbook workflow ended. Currently reported only for the OpsItem type /aws/changerequest.

Returns:

  • (Time)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#actual_start_timeTime

The time a runbook workflow started. Currently reported only for the OpsItem type /aws/changerequest.

Returns:

  • (Time)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#categoryString

Specify a new category for an OpsItem.

Returns:

  • (String)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

User-defined text that contains information about the OpsItem, in Markdown format.

Returns:

  • (String)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#notificationsArray<Types::OpsItemNotification>

The Amazon Resource Name (ARN) of an SNS topic where notifications are sent when this OpsItem is edited or changed.

Returns:



21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#operational_dataHash<String,Types::OpsItemDataValue>

Add new keys or edit existing key-value pairs of the OperationalData map in the OpsItem object.

Operational data is custom data that provides useful reference details about the OpsItem. For example, you can specify log files, error strings, license keys, troubleshooting tips, or other relevant data. You enter operational data as key-value pairs. The key has a maximum length of 128 characters. The value has a maximum size of 20 KB.

Operational data keys can't begin with the following: amazon, aws, amzn, ssm, /amazon, /aws, /amzn, /ssm.

You can choose to make the data searchable by other users in the account or you can restrict search access. Searchable data means that all users with access to the OpsItem Overview page (as provided by the DescribeOpsItems API operation) can view and search on the specified data. Operational data that isn't searchable is only viewable by users who have access to the OpsItem (as provided by the GetOpsItem API operation).

Use the /aws/resources key in OperationalData to specify a related resource in the request. Use the /aws/automations key in OperationalData to associate an Automation runbook with the OpsItem. To view Amazon Web Services CLI example commands that use these keys, see Creating OpsItems manually in the Amazon Web Services Systems Manager User Guide.

Returns:



21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#operational_data_to_deleteArray<String>

Keys that you want to remove from the OperationalData map.

Returns:

  • (Array<String>)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#ops_item_arnString

The OpsItem Amazon Resource Name (ARN).

Returns:

  • (String)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#ops_item_idString

The ID of the OpsItem.

Returns:

  • (String)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#planned_end_timeTime

The time specified in a change request for a runbook workflow to end. Currently supported only for the OpsItem type /aws/changerequest.

Returns:

  • (Time)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#planned_start_timeTime

The time specified in a change request for a runbook workflow to start. Currently supported only for the OpsItem type /aws/changerequest.

Returns:

  • (Time)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#priorityInteger

The importance of this OpsItem in relation to other OpsItems in the system.

Returns:

  • (Integer)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

One or more OpsItems that share something in common with the current OpsItems. For example, related OpsItems can include OpsItems with similar error messages, impacted resources, or statuses for the impacted resource.

Returns:



21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

Specify a new severity for an OpsItem.

Returns:

  • (String)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The OpsItem status. For more information, see Editing OpsItem details in the Amazon Web Services Systems Manager User Guide.

Returns:

  • (String)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

A short heading that describes the nature of the OpsItem and the impacted resource.

Returns:

  • (String)


21262
21263
21264
21265
21266
21267
21268
21269
21270
21271
21272
21273
21274
21275
21276
21277
21278
21279
21280
21281
# File 'lib/aws-sdk-ssm/types.rb', line 21262

class UpdateOpsItemRequest < Struct.new(
  :description,
  :operational_data,
  :operational_data_to_delete,
  :notifications,
  :priority,
  :related_ops_items,
  :status,
  :ops_item_id,
  :title,
  :category,
  :severity,
  :actual_start_time,
  :actual_end_time,
  :planned_start_time,
  :planned_end_time,
  :ops_item_arn)
  SENSITIVE = []
  include Aws::Structure
end