Class: Aws::SSM::Types::UpdatePatchBaselineRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approval_rulesTypes::PatchRuleGroup

A set of rules used to include patches in the baseline.



21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#approved_patchesArray<String>

A list of explicitly approved patches for the baseline.

For information about accepted formats for lists of approved patches and rejected patches, see Package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide.

Returns:

  • (Array<String>)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#approved_patches_compliance_levelString

Assigns a new compliance severity level to an existing patch baseline.

Returns:

  • (String)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#approved_patches_enable_non_securityBoolean

Indicates whether the list of approved patches includes non-security updates that should be applied to the managed nodes. The default value is false. Applies to Linux managed nodes only.

Returns:

  • (Boolean)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#available_security_updates_compliance_statusString

Indicates the status to be assigned to security patches that are available but not approved because they don't meet the installation criteria specified in the patch baseline.

Example scenario: Security patches that you might want installed can be skipped if you have specified a long period to wait after a patch is released before installation. If an update to the patch is released during your specified waiting period, the waiting period for installing the patch starts over. If the waiting period is too long, multiple versions of the patch could be released but never installed.

Supported for Windows Server managed nodes only.

Returns:

  • (String)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#baseline_idString

The ID of the patch baseline to update.

Returns:

  • (String)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the patch baseline.

Returns:

  • (String)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#global_filtersTypes::PatchFilterGroup

A set of global filters used to include patches in the baseline.

The GlobalFilters parameter can be configured only by using the CLI or an Amazon Web Services SDK. It can't be configured from the Patch Manager console, and its value isn't displayed in the console.



21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the patch baseline.

Returns:

  • (String)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#rejected_patchesArray<String>

A list of explicitly rejected patches for the baseline.

For information about accepted formats for lists of approved patches and rejected patches, see Package name formats for approved and rejected patch lists in the Amazon Web Services Systems Manager User Guide.

Returns:

  • (Array<String>)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#rejected_patches_actionString

The action for Patch Manager to take on patches included in the RejectedPackages list.

ALLOW_AS_DEPENDENCY

: Linux and macOS: A package in the rejected patches list is installed only if it is a dependency of another package. It is considered compliant with the patch baseline, and its status is reported as INSTALLED_OTHER. This is the default action if no option is specified.

**Windows Server**: Windows Server doesn't support the concept of
package dependencies. If a package in the rejected patches list
and already installed on the node, its status is reported as
`INSTALLED_OTHER`. Any package not already installed on the node
is skipped. This is the default action if no option is specified.

BLOCK

: All OSs: Packages in the rejected patches list, and packages that include them as dependencies, aren't installed by Patch Manager under any circumstances.

State value assignment for patch compliance:

* If a package was installed before it was added to the rejected
patches list, or is installed outside of Patch Manager
afterward, it's considered noncompliant with the patch baseline
and its status is reported as `INSTALLED_REJECTED`.

* If an update attempts to install a dependency package that is
now rejected by the baseline, when previous versions of the
package were not rejected, the package being updated is reported
as `MISSING` for `SCAN` operations and as `FAILED` for `INSTALL`
operations.

Returns:

  • (String)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#replaceBoolean

If True, then all fields that are required by the CreatePatchBaseline operation are also required for this API request. Optional fields that aren't specified are set to null.

Returns:

  • (Boolean)


21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::PatchSource>

Information about the patches to use to update the managed nodes, including target operating systems and source repositories. Applies to Linux managed nodes only.

Returns:



21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
# File 'lib/aws-sdk-ssm/types.rb', line 21452

class UpdatePatchBaselineRequest < Struct.new(
  :baseline_id,
  :name,
  :global_filters,
  :approval_rules,
  :approved_patches,
  :approved_patches_compliance_level,
  :approved_patches_enable_non_security,
  :rejected_patches,
  :rejected_patches_action,
  :description,
  :sources,
  :available_security_updates_compliance_status,
  :replace)
  SENSITIVE = []
  include Aws::Structure
end