Class: Aws::SSM::Types::UpdatePatchBaselineResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::UpdatePatchBaselineResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approval_rules ⇒ Types::PatchRuleGroup
A set of rules used to include patches in the baseline.
-
#approved_patches ⇒ Array<String>
A list of explicitly approved patches for the baseline.
-
#approved_patches_compliance_level ⇒ String
The compliance severity level assigned to the patch baseline after the update completed.
-
#approved_patches_enable_non_security ⇒ Boolean
Indicates whether the list of approved patches includes non-security updates that should be applied to the managed nodes.
-
#available_security_updates_compliance_status ⇒ String
Indicates the compliance status of managed nodes for which security-related patches are available but were not approved.
-
#baseline_id ⇒ String
The ID of the deleted patch baseline.
-
#created_date ⇒ Time
The date when the patch baseline was created.
-
#description ⇒ String
A description of the patch baseline.
-
#global_filters ⇒ Types::PatchFilterGroup
A set of global filters used to exclude patches from the baseline.
-
#modified_date ⇒ Time
The date when the patch baseline was last modified.
-
#name ⇒ String
The name of the patch baseline.
-
#operating_system ⇒ String
The operating system rule used by the updated patch baseline.
-
#rejected_patches ⇒ Array<String>
A list of explicitly rejected patches for the baseline.
-
#rejected_patches_action ⇒ String
The action specified to take on patches included in the
RejectedPatcheslist. -
#sources ⇒ Array<Types::PatchSource>
Information about the patches to use to update the managed nodes, including target operating systems and source repositories.
Instance Attribute Details
#approval_rules ⇒ Types::PatchRuleGroup
A set of rules used to include patches in the baseline.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#approved_patches ⇒ Array<String>
A list of explicitly approved patches for the baseline.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#approved_patches_compliance_level ⇒ String
The compliance severity level assigned to the patch baseline after the update completed.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#approved_patches_enable_non_security ⇒ Boolean
Indicates whether the list of approved patches includes non-security updates that should be applied to the managed nodes. The default value is false. Applies to Linux managed nodes only.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#available_security_updates_compliance_status ⇒ String
Indicates the compliance status of managed nodes for which security-related patches are available but were not approved. This preference is specified when the CreatePatchBaseline or UpdatePatchBaseline commands are run.
Applies to Windows Server managed nodes only.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#baseline_id ⇒ String
The ID of the deleted patch baseline.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date when the patch baseline was created.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the patch baseline.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#global_filters ⇒ Types::PatchFilterGroup
A set of global filters used to exclude patches from the baseline.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#modified_date ⇒ Time
The date when the patch baseline was last modified.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the patch baseline.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#operating_system ⇒ String
The operating system rule used by the updated patch baseline.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#rejected_patches ⇒ Array<String>
A list of explicitly rejected patches for the baseline.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#rejected_patches_action ⇒ String
The action specified to take on patches included in the RejectedPatches list. A patch can be allowed only if it is a dependency of another package, or blocked entirely along with packages that include it as a dependency.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::PatchSource>
Information about the patches to use to update the managed nodes, including target operating systems and source repositories. Applies to Linux managed nodes only.
21081 21082 21083 21084 21085 21086 21087 21088 21089 21090 21091 21092 21093 21094 21095 21096 21097 21098 21099 |
# File 'lib/aws-sdk-ssm/types.rb', line 21081 class UpdatePatchBaselineResult < Struct.new( :baseline_id, :name, :operating_system, :global_filters, :approval_rules, :approved_patches, :approved_patches_compliance_level, :approved_patches_enable_non_security, :rejected_patches, :rejected_patches_action, :created_date, :modified_date, :description, :sources, :available_security_updates_compliance_status) SENSITIVE = [] include Aws::Structure end |