Method: Aws::SSM::Types::UpdateServiceSettingRequest#setting_value

Defined in:
lib/aws-sdk-ssm/types.rb

#setting_valueString

The new value to specify for the service setting. The following list specifies the available values for each setting.

  • For /ssm/managed-instance/default-ec2-instance-management-role, enter the name of an IAM role.

  • For /ssm/automation/customer-script-log-destination, enter CloudWatch.

  • For /ssm/automation/customer-script-log-group-name, enter the name of an Amazon CloudWatch Logs log group.

  • For /ssm/documents/console/public-sharing-permission, enter Enable or Disable.

  • For /ssm/managed-instance/activation-tier, enter standard or advanced.

  • For /ssm/opsinsights/opscenter, enter Enabled or Disabled.

  • For /ssm/parameter-store/default-parameter-tier, enter Standard, Advanced, or Intelligent-Tiering

  • For /ssm/parameter-store/high-throughput-enabled, enter true or false.



20014
20015
20016
20017
20018
20019
# File 'lib/aws-sdk-ssm/types.rb', line 20014

class UpdateServiceSettingRequest < Struct.new(
  :setting_id,
  :setting_value)
  SENSITIVE = []
  include Aws::Structure
end