Class: Aws::SSM::Types::ValidateCloudConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ValidateCloudConnectorRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_connector_id ⇒ String
The ID of the cloud connector to validate.
-
#max_results ⇒ Integer
The maximum number of validation findings to return.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#cloud_connector_id ⇒ String
The ID of the cloud connector to validate.
21709 21710 21711 21712 21713 21714 21715 |
# File 'lib/aws-sdk-ssm/types.rb', line 21709 class ValidateCloudConnectorRequest < Struct.new( :cloud_connector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of validation findings to return.
21709 21710 21711 21712 21713 21714 21715 |
# File 'lib/aws-sdk-ssm/types.rb', line 21709 class ValidateCloudConnectorRequest < Struct.new( :cloud_connector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
21709 21710 21711 21712 21713 21714 21715 |
# File 'lib/aws-sdk-ssm/types.rb', line 21709 class ValidateCloudConnectorRequest < Struct.new( :cloud_connector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |