Class: Aws::SSM::Types::AssociationOverview
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::AssociationOverview
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about the association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_status_aggregated_count ⇒ Hash<String,Integer>
Returns the number of targets for the association status.
-
#detailed_status ⇒ String
A detailed status of the association.
-
#status ⇒ String
The status of the association.
Instance Attribute Details
#association_status_aggregated_count ⇒ Hash<String,Integer>
Returns the number of targets for the association status. For example, if you created an association with two managed nodes, and one of them was successful, this would return the count of managed nodes by status.
868 869 870 871 872 873 874 |
# File 'lib/aws-sdk-ssm/types.rb', line 868 class AssociationOverview < Struct.new( :status, :detailed_status, :association_status_aggregated_count) SENSITIVE = [] include Aws::Structure end |
#detailed_status ⇒ String
A detailed status of the association.
868 869 870 871 872 873 874 |
# File 'lib/aws-sdk-ssm/types.rb', line 868 class AssociationOverview < Struct.new( :status, :detailed_status, :association_status_aggregated_count) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the association. Status can be: Pending, Success, or Failed.
868 869 870 871 872 873 874 |
# File 'lib/aws-sdk-ssm/types.rb', line 868 class AssociationOverview < Struct.new( :status, :detailed_status, :association_status_aggregated_count) SENSITIVE = [] include Aws::Structure end |