Class: Aws::SSM::Types::AutomationExecutionInputs
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::AutomationExecutionInputs
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about the optional inputs that can be specified for an automation execution preview.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#parameters ⇒ Hash<String,Array<String>>
Information about parameters that can be specified for the preview operation.
-
#target_locations ⇒ Array<Types::TargetLocation>
Information about the Amazon Web Services Regions and Amazon Web Services accounts targeted by the Automation execution preview operation.
-
#target_locations_url ⇒ String
A publicly accessible URL for a file that contains the
TargetLocationsbody. -
#target_maps ⇒ Array<Hash<String,Array<String>>>
A key-value mapping of document parameters to target resources.
-
#target_parameter_name ⇒ String
The name of the parameter used as the target resource for the rate-controlled execution.
-
#targets ⇒ Array<Types::Target>
Information about the resources that would be included in the actual runbook execution, if it were to be run.
Instance Attribute Details
#parameters ⇒ Hash<String,Array<String>>
Information about parameters that can be specified for the preview operation.
1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/aws-sdk-ssm/types.rb', line 1514 class AutomationExecutionInputs < Struct.new( :parameters, :target_parameter_name, :targets, :target_maps, :target_locations, :target_locations_url) SENSITIVE = [] include Aws::Structure end |
#target_locations ⇒ Array<Types::TargetLocation>
Information about the Amazon Web Services Regions and Amazon Web Services accounts targeted by the Automation execution preview operation.
1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/aws-sdk-ssm/types.rb', line 1514 class AutomationExecutionInputs < Struct.new( :parameters, :target_parameter_name, :targets, :target_maps, :target_locations, :target_locations_url) SENSITIVE = [] include Aws::Structure end |
#target_locations_url ⇒ String
A publicly accessible URL for a file that contains the TargetLocations body. Currently, only files in presigned Amazon S3 buckets are supported.
1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/aws-sdk-ssm/types.rb', line 1514 class AutomationExecutionInputs < Struct.new( :parameters, :target_parameter_name, :targets, :target_maps, :target_locations, :target_locations_url) SENSITIVE = [] include Aws::Structure end |
#target_maps ⇒ Array<Hash<String,Array<String>>>
A key-value mapping of document parameters to target resources. Both Targets and TargetMaps can’t be specified together.
1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/aws-sdk-ssm/types.rb', line 1514 class AutomationExecutionInputs < Struct.new( :parameters, :target_parameter_name, :targets, :target_maps, :target_locations, :target_locations_url) SENSITIVE = [] include Aws::Structure end |
#target_parameter_name ⇒ String
The name of the parameter used as the target resource for the rate-controlled execution. Required if you specify targets.
1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/aws-sdk-ssm/types.rb', line 1514 class AutomationExecutionInputs < Struct.new( :parameters, :target_parameter_name, :targets, :target_maps, :target_locations, :target_locations_url) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<Types::Target>
Information about the resources that would be included in the actual runbook execution, if it were to be run. Both Targets and TargetMaps can’t be specified together.
1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/aws-sdk-ssm/types.rb', line 1514 class AutomationExecutionInputs < Struct.new( :parameters, :target_parameter_name, :targets, :target_maps, :target_locations, :target_locations_url) SENSITIVE = [] include Aws::Structure end |