Class: Aws::SSM::Types::AutomationExecutionMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Details about a specific Automation execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_configurationTypes::AlarmConfiguration

The details for the CloudWatch alarm applied to your automation.



1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#association_idString

The ID of a State Manager association used in the Automation operation.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#automation_execution_idString

The execution ID.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#automation_execution_statusString

The status of the execution.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#automation_subtypeString

The subtype of the Automation operation. Currently, the only supported value is ChangeRequest.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#automation_typeString

Use this filter with DescribeAutomationExecutions. Specify either Local or CrossAccount. CrossAccount is an Automation that runs in multiple Amazon Web Services Regions and Amazon Web Services accounts. For more information, see Running automations in multiple Amazon Web Services Regions and accounts in the Amazon Web Services Systems Manager User Guide.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#change_request_nameString

The name of the Change Manager change request.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#current_actionString

The action of the step that is currently running.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#current_step_nameString

The name of the step that is currently running.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#document_nameString

The name of the Automation runbook used during execution.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#document_versionString

The document version used during the execution.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#executed_byString

The IAM role ARN of the user who ran the automation.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#execution_end_timeTime

The time the execution finished. This isn't populated if the execution is still in progress.

Returns:

  • (Time)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#execution_start_timeTime

The time the execution started.

Returns:

  • (Time)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

A message that describes a failure that occurred during the automation execution.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#log_fileString

An S3 bucket where execution information is stored.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#max_concurrencyString

The MaxConcurrency value specified by the user when starting the automation.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#max_errorsString

The MaxErrors value specified by the user when starting the automation.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

The Automation execution mode.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#ops_item_idString

The ID of an OpsItem that is created to represent a Change Manager change request.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#outputsHash<String,Array<String>>

The list of execution outputs as defined in the Automation runbook.

Returns:

  • (Hash<String,Array<String>>)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#parent_automation_execution_idString

The execution ID of the parent automation.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_targetsTypes::ResolvedTargets

A list of targets that resolved during the execution.



1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#runbooksArray<Types::Runbook>

Information about the Automation runbooks that are run during a runbook workflow in Change Manager.

The Automation runbooks specified for the runbook workflow can't run until all required approvals for the change request have been received.

Returns:



1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_timeTime

The date and time the Automation operation is scheduled to start.

Returns:

  • (Time)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#targetString

The list of execution outputs as defined in the Automation runbook.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#target_locations_urlString

A publicly accessible URL for a file that contains the TargetLocations body. Currently, only files in presigned Amazon S3 buckets are supported

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#target_mapsArray<Hash<String,Array<String>>>

The specified key-value mapping of document parameters to target resources.

Returns:

  • (Array<Hash<String,Array<String>>>)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#target_parameter_nameString

The list of execution outputs as defined in the Automation runbook.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#targetsArray<Types::Target>

The targets defined by the user when starting the automation.

Returns:



1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#triggered_alarmsArray<Types::AlarmStateInformation>

The CloudWatch alarm that was invoked by the automation.

Returns:



1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end

#warning_messageString

A message that describes a non-critical issue that occurred during the automation execution.

Returns:

  • (String)


1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/aws-sdk-ssm/types.rb', line 1704

class AutomationExecutionMetadata < Struct.new(
  :automation_execution_id,
  :document_name,
  :document_version,
  :automation_execution_status,
  :execution_start_time,
  :execution_end_time,
  :executed_by,
  :log_file,
  :outputs,
  :mode,
  :parent_automation_execution_id,
  :current_step_name,
  :current_action,
  :failure_message,
  :warning_message,
  :target_parameter_name,
  :targets,
  :target_maps,
  :resolved_targets,
  :max_concurrency,
  :max_errors,
  :target,
  :automation_type,
  :alarm_configuration,
  :triggered_alarms,
  :target_locations_url,
  :automation_subtype,
  :scheduled_time,
  :runbooks,
  :ops_item_id,
  :association_id,
  :change_request_name)
  SENSITIVE = []
  include Aws::Structure
end