Class: Aws::SSM::Types::AzureConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::AzureConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The access details and targets for connecting to a Microsoft Azure tenant, including the application registration used for authentication and the subscriptions to target.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_display_name ⇒ String
The display name of the Azure application registration.
-
#application_id ⇒ String
The ID of the Azure application registration used for authentication.
-
#targets ⇒ Types::ConfigurationTargets
The target Azure subscriptions for the cloud connector.
-
#tenant_display_name ⇒ String
The display name of the Azure tenant.
-
#tenant_id ⇒ String
The ID of the Azure tenant.
Instance Attribute Details
#application_display_name ⇒ String
The display name of the Azure application registration.
1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-ssm/types.rb', line 1832 class AzureConfiguration < Struct.new( :tenant_id, :tenant_display_name, :application_id, :application_display_name, :targets) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
The ID of the Azure application registration used for authentication.
1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-ssm/types.rb', line 1832 class AzureConfiguration < Struct.new( :tenant_id, :tenant_display_name, :application_id, :application_display_name, :targets) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Types::ConfigurationTargets
The target Azure subscriptions for the cloud connector.
1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-ssm/types.rb', line 1832 class AzureConfiguration < Struct.new( :tenant_id, :tenant_display_name, :application_id, :application_display_name, :targets) SENSITIVE = [] include Aws::Structure end |
#tenant_display_name ⇒ String
The display name of the Azure tenant.
1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-ssm/types.rb', line 1832 class AzureConfiguration < Struct.new( :tenant_id, :tenant_display_name, :application_id, :application_display_name, :targets) SENSITIVE = [] include Aws::Structure end |
#tenant_id ⇒ String
The ID of the Azure tenant.
1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-ssm/types.rb', line 1832 class AzureConfiguration < Struct.new( :tenant_id, :tenant_display_name, :application_id, :application_display_name, :targets) SENSITIVE = [] include Aws::Structure end |