Class: Aws::SSM::Types::CancelCommandRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::CancelCommandRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command_id ⇒ String
The ID of the command you want to cancel.
-
#instance_ids ⇒ Array<String>
(Optional) A list of managed node IDs on which you want to cancel the command.
Instance Attribute Details
#command_id ⇒ String
The ID of the command you want to cancel.
1979 1980 1981 1982 1983 1984 |
# File 'lib/aws-sdk-ssm/types.rb', line 1979 class CancelCommandRequest < Struct.new( :command_id, :instance_ids) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
(Optional) A list of managed node IDs on which you want to cancel the command. If not provided, the command is canceled on every node on which it was requested.
1979 1980 1981 1982 1983 1984 |
# File 'lib/aws-sdk-ssm/types.rb', line 1979 class CancelCommandRequest < Struct.new( :command_id, :instance_ids) SENSITIVE = [] include Aws::Structure end |