Class: Aws::SSM::Types::CloudConnectorConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::CloudConnectorConfiguration
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Note:
CloudConnectorConfiguration is a union - when making an API calls you must set exactly one of the members.
Note:
CloudConnectorConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CloudConnectorConfiguration corresponding to the set member.
The configuration that provides access details and targets for connecting to a third-party cloud environment.
Defined Under Namespace
Classes: AzureConfiguration, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#azure_configuration ⇒ Types::AzureConfiguration
The access details and targets for connecting to a Microsoft Azure environment.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#azure_configuration ⇒ Types::AzureConfiguration
The access details and targets for connecting to a Microsoft Azure environment.
2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-ssm/types.rb', line 2018 class CloudConnectorConfiguration < Struct.new( :azure_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AzureConfiguration < CloudConnectorConfiguration; end class Unknown < CloudConnectorConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2018 2019 2020 |
# File 'lib/aws-sdk-ssm/types.rb', line 2018 def unknown @unknown end |