Class: Aws::SSM::Types::CreateAssociationBatchRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::CreateAssociationBatchRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_dispatch_assume_role ⇒ String
A role used by association to take actions on your behalf.
-
#entries ⇒ Array<Types::CreateAssociationBatchRequestEntry>
One or more associations.
Instance Attribute Details
#association_dispatch_assume_role ⇒ String
A role used by association to take actions on your behalf. State Manager will assume this role and call required APIs when dispatching configurations to nodes. If not specified, service-linked role for Systems Manager will be used by default.
Service-linked role support in State Manager is being phased out. Associations relying on service-linked role may require updates in the future to continue functioning properly.
3189 3190 3191 3192 3193 3194 |
# File 'lib/aws-sdk-ssm/types.rb', line 3189 class CreateAssociationBatchRequest < Struct.new( :entries, :association_dispatch_assume_role) SENSITIVE = [] include Aws::Structure end |
#entries ⇒ Array<Types::CreateAssociationBatchRequestEntry>
One or more associations.
3189 3190 3191 3192 3193 3194 |
# File 'lib/aws-sdk-ssm/types.rb', line 3189 class CreateAssociationBatchRequest < Struct.new( :entries, :association_dispatch_assume_role) SENSITIVE = [] include Aws::Structure end |