Method: Aws::SSM::Types::CreateAssociationBatchRequestEntry#name
- Defined in:
- lib/aws-sdk-ssm/types.rb
#name ⇒ String
The name of the SSM document that contains the configuration information for the managed node. You can specify Command or Automation runbooks.
You can specify Amazon Web Services-predefined documents, documents you created, or a document that is shared with you from another account.
For SSM documents that are shared with you from other Amazon Web Services accounts, you must specify the complete SSM document ARN, in the following format:
‘arn:aws:ssm:region:account-id:document/document-name `
For example:
arn:aws:ssm:us-east-2:12345678912:document/My-Shared-Document
For Amazon Web Services-predefined documents and SSM documents you created in your account, you only need to specify the document name. For example, AWS-ApplyPatchBaseline or My-Document.
3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 |
# File 'lib/aws-sdk-ssm/types.rb', line 3208 class CreateAssociationBatchRequestEntry < Struct.new( :name, :instance_id, :parameters, :automation_target_parameter_name, :document_version, :targets, :schedule_expression, :output_location, :association_name, :max_errors, :max_concurrency, :compliance_severity, :sync_compliance, :apply_only_at_cron_interval, :calendar_names, :target_locations, :schedule_offset, :duration, :target_maps, :alarm_configuration) SENSITIVE = [:parameters] include Aws::Structure end |