Class: Aws::SSM::Types::DeleteInventoryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DeleteInventoryResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deletion_id ⇒ String
Every
DeleteInventoryoperation is assigned a unique ID. -
#deletion_summary ⇒ Types::InventoryDeletionSummary
A summary of the delete operation.
-
#type_name ⇒ String
The name of the inventory data type specified in the request.
Instance Attribute Details
#deletion_id ⇒ String
Every DeleteInventory operation is assigned a unique ID. This
option returns a unique ID. You can use this ID to query the status
of a delete operation. This option is useful for ensuring that a
delete operation has completed before you begin other operations.
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-ssm/types.rb', line 4780 class DeleteInventoryResult < Struct.new( :deletion_id, :type_name, :deletion_summary) SENSITIVE = [] include Aws::Structure end |
#deletion_summary ⇒ Types::InventoryDeletionSummary
A summary of the delete operation. For more information about this summary, see Deleting custom inventory in the Amazon Web Services Systems Manager User Guide.
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-ssm/types.rb', line 4780 class DeleteInventoryResult < Struct.new( :deletion_id, :type_name, :deletion_summary) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the inventory data type specified in the request.
4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/aws-sdk-ssm/types.rb', line 4780 class DeleteInventoryResult < Struct.new( :deletion_id, :type_name, :deletion_summary) SENSITIVE = [] include Aws::Structure end |