Method: Aws::SSM::Types::DescribeAutomationExecutionsResult#next_token
- Defined in:
- lib/aws-sdk-ssm/types.rb
#next_token ⇒ String
The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-ssm/types.rb', line 5095 class DescribeAutomationExecutionsResult < Struct.new( :automation_execution_metadata_list, :next_token) SENSITIVE = [] include Aws::Structure end |