Class: Aws::SSM::Types::DescribeMaintenanceWindowTargetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DescribeMaintenanceWindowTargetsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::MaintenanceWindowFilter>
Optional filters that can be used to narrow down the scope of the returned window targets.
-
#max_results ⇒ Integer
The maximum number of items to return for this call.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#window_id ⇒ String
The ID of the maintenance window whose targets should be retrieved.
Instance Attribute Details
#filters ⇒ Array<Types::MaintenanceWindowFilter>
Optional filters that can be used to narrow down the scope of the returned window targets. The supported filter keys are Type, WindowTargetId, and OwnerInformation.
5789 5790 5791 5792 5793 5794 5795 5796 |
# File 'lib/aws-sdk-ssm/types.rb', line 5789 class DescribeMaintenanceWindowTargetsRequest < Struct.new( :window_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
5789 5790 5791 5792 5793 5794 5795 5796 |
# File 'lib/aws-sdk-ssm/types.rb', line 5789 class DescribeMaintenanceWindowTargetsRequest < Struct.new( :window_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5789 5790 5791 5792 5793 5794 5795 5796 |
# File 'lib/aws-sdk-ssm/types.rb', line 5789 class DescribeMaintenanceWindowTargetsRequest < Struct.new( :window_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#window_id ⇒ String
The ID of the maintenance window whose targets should be retrieved.
5789 5790 5791 5792 5793 5794 5795 5796 |
# File 'lib/aws-sdk-ssm/types.rb', line 5789 class DescribeMaintenanceWindowTargetsRequest < Struct.new( :window_id, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |