Class: Aws::SSM::Types::DescribePatchGroupStateResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DescribePatchGroupStateResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Integer
The number of managed nodes in the patch group.
-
#instances_with_available_security_updates ⇒ Integer
The number of managed nodes for which security-related patches are available but not approved because because they didn’t meet the patch baseline requirements.
-
#instances_with_critical_non_compliant_patches ⇒ Integer
The number of managed nodes where patches that are specified as ‘Critical` for compliance reporting in the patch baseline aren’t installed.
-
#instances_with_failed_patches ⇒ Integer
The number of managed nodes with patches from the patch baseline that failed to install.
-
#instances_with_installed_other_patches ⇒ Integer
The number of managed nodes with patches installed that aren’t defined in the patch baseline.
-
#instances_with_installed_patches ⇒ Integer
The number of managed nodes with installed patches.
-
#instances_with_installed_pending_reboot_patches ⇒ Integer
The number of managed nodes with patches installed by Patch Manager that haven’t been rebooted after the patch installation.
-
#instances_with_installed_rejected_patches ⇒ Integer
The number of managed nodes with patches installed that are specified in a ‘RejectedPatches` list.
-
#instances_with_missing_patches ⇒ Integer
The number of managed nodes with missing patches from the patch baseline.
-
#instances_with_not_applicable_patches ⇒ Integer
The number of managed nodes with patches that aren’t applicable.
-
#instances_with_other_non_compliant_patches ⇒ Integer
The number of managed nodes with patches installed that are specified as other than ‘Critical` or `Security` but aren’t compliant with the patch baseline.
-
#instances_with_security_non_compliant_patches ⇒ Integer
The number of managed nodes where patches that are specified as ‘Security` in a patch advisory aren’t installed.
-
#instances_with_unreported_not_applicable_patches ⇒ Integer
The number of managed nodes with ‘NotApplicable` patches beyond the supported limit, which aren’t reported by name to Inventory.
Instance Attribute Details
#instances ⇒ Integer
The number of managed nodes in the patch group.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_available_security_updates ⇒ Integer
The number of managed nodes for which security-related patches are available but not approved because because they didn’t meet the patch baseline requirements. For example, an updated version of a patch might have been released before the specified auto-approval period was over.
Applies to Windows Server managed nodes only.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_critical_non_compliant_patches ⇒ Integer
The number of managed nodes where patches that are specified as ‘Critical` for compliance reporting in the patch baseline aren’t installed. These patches might be missing, have failed installation, were rejected, or were installed but awaiting a required managed node reboot. The status of these managed nodes is ‘NON_COMPLIANT`.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_failed_patches ⇒ Integer
The number of managed nodes with patches from the patch baseline that failed to install.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_installed_other_patches ⇒ Integer
The number of managed nodes with patches installed that aren’t defined in the patch baseline.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_installed_patches ⇒ Integer
The number of managed nodes with installed patches.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_installed_pending_reboot_patches ⇒ Integer
The number of managed nodes with patches installed by Patch Manager that haven’t been rebooted after the patch installation. The status of these managed nodes is ‘NON_COMPLIANT`.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_installed_rejected_patches ⇒ Integer
The number of managed nodes with patches installed that are specified in a ‘RejectedPatches` list. Patches with a status of `INSTALLED_REJECTED` were typically installed before they were added to a `RejectedPatches` list.
<note markdown=“1”> If ‘ALLOW_AS_DEPENDENCY` is the specified option for `RejectedPatchesAction`, the value of `InstancesWithInstalledRejectedPatches` will always be `0` (zero).
</note>
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_missing_patches ⇒ Integer
The number of managed nodes with missing patches from the patch baseline.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_not_applicable_patches ⇒ Integer
The number of managed nodes with patches that aren’t applicable.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_other_non_compliant_patches ⇒ Integer
The number of managed nodes with patches installed that are specified as other than ‘Critical` or `Security` but aren’t compliant with the patch baseline. The status of these managed nodes is ‘NON_COMPLIANT`.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_security_non_compliant_patches ⇒ Integer
The number of managed nodes where patches that are specified as ‘Security` in a patch advisory aren’t installed. These patches might be missing, have failed installation, were rejected, or were installed but awaiting a required managed node reboot. The status of these managed nodes is ‘NON_COMPLIANT`.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |
#instances_with_unreported_not_applicable_patches ⇒ Integer
The number of managed nodes with ‘NotApplicable` patches beyond the supported limit, which aren’t reported by name to Inventory. Inventory is a tool in Amazon Web Services Systems Manager.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-ssm/types.rb', line 6613 class DescribePatchGroupStateResult < Struct.new( :instances, :instances_with_installed_patches, :instances_with_installed_other_patches, :instances_with_installed_pending_reboot_patches, :instances_with_installed_rejected_patches, :instances_with_missing_patches, :instances_with_failed_patches, :instances_with_not_applicable_patches, :instances_with_unreported_not_applicable_patches, :instances_with_critical_non_compliant_patches, :instances_with_security_non_compliant_patches, :instances_with_other_non_compliant_patches, :instances_with_available_security_updates) SENSITIVE = [] include Aws::Structure end |