Class: Aws::SSM::Types::DocumentDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DocumentDescription
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Describes an Amazon Web Services Systems Manager document (SSM document).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approved_version ⇒ String
The version of the document currently approved for use in the organization.
-
#attachments_information ⇒ Array<Types::AttachmentInformation>
Details about the document attachments, including names, locations, sizes, and so on.
-
#author ⇒ String
The user in your organization who created the document.
-
#category ⇒ Array<String>
The classification of a document to help you identify and categorize its use.
-
#category_enum ⇒ Array<String>
The value that identifies a document’s category.
-
#created_date ⇒ Time
The date when the document was created.
-
#default_version ⇒ String
The default version.
-
#description ⇒ String
A description of the document.
-
#display_name ⇒ String
The friendly name of the SSM document.
-
#document_format ⇒ String
The document format, either JSON or YAML.
-
#document_type ⇒ String
The type of document.
-
#document_version ⇒ String
The document version.
-
#hash ⇒ String
The Sha256 or Sha1 hash created by the system when the document was created.
-
#hash_type ⇒ String
The hash type of the document.
-
#latest_version ⇒ String
The latest version of the document.
-
#name ⇒ String
The name of the SSM document.
-
#owner ⇒ String
The Amazon Web Services user that created the document.
-
#parameters ⇒ Array<Types::DocumentParameter>
A description of the parameters for a document.
-
#pending_review_version ⇒ String
The version of the document that is currently under review.
-
#platform_types ⇒ Array<String>
The list of operating system (OS) platforms compatible with this SSM document.
-
#requires ⇒ Array<Types::DocumentRequires>
A list of SSM documents required by a document.
-
#review_information ⇒ Array<Types::ReviewInformation>
Details about the review of a document.
-
#review_status ⇒ String
The current status of the review.
-
#schema_version ⇒ String
The schema version.
-
#sha_1 ⇒ String
The SHA1 hash of the document, which you can use for verification.
-
#status ⇒ String
The status of the SSM document.
-
#status_information ⇒ String
A message returned by Amazon Web Services Systems Manager that explains the
Statusvalue. -
#tags ⇒ Array<Types::Tag>
The tags, or metadata, that have been applied to the document.
-
#target_type ⇒ String
The target type which defines the kinds of resources the document can run on.
-
#version_name ⇒ String
The version of the artifact associated with the document.
Instance Attribute Details
#approved_version ⇒ String
The version of the document currently approved for use in the organization.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#attachments_information ⇒ Array<Types::AttachmentInformation>
Details about the document attachments, including names, locations, sizes, and so on.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#author ⇒ String
The user in your organization who created the document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#category ⇒ Array<String>
The classification of a document to help you identify and categorize its use.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#category_enum ⇒ Array<String>
The value that identifies a document’s category.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date when the document was created.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#default_version ⇒ String
The default version.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The friendly name of the SSM document. This value can differ for each version of the document. If you want to update this value, see UpdateDocument.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#document_format ⇒ String
The document format, either JSON or YAML.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#document_type ⇒ String
The type of document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The document version.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#hash ⇒ String
The Sha256 or Sha1 hash created by the system when the document was created.
<note markdown=“1”> Sha1 hashes have been deprecated.
</note>
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#hash_type ⇒ String
The hash type of the document. Valid values include Sha256 or Sha1.
<note markdown=“1”> Sha1 hashes have been deprecated.
</note>
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#latest_version ⇒ String
The latest version of the document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SSM document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The Amazon Web Services user that created the document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::DocumentParameter>
A description of the parameters for a document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#pending_review_version ⇒ String
The version of the document that is currently under review.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#platform_types ⇒ Array<String>
The list of operating system (OS) platforms compatible with this SSM document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#requires ⇒ Array<Types::DocumentRequires>
A list of SSM documents required by a document. For example, an ApplicationConfiguration document requires an ApplicationConfigurationSchema document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#review_information ⇒ Array<Types::ReviewInformation>
Details about the review of a document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#review_status ⇒ String
The current status of the review.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#schema_version ⇒ String
The schema version.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#sha_1 ⇒ String
The SHA1 hash of the document, which you can use for verification.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the SSM document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#status_information ⇒ String
A message returned by Amazon Web Services Systems Manager that explains the Status value. For example, a Failed status might be explained by the StatusInformation message, “The specified S3 bucket doesn’t exist. Verify that the URL of the S3 bucket is correct.”
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags, or metadata, that have been applied to the document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
The target type which defines the kinds of resources the document can run on. For example, /AWS::EC2::Instance. For a list of valid resource types, see [Amazon Web Services resource and property types reference] in the *CloudFormation User Guide*.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
The version of the artifact associated with the document.
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 |
# File 'lib/aws-sdk-ssm/types.rb', line 7008 class DocumentDescription < Struct.new( :sha_1, :hash, :hash_type, :name, :display_name, :version_name, :owner, :created_date, :status, :status_information, :document_version, :description, :parameters, :platform_types, :document_type, :schema_version, :latest_version, :default_version, :document_format, :target_type, :tags, :attachments_information, :requires, :author, :review_information, :approved_version, :pending_review_version, :review_status, :category, :category_enum) SENSITIVE = [] include Aws::Structure end |