Class: Aws::SSM::Types::DocumentIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DocumentIdentifier
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Describes the name of a SSM document.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#author ⇒ String
The user in your organization who created the document.
-
#created_date ⇒ Time
The date the SSM document was created.
-
#display_name ⇒ String
An optional field where you can specify a friendly name for the SSM document.
-
#document_format ⇒ String
The document format, either JSON or YAML.
-
#document_type ⇒ String
The document type.
-
#document_version ⇒ String
The document version.
-
#name ⇒ String
The name of the SSM document.
-
#owner ⇒ String
The Amazon Web Services user that created the document.
-
#platform_types ⇒ Array<String>
The operating system platform.
-
#requires ⇒ Array<Types::DocumentRequires>
A list of SSM documents required by a document.
-
#review_status ⇒ String
The current status of a document review.
-
#schema_version ⇒ String
The schema version.
-
#tags ⇒ Array<Types::Tag>
The tags, or metadata, that have been applied to the document.
-
#target_type ⇒ String
The target type which defines the kinds of resources the document can run on.
-
#version_name ⇒ String
An optional field specifying the version of the artifact associated with the document.
Instance Attribute Details
#author ⇒ String
The user in your organization who created the document.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date the SSM document was created.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
An optional field where you can specify a friendly name for the SSM document. This value can differ for each version of the document. If you want to update this value, see UpdateDocument.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#document_format ⇒ String
The document format, either JSON or YAML.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#document_type ⇒ String
The document type.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The document version.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SSM document.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The Amazon Web Services user that created the document.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#platform_types ⇒ Array<String>
The operating system platform.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#requires ⇒ Array<Types::DocumentRequires>
A list of SSM documents required by a document. For example, an
ApplicationConfiguration document requires an
ApplicationConfigurationSchema document.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#review_status ⇒ String
The current status of a document review.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#schema_version ⇒ String
The schema version.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags, or metadata, that have been applied to the document.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
The target type which defines the kinds of resources the document
can run on. For example, /AWS::EC2::Instance. For a list of valid
resource types, see Amazon Web Services resource and property types
reference in the CloudFormation User Guide.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
An optional field specifying the version of the artifact associated with the document. For example, 12.6. This value is unique across all versions of a document, and can't be changed.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 |
# File 'lib/aws-sdk-ssm/types.rb', line 7405 class DocumentIdentifier < Struct.new( :name, :created_date, :display_name, :owner, :version_name, :platform_types, :document_version, :document_type, :schema_version, :document_format, :target_type, :tags, :requires, :review_status, :author) SENSITIVE = [] include Aws::Structure end |