Class: Aws::SSM::Types::DocumentVersionInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::DocumentVersionInfo
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Version information about the document.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_date ⇒ Time
The date the document was created.
-
#display_name ⇒ String
The friendly name of the SSM document.
-
#document_format ⇒ String
The document format, either JSON or YAML.
-
#document_version ⇒ String
The document version.
-
#is_default_version ⇒ Boolean
An identifier for the default version of the document.
-
#name ⇒ String
The document name.
-
#review_status ⇒ String
The current status of the approval review for the latest version of the document.
-
#status ⇒ String
The status of the SSM document, such as
Creating,Active,Failed, andDeleting. -
#status_information ⇒ String
A message returned by Amazon Web Services Systems Manager that explains the
Statusvalue. -
#version_name ⇒ String
The version of the artifact associated with the document.
Instance Attribute Details
#created_date ⇒ Time
The date the document was created.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The friendly name of the SSM document. This value can differ for each version of the document. If you want to update this value, see UpdateDocument.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#document_format ⇒ String
The document format, either JSON or YAML.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The document version.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#is_default_version ⇒ Boolean
An identifier for the default version of the document.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The document name.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#review_status ⇒ String
The current status of the approval review for the latest version of the document.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the SSM document, such as Creating, Active,
Failed, and Deleting.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#status_information ⇒ String
A message returned by Amazon Web Services Systems Manager that
explains the Status value. For example, a Failed status might be
explained by the StatusInformation message, "The specified S3
bucket doesn't exist. Verify that the URL of the S3 bucket is
correct."
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
The version of the artifact associated with the document. For example, 12.6. This value is unique across all versions of a document, and can't be changed.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 |
# File 'lib/aws-sdk-ssm/types.rb', line 7773 class DocumentVersionInfo < Struct.new( :name, :display_name, :document_version, :version_name, :created_date, :is_default_version, :document_format, :status, :status_information, :review_status) SENSITIVE = [] include Aws::Structure end |