Class: Aws::SSM::Types::GetAutomationExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetAutomationExecutionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automation_execution_id ⇒ String
The unique identifier for an existing automation execution to examine.
Instance Attribute Details
#automation_execution_id ⇒ String
The unique identifier for an existing automation execution to examine. The execution ID is returned by StartAutomationExecution when the execution of an Automation runbook is initiated.
8047 8048 8049 8050 8051 |
# File 'lib/aws-sdk-ssm/types.rb', line 8047 class GetAutomationExecutionRequest < Struct.new( :automation_execution_id) SENSITIVE = [] include Aws::Structure end |