Class: Aws::SSM::Types::GetCalendarStateRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#at_timeString

(Optional) The specific time for which you want to get calendar state information, in [ISO 8601][1] format. If you don’t specify a value or AtTime, the current time is used.

[1]: en.wikipedia.org/wiki/ISO_8601



7401
7402
7403
7404
7405
7406
# File 'lib/aws-sdk-ssm/types.rb', line 7401

class GetCalendarStateRequest < Struct.new(
  :calendar_names,
  :at_time)
  SENSITIVE = []
  include Aws::Structure
end

#calendar_namesArray<String>

The names or Amazon Resource Names (ARNs) of the Systems Manager documents (SSM documents) that represent the calendar entries for which you want to get the state.



7401
7402
7403
7404
7405
7406
# File 'lib/aws-sdk-ssm/types.rb', line 7401

class GetCalendarStateRequest < Struct.new(
  :calendar_names,
  :at_time)
  SENSITIVE = []
  include Aws::Structure
end