Class: Aws::SSM::Types::GetCloudConnectorResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetCloudConnectorResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_connector_arn ⇒ String
The ARN of the cloud connector.
-
#config_connector_arn ⇒ String
The ARN of the Amazon Web Services Config connector associated with this cloud connector.
-
#configuration ⇒ Types::CloudConnectorConfiguration
The configuration details for the third-party cloud environment connection.
-
#created_at ⇒ Time
The date and time the cloud connector was created.
-
#description ⇒ String
The description of the cloud connector.
-
#display_name ⇒ String
The friendly name of the cloud connector.
-
#role_arn ⇒ String
The ARN of the IAM role used by the cloud connector.
-
#updated_at ⇒ Time
The date and time the cloud connector was last updated.
Instance Attribute Details
#cloud_connector_arn ⇒ String
The ARN of the cloud connector.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/aws-sdk-ssm/types.rb', line 8163 class GetCloudConnectorResult < Struct.new( :cloud_connector_arn, :display_name, :description, :role_arn, :configuration, :config_connector_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#config_connector_arn ⇒ String
The ARN of the Amazon Web Services Config connector associated with this cloud connector.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/aws-sdk-ssm/types.rb', line 8163 class GetCloudConnectorResult < Struct.new( :cloud_connector_arn, :display_name, :description, :role_arn, :configuration, :config_connector_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::CloudConnectorConfiguration
The configuration details for the third-party cloud environment connection.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/aws-sdk-ssm/types.rb', line 8163 class GetCloudConnectorResult < Struct.new( :cloud_connector_arn, :display_name, :description, :role_arn, :configuration, :config_connector_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the cloud connector was created.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/aws-sdk-ssm/types.rb', line 8163 class GetCloudConnectorResult < Struct.new( :cloud_connector_arn, :display_name, :description, :role_arn, :configuration, :config_connector_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the cloud connector.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/aws-sdk-ssm/types.rb', line 8163 class GetCloudConnectorResult < Struct.new( :cloud_connector_arn, :display_name, :description, :role_arn, :configuration, :config_connector_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The friendly name of the cloud connector.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/aws-sdk-ssm/types.rb', line 8163 class GetCloudConnectorResult < Struct.new( :cloud_connector_arn, :display_name, :description, :role_arn, :configuration, :config_connector_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role used by the cloud connector.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/aws-sdk-ssm/types.rb', line 8163 class GetCloudConnectorResult < Struct.new( :cloud_connector_arn, :display_name, :description, :role_arn, :configuration, :config_connector_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the cloud connector was last updated.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/aws-sdk-ssm/types.rb', line 8163 class GetCloudConnectorResult < Struct.new( :cloud_connector_arn, :display_name, :description, :role_arn, :configuration, :config_connector_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |