Class: Aws::SSM::Types::GetDeployablePatchSnapshotForInstanceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetDeployablePatchSnapshotForInstanceResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_id ⇒ String
The managed node ID.
-
#product ⇒ String
Returns the specific operating system (for example Windows Server 2012 or Amazon Linux 2015.09) on the managed node for the specified patch snapshot.
-
#snapshot_download_url ⇒ String
A pre-signed Amazon Simple Storage Service (Amazon S3) URL that can be used to download the patch snapshot.
-
#snapshot_id ⇒ String
The user-defined snapshot ID.
Instance Attribute Details
#instance_id ⇒ String
The managed node ID.
8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-ssm/types.rb', line 8507 class GetDeployablePatchSnapshotForInstanceResult < Struct.new( :instance_id, :snapshot_id, :snapshot_download_url, :product) SENSITIVE = [] include Aws::Structure end |
#product ⇒ String
Returns the specific operating system (for example Windows Server 2012 or Amazon Linux 2015.09) on the managed node for the specified patch snapshot.
8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-ssm/types.rb', line 8507 class GetDeployablePatchSnapshotForInstanceResult < Struct.new( :instance_id, :snapshot_id, :snapshot_download_url, :product) SENSITIVE = [] include Aws::Structure end |
#snapshot_download_url ⇒ String
A pre-signed Amazon Simple Storage Service (Amazon S3) URL that can be used to download the patch snapshot.
8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-ssm/types.rb', line 8507 class GetDeployablePatchSnapshotForInstanceResult < Struct.new( :instance_id, :snapshot_id, :snapshot_download_url, :product) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The user-defined snapshot ID.
8507 8508 8509 8510 8511 8512 8513 8514 |
# File 'lib/aws-sdk-ssm/types.rb', line 8507 class GetDeployablePatchSnapshotForInstanceResult < Struct.new( :instance_id, :snapshot_id, :snapshot_download_url, :product) SENSITIVE = [] include Aws::Structure end |