Class: Aws::SSM::Types::GetDocumentResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetDocumentResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachments_content ⇒ Array<Types::AttachmentContent>
A description of the document attachments, including names, locations, sizes, and so on.
-
#content ⇒ String
The contents of the SSM document.
-
#created_date ⇒ Time
The date the SSM document was created.
-
#display_name ⇒ String
The friendly name of the SSM document.
-
#document_format ⇒ String
The document format, either JSON or YAML.
-
#document_type ⇒ String
The document type.
-
#document_version ⇒ String
The document version.
-
#name ⇒ String
The name of the SSM document.
-
#requires ⇒ Array<Types::DocumentRequires>
A list of SSM documents required by a document.
-
#review_status ⇒ String
The current review status of a new custom Systems Manager document (SSM document) created by a member of your organization, or of the latest version of an existing SSM document.
-
#status ⇒ String
The status of the SSM document, such as
Creating,Active,Updating,Failed, andDeleting. -
#status_information ⇒ String
A message returned by Amazon Web Services Systems Manager that explains the
Statusvalue. -
#version_name ⇒ String
The version of the artifact associated with the document.
Instance Attribute Details
#attachments_content ⇒ Array<Types::AttachmentContent>
A description of the document attachments, including names, locations, sizes, and so on.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
The contents of the SSM document.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date the SSM document was created.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The friendly name of the SSM document. This value can differ for each version of the document. If you want to update this value, see UpdateDocument.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#document_format ⇒ String
The document format, either JSON or YAML.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#document_type ⇒ String
The document type.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The document version.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SSM document.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#requires ⇒ Array<Types::DocumentRequires>
A list of SSM documents required by a document. For example, an ApplicationConfiguration document requires an ApplicationConfigurationSchema document.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#review_status ⇒ String
The current review status of a new custom Systems Manager document (SSM document) created by a member of your organization, or of the latest version of an existing SSM document.
Only one version of an SSM document can be in the APPROVED state at a time. When a new version is approved, the status of the previous version changes to REJECTED.
Only one version of an SSM document can be in review, or PENDING, at a time.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the SSM document, such as Creating, Active, Updating, Failed, and Deleting.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#status_information ⇒ String
A message returned by Amazon Web Services Systems Manager that explains the Status value. For example, a Failed status might be explained by the StatusInformation message, “The specified S3 bucket doesn’t exist. Verify that the URL of the S3 bucket is correct.”
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
The version of the artifact associated with the document. For example, 12.6. This value is unique across all versions of a document, and can’t be changed.
8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/aws-sdk-ssm/types.rb', line 8294 class GetDocumentResult < Struct.new( :name, :created_date, :display_name, :version_name, :document_version, :status, :status_information, :content, :document_type, :document_format, :requires, :attachments_content, :review_status) SENSITIVE = [] include Aws::Structure end |