Class: Aws::SSM::Types::GetMaintenanceWindowExecutionTaskInvocationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetMaintenanceWindowExecutionTaskInvocationResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:parameters, :owner_information]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The time that the task finished running on the target.
-
#execution_id ⇒ String
The execution ID.
-
#invocation_id ⇒ String
The invocation ID.
-
#owner_information ⇒ String
User-provided value to be included in any Amazon CloudWatch Events or Amazon EventBridge events raised while running tasks for these targets in this maintenance window.
-
#parameters ⇒ String
The parameters used at the time that the task ran.
-
#start_time ⇒ Time
The time that the task started running on the target.
-
#status ⇒ String
The task status for an invocation.
-
#status_details ⇒ String
The details explaining the status.
-
#task_execution_id ⇒ String
The task execution ID.
-
#task_type ⇒ String
Retrieves the task type for a maintenance window.
-
#window_execution_id ⇒ String
The maintenance window execution ID.
-
#window_target_id ⇒ String
The maintenance window target ID.
Instance Attribute Details
#end_time ⇒ Time
The time that the task finished running on the target.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#execution_id ⇒ String
The execution ID.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#invocation_id ⇒ String
The invocation ID.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#owner_information ⇒ String
User-provided value to be included in any Amazon CloudWatch Events or Amazon EventBridge events raised while running tasks for these targets in this maintenance window.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#parameters ⇒ String
The parameters used at the time that the task ran.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#start_time ⇒ Time
The time that the task started running on the target.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#status ⇒ String
The task status for an invocation.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#status_details ⇒ String
The details explaining the status. Details are only available for certain status values.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#task_execution_id ⇒ String
The task execution ID.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#task_type ⇒ String
Retrieves the task type for a maintenance window.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#window_execution_id ⇒ String
The maintenance window execution ID.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |
#window_target_id ⇒ String
The maintenance window target ID.
8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 |
# File 'lib/aws-sdk-ssm/types.rb', line 8928 class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new( :window_execution_id, :task_execution_id, :invocation_id, :execution_id, :task_type, :parameters, :status, :status_details, :start_time, :end_time, :owner_information, :window_target_id) SENSITIVE = [:parameters, :owner_information] include Aws::Structure end |