Class: Aws::SSM::Types::GetMaintenanceWindowExecutionTaskInvocationResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:parameters, :owner_information]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The time that the task finished running on the target.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#execution_idString

The execution ID.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#invocation_idString

The invocation ID.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#owner_informationString

User-provided value to be included in any Amazon CloudWatch Events or Amazon EventBridge events raised while running tasks for these targets in this maintenance window.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#parametersString

The parameters used at the time that the task ran.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#start_timeTime

The time that the task started running on the target.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#statusString

The task status for an invocation.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#status_detailsString

The details explaining the status. Details are only available for certain status values.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#task_execution_idString

The task execution ID.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#task_typeString

Retrieves the task type for a maintenance window.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#window_execution_idString

The maintenance window execution ID.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end

#window_target_idString

The maintenance window target ID.



8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
# File 'lib/aws-sdk-ssm/types.rb', line 8141

class GetMaintenanceWindowExecutionTaskInvocationResult < Struct.new(
  :window_execution_id,
  :task_execution_id,
  :invocation_id,
  :execution_id,
  :task_type,
  :parameters,
  :status,
  :status_details,
  :start_time,
  :end_time,
  :owner_information,
  :window_target_id)
  SENSITIVE = [:parameters, :owner_information]
  include Aws::Structure
end