Class: Aws::SSM::Types::GetMaintenanceWindowResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::GetMaintenanceWindowResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#allow_unassociated_targets ⇒ Boolean
Whether targets must be registered with the maintenance window before tasks can be defined for those targets.
-
#created_date ⇒ Time
The date the maintenance window was created.
-
#cutoff ⇒ Integer
The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.
-
#description ⇒ String
The description of the maintenance window.
-
#duration ⇒ Integer
The duration of the maintenance window in hours.
-
#enabled ⇒ Boolean
Indicates whether the maintenance window is enabled.
-
#end_date ⇒ String
The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become inactive.
-
#modified_date ⇒ Time
The date the maintenance window was last modified.
-
#name ⇒ String
The name of the maintenance window.
-
#next_execution_time ⇒ String
The next time the maintenance window will actually run, taking into account any specified times for the maintenance window to become active or inactive.
-
#schedule ⇒ String
The schedule of the maintenance window in the form of a cron or rate expression.
-
#schedule_offset ⇒ Integer
The number of days to wait to run a maintenance window after the scheduled cron expression date and time.
-
#schedule_timezone ⇒ String
The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format.
-
#start_date ⇒ String
The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become active.
-
#window_id ⇒ String
The ID of the created maintenance window.
Instance Attribute Details
#allow_unassociated_targets ⇒ Boolean
Whether targets must be registered with the maintenance window before tasks can be defined for those targets.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#created_date ⇒ Time
The date the maintenance window was created.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#cutoff ⇒ Integer
The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the maintenance window.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#duration ⇒ Integer
The duration of the maintenance window in hours.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#enabled ⇒ Boolean
Indicates whether the maintenance window is enabled.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#end_date ⇒ String
The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become inactive. The maintenance window won’t run after this specified time.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#modified_date ⇒ Time
The date the maintenance window was last modified.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the maintenance window.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#next_execution_time ⇒ String
The next time the maintenance window will actually run, taking into account any specified times for the maintenance window to become active or inactive.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#schedule ⇒ String
The schedule of the maintenance window in the form of a cron or rate expression.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#schedule_offset ⇒ Integer
The number of days to wait to run a maintenance window after the scheduled cron expression date and time.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#schedule_timezone ⇒ String
The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format. For example: “America/Los_Angeles”, “UTC”, or “Asia/Seoul”. For more information, see the [Time Zone Database] on the IANA website.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#start_date ⇒ String
The date and time, in ISO-8601 Extended format, for when the maintenance window is scheduled to become active. The maintenance window won’t run before this specified time.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |
#window_id ⇒ String
The ID of the created maintenance window.
8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 |
# File 'lib/aws-sdk-ssm/types.rb', line 8832 class GetMaintenanceWindowResult < Struct.new( :window_id, :name, :description, :start_date, :end_date, :schedule, :schedule_timezone, :schedule_offset, :next_execution_time, :duration, :cutoff, :allow_unassociated_targets, :enabled, :created_date, :modified_date) SENSITIVE = [:description] include Aws::Structure end |