Class: Aws::SSM::Types::GetParameterHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

Returns:

  • (Integer)


9509
9510
9511
9512
9513
9514
9515
9516
# File 'lib/aws-sdk-ssm/types.rb', line 9509

class GetParameterHistoryRequest < Struct.new(
  :name,
  :with_decryption,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name or Amazon Resource Name (ARN) of the parameter for which you want to review history. For parameters shared with you from another account, you must use the full ARN.

Returns:

  • (String)


9509
9510
9511
9512
9513
9514
9515
9516
# File 'lib/aws-sdk-ssm/types.rb', line 9509

class GetParameterHistoryRequest < Struct.new(
  :name,
  :with_decryption,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


9509
9510
9511
9512
9513
9514
9515
9516
# File 'lib/aws-sdk-ssm/types.rb', line 9509

class GetParameterHistoryRequest < Struct.new(
  :name,
  :with_decryption,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#with_decryptionBoolean

Return decrypted values for secure string parameters. This flag is ignored for String and StringList parameter types.

Returns:

  • (Boolean)


9509
9510
9511
9512
9513
9514
9515
9516
# File 'lib/aws-sdk-ssm/types.rb', line 9509

class GetParameterHistoryRequest < Struct.new(
  :name,
  :with_decryption,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end