Class: Aws::SSM::Types::HierarchyLevelLimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::HierarchyLevelLimitExceededException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
A hierarchy can have a maximum of 15 levels. For more information, see Requirements and constraints for parameter names in the Amazon Web Services Systems Manager User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A hierarchy can have a maximum of 15 levels.
Instance Attribute Details
#message ⇒ String
A hierarchy can have a maximum of 15 levels. For more information, see About requirements and constraints for parameter names in the Amazon Web Services Systems Manager User Guide.
10026 10027 10028 10029 10030 |
# File 'lib/aws-sdk-ssm/types.rb', line 10026 class HierarchyLevelLimitExceededException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |