Class: Aws::SSM::Types::InstanceInfo

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Details about a specific managed node.

Constant Summary collapse

SENSITIVE =
[:ip_address]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_typeString

The type of agent installed on the node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#agent_versionString

The version number of the agent installed on the node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#availability_zoneString

The Availability Zone where the managed node is located.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#availability_zone_idString

The Availability Zone ID where the managed node is located.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#computer_nameString

The fully qualified host name of the managed node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#instance_statusString

The current status of the managed node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#ip_addressString

The IP address of the managed node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#managed_statusString

Indicates whether the node is managed by Systems Manager.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#nameString

The name assigned to the managed node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#platform_nameString

The name of the operating system platform running on your managed node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#platform_typeString

The operating system platform type of the managed node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#platform_versionString

The version of the OS platform running on your managed node.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#resource_typeString

The type of instance, either an EC2 instance or another supported machine type in a hybrid fleet.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#source_idString

The ID of the source resource. For IoT Greengrass devices, SourceId is the Thing name.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#source_locationString

The location of the source resource in the third-party cloud environment.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#source_typeString

The type of the source resource. For IoT Greengrass devices, SourceType is AWS::IoT::Thing.

Returns:

  • (String)


10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
# File 'lib/aws-sdk-ssm/types.rb', line 10311

class InstanceInfo < Struct.new(
  :agent_type,
  :agent_version,
  :computer_name,
  :instance_status,
  :ip_address,
  :managed_status,
  :name,
  :platform_type,
  :platform_name,
  :platform_version,
  :resource_type,
  :source_type,
  :source_id,
  :source_location,
  :availability_zone,
  :availability_zone_id)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end