Class: Aws::SSM::Types::InstanceInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InstanceInformation
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Describes a filter for a specific list of managed nodes.
Constant Summary collapse
- SENSITIVE =
[:ip_address]
Instance Attribute Summary collapse
-
#activation_id ⇒ String
The activation ID created by Amazon Web Services Systems Manager when the server or virtual machine (VM) was registered.
-
#agent_version ⇒ String
The version of SSM Agent running on your Linux managed node.
-
#association_overview ⇒ Types::InstanceAggregatedAssociationOverview
Information about the association.
-
#association_status ⇒ String
The status of the association.
-
#computer_name ⇒ String
The fully qualified host name of the managed node.
-
#iam_role ⇒ String
The role assigned to an Amazon EC2 instance configured with a Systems Manager Quick Setup host management configuration or the role assigned to an on-premises managed node.
-
#instance_id ⇒ String
The managed node ID.
-
#ip_address ⇒ String
The IP address of the managed node.
-
#is_latest_version ⇒ Boolean
Indicates whether the latest version of SSM Agent is running on your Linux managed node.
-
#last_association_execution_date ⇒ Time
The date the association was last run.
-
#last_ping_date_time ⇒ Time
The date and time when the agent last pinged the Systems Manager service.
-
#last_successful_association_execution_date ⇒ Time
The last date the association was successfully run.
-
#name ⇒ String
The name assigned to an on-premises server, edge device, or virtual machine (VM) when it is activated as a Systems Manager managed node.
-
#ping_status ⇒ String
Connection status of SSM Agent.
-
#platform_name ⇒ String
The name of the operating system platform running on your managed node.
-
#platform_type ⇒ String
The operating system platform type.
-
#platform_version ⇒ String
The version of the OS platform running on your managed node.
-
#registration_date ⇒ Time
The date the server or VM was registered with Amazon Web Services as a managed node.
-
#resource_type ⇒ String
The type of instance.
-
#source_id ⇒ String
The ID of the source resource.
-
#source_type ⇒ String
The type of the source resource.
Instance Attribute Details
#activation_id ⇒ String
The activation ID created by Amazon Web Services Systems Manager when the server or virtual machine (VM) was registered.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#agent_version ⇒ String
The version of SSM Agent running on your Linux managed node.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#association_overview ⇒ Types::InstanceAggregatedAssociationOverview
Information about the association.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#association_status ⇒ String
The status of the association.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#computer_name ⇒ String
The fully qualified host name of the managed node.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#iam_role ⇒ String
The role assigned to an Amazon EC2 instance configured with a Systems Manager Quick Setup host management configuration or the role assigned to an on-premises managed node.
This call doesn’t return the IAM role for unmanaged Amazon EC2 instances (instances not configured for Systems Manager). To retrieve the role for an unmanaged instance, use the Amazon EC2 ‘DescribeInstances` operation. For information, see
- DescribeInstances][1
-
in the *Amazon EC2 API Reference* or
- describe-instances][2
-
in the *Amazon Web Services CLI Command
Reference*.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstances.html [2]: docs.aws.amazon.com/cli/latest/reference/ec2/describe-instances.html
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#instance_id ⇒ String
The managed node ID.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#ip_address ⇒ String
The IP address of the managed node.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#is_latest_version ⇒ Boolean
Indicates whether the latest version of SSM Agent is running on your Linux managed node. This field doesn’t indicate whether or not the latest version is installed on Windows managed nodes, because some older versions of Windows Server use the EC2Config service to process Systems Manager requests.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#last_association_execution_date ⇒ Time
The date the association was last run.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#last_ping_date_time ⇒ Time
The date and time when the agent last pinged the Systems Manager service.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#last_successful_association_execution_date ⇒ Time
The last date the association was successfully run.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#name ⇒ String
The name assigned to an on-premises server, edge device, or virtual machine (VM) when it is activated as a Systems Manager managed node. The name is specified as the ‘DefaultInstanceName` property using the CreateActivation command. It is applied to the managed node by specifying the Activation Code and Activation ID when you install SSM Agent on the node, as explained in [How to install SSM Agent on hybrid Linux nodes] and [How to install SSM Agent on hybrid Windows Server nodes]. To retrieve the `Name` tag of an EC2 instance, use the Amazon EC2 `DescribeInstances` operation. For information, see [DescribeInstances] in the *Amazon EC2 API Reference* or [describe-instances] in the *Amazon Web Services CLI Command Reference*.
[1]: docs.aws.amazon.com/systems-manager/latest/userguide/hybrid-multicloud-ssm-agent-install-linux.html [2]: docs.aws.amazon.com/systems-manager/latest/userguide/hybrid-multicloud-ssm-agent-install-windows.html [3]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstances.html [4]: docs.aws.amazon.com/cli/latest/reference/ec2/describe-instances.html
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#ping_status ⇒ String
Connection status of SSM Agent.
<note markdown=“1”> The status ‘Inactive` has been deprecated and is no longer in use.
</note>
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_name ⇒ String
The name of the operating system platform running on your managed node.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_type ⇒ String
The operating system platform type.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#platform_version ⇒ String
The version of the OS platform running on your managed node.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#registration_date ⇒ Time
The date the server or VM was registered with Amazon Web Services as a managed node.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#resource_type ⇒ String
The type of instance. Instances are either EC2 instances or managed instances.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#source_id ⇒ String
The ID of the source resource. For IoT Greengrass devices, ‘SourceId` is the Thing name.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |
#source_type ⇒ String
The type of the source resource. For IoT Greengrass devices, ‘SourceType` is `AWS::IoT::Thing`.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 10129 10130 10131 10132 |
# File 'lib/aws-sdk-ssm/types.rb', line 10108 class InstanceInformation < Struct.new( :instance_id, :ping_status, :last_ping_date_time, :agent_version, :is_latest_version, :platform_type, :platform_name, :platform_version, :activation_id, :iam_role, :registration_date, :resource_type, :name, :ip_address, :computer_name, :association_status, :last_association_execution_date, :last_successful_association_execution_date, :association_overview, :source_id, :source_type) SENSITIVE = [:ip_address] include Aws::Structure end |