Class: Aws::SSM::Types::InvalidAutomationExecutionParametersException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InvalidAutomationExecutionParametersException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The supplied parameters for invoking the specified Automation runbook are incorrect. For example, they may not match the set of parameters permitted for the specified Automation document.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
11148 11149 11150 11151 11152 |
# File 'lib/aws-sdk-ssm/types.rb', line 11148 class InvalidAutomationExecutionParametersException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |