Class: Aws::SSM::Types::InvalidAutomationExecutionParametersException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InvalidAutomationExecutionParametersException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The supplied parameters for invoking the specified Automation runbook are incorrect. For example, they may not match the set of parameters permitted for the specified Automation document.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
11135 11136 11137 11138 11139 |
# File 'lib/aws-sdk-ssm/types.rb', line 11135 class InvalidAutomationExecutionParametersException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |