Class: Aws::SSM::Types::InventoryGroup

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

A user-defined set of one or more filters on which to aggregate inventory data. Groups return a count of resources that match and don't match the specified criteria.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::InventoryFilter>

Filters define the criteria for the group. The matchingCount field displays the number of resources that match the criteria. The notMatchingCount field displays the number of resources that don't match the criteria.

Returns:



11928
11929
11930
11931
11932
11933
# File 'lib/aws-sdk-ssm/types.rb', line 11928

class InventoryGroup < Struct.new(
  :name,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the group.

Returns:

  • (String)


11928
11929
11930
11931
11932
11933
# File 'lib/aws-sdk-ssm/types.rb', line 11928

class InventoryGroup < Struct.new(
  :name,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end