Class: Aws::SSM::Types::InventoryGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InventoryGroup
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
A user-defined set of one or more filters on which to aggregate inventory data. Groups return a count of resources that match and don’t match the specified criteria.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::InventoryFilter>
Filters define the criteria for the group.
-
#name ⇒ String
The name of the group.
Instance Attribute Details
#filters ⇒ Array<Types::InventoryFilter>
Filters define the criteria for the group. The matchingCount field displays the number of resources that match the criteria. The notMatchingCount field displays the number of resources that don’t match the criteria.
11534 11535 11536 11537 11538 11539 |
# File 'lib/aws-sdk-ssm/types.rb', line 11534 class InventoryGroup < Struct.new( :name, :filters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the group.
11534 11535 11536 11537 11538 11539 |
# File 'lib/aws-sdk-ssm/types.rb', line 11534 class InventoryGroup < Struct.new( :name, :filters) SENSITIVE = [] include Aws::Structure end |