Class: Aws::SSM::Types::InventoryResultEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InventoryResultEntity
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Inventory query results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data ⇒ Hash<String,Types::InventoryResultItem>
The data section in the inventory result entity JSON.
-
#id ⇒ String
ID of the inventory result entity.
Instance Attribute Details
#data ⇒ Hash<String,Types::InventoryResultItem>
The data section in the inventory result entity JSON.
12042 12043 12044 12045 12046 12047 |
# File 'lib/aws-sdk-ssm/types.rb', line 12042 class InventoryResultEntity < Struct.new( :id, :data) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
ID of the inventory result entity. For example, for managed node inventory the result will be the managed node ID. For EC2 instance inventory, the result will be the instance ID.
12042 12043 12044 12045 12046 12047 |
# File 'lib/aws-sdk-ssm/types.rb', line 12042 class InventoryResultEntity < Struct.new( :id, :data) SENSITIVE = [] include Aws::Structure end |