Class: Aws::SSM::Types::InventoryResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::InventoryResultItem
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The inventory result item.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capture_time ⇒ String
The time inventory item data was captured.
-
#content ⇒ Array<Hash<String,String>>
Contains all the inventory data of the item type.
-
#content_hash ⇒ String
MD5 hash of the inventory item type contents.
-
#schema_version ⇒ String
The schema version for the inventory result item/.
-
#type_name ⇒ String
The name of the inventory result item type.
Instance Attribute Details
#capture_time ⇒ String
The time inventory item data was captured.
12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-ssm/types.rb', line 12077 class InventoryResultItem < Struct.new( :type_name, :schema_version, :capture_time, :content_hash, :content) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Array<Hash<String,String>>
Contains all the inventory data of the item type. Results include attribute names and values.
12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-ssm/types.rb', line 12077 class InventoryResultItem < Struct.new( :type_name, :schema_version, :capture_time, :content_hash, :content) SENSITIVE = [] include Aws::Structure end |
#content_hash ⇒ String
MD5 hash of the inventory item type contents. The content hash is used to determine whether to update inventory information. The PutInventory API doesn't update the inventory item type contents if the MD5 hash hasn't changed since last update.
12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-ssm/types.rb', line 12077 class InventoryResultItem < Struct.new( :type_name, :schema_version, :capture_time, :content_hash, :content) SENSITIVE = [] include Aws::Structure end |
#schema_version ⇒ String
The schema version for the inventory result item/
12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-ssm/types.rb', line 12077 class InventoryResultItem < Struct.new( :type_name, :schema_version, :capture_time, :content_hash, :content) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the inventory result item type.
12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-ssm/types.rb', line 12077 class InventoryResultItem < Struct.new( :type_name, :schema_version, :capture_time, :content_hash, :content) SENSITIVE = [] include Aws::Structure end |