Class: Aws::SSM::Types::LabelParameterVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#labelsArray<String>

One or more labels to attach to the specified parameter version.

Returns:

  • (Array<String>)


12150
12151
12152
12153
12154
12155
12156
# File 'lib/aws-sdk-ssm/types.rb', line 12150

class LabelParameterVersionRequest < Struct.new(
  :name,
  :parameter_version,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The parameter name on which you want to attach one or more labels.

You can't enter the Amazon Resource Name (ARN) for a parameter, only the parameter name itself.

Returns:

  • (String)


12150
12151
12152
12153
12154
12155
12156
# File 'lib/aws-sdk-ssm/types.rb', line 12150

class LabelParameterVersionRequest < Struct.new(
  :name,
  :parameter_version,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_versionInteger

The specific version of the parameter on which you want to attach one or more labels. If no version is specified, the system attaches the label to the latest version.

Returns:

  • (Integer)


12150
12151
12152
12153
12154
12155
12156
# File 'lib/aws-sdk-ssm/types.rb', line 12150

class LabelParameterVersionRequest < Struct.new(
  :name,
  :parameter_version,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end