Class: Aws::SSM::Types::LabelParameterVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::LabelParameterVersionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#labels ⇒ Array<String>
One or more labels to attach to the specified parameter version.
-
#name ⇒ String
The parameter name on which you want to attach one or more labels.
-
#parameter_version ⇒ Integer
The specific version of the parameter on which you want to attach one or more labels.
Instance Attribute Details
#labels ⇒ Array<String>
One or more labels to attach to the specified parameter version.
12150 12151 12152 12153 12154 12155 12156 |
# File 'lib/aws-sdk-ssm/types.rb', line 12150 class LabelParameterVersionRequest < Struct.new( :name, :parameter_version, :labels) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The parameter name on which you want to attach one or more labels.
12150 12151 12152 12153 12154 12155 12156 |
# File 'lib/aws-sdk-ssm/types.rb', line 12150 class LabelParameterVersionRequest < Struct.new( :name, :parameter_version, :labels) SENSITIVE = [] include Aws::Structure end |
#parameter_version ⇒ Integer
The specific version of the parameter on which you want to attach one or more labels. If no version is specified, the system attaches the label to the latest version.
12150 12151 12152 12153 12154 12155 12156 |
# File 'lib/aws-sdk-ssm/types.rb', line 12150 class LabelParameterVersionRequest < Struct.new( :name, :parameter_version, :labels) SENSITIVE = [] include Aws::Structure end |