Class: Aws::SSM::Types::ListAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ListAssociationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_filter_list ⇒ Array<Types::AssociationFilter>
One or more filters.
-
#max_results ⇒ Integer
The maximum number of items to return for this call.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#association_filter_list ⇒ Array<Types::AssociationFilter>
One or more filters. Use a filter to return a more specific list of results.
<note markdown=“1”> Filtering associations using the InstanceID attribute only returns legacy associations created using the InstanceID attribute. Associations targeting the managed node that are part of the Target Attributes ResourceGroup or Tags aren’t returned.
</note>
11803 11804 11805 11806 11807 11808 11809 |
# File 'lib/aws-sdk-ssm/types.rb', line 11803 class ListAssociationsRequest < Struct.new( :association_filter_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
11803 11804 11805 11806 11807 11808 11809 |
# File 'lib/aws-sdk-ssm/types.rb', line 11803 class ListAssociationsRequest < Struct.new( :association_filter_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
11803 11804 11805 11806 11807 11808 11809 |
# File 'lib/aws-sdk-ssm/types.rb', line 11803 class ListAssociationsRequest < Struct.new( :association_filter_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |