Class: Aws::SSM::Types::ListCommandInvocationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ListCommandInvocationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command_id ⇒ String
(Optional) The invocations for a specific command ID.
-
#details ⇒ Boolean
(Optional) If set this returns the response of the command executions and any command output.
-
#filters ⇒ Array<Types::CommandFilter>
(Optional) One or more filters.
-
#instance_id ⇒ String
(Optional) The command execution details for a specific managed node ID.
-
#max_results ⇒ Integer
(Optional) The maximum number of items to return for this call.
-
#next_token ⇒ String
(Optional) The token for the next set of items to return.
Instance Attribute Details
#command_id ⇒ String
(Optional) The invocations for a specific command ID.
11927 11928 11929 11930 11931 11932 11933 11934 11935 11936 |
# File 'lib/aws-sdk-ssm/types.rb', line 11927 class ListCommandInvocationsRequest < Struct.new( :command_id, :instance_id, :max_results, :next_token, :filters, :details) SENSITIVE = [] include Aws::Structure end |
#details ⇒ Boolean
(Optional) If set this returns the response of the command executions and any command output. The default value is false.
11927 11928 11929 11930 11931 11932 11933 11934 11935 11936 |
# File 'lib/aws-sdk-ssm/types.rb', line 11927 class ListCommandInvocationsRequest < Struct.new( :command_id, :instance_id, :max_results, :next_token, :filters, :details) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::CommandFilter>
(Optional) One or more filters. Use a filter to return a more specific list of results.
11927 11928 11929 11930 11931 11932 11933 11934 11935 11936 |
# File 'lib/aws-sdk-ssm/types.rb', line 11927 class ListCommandInvocationsRequest < Struct.new( :command_id, :instance_id, :max_results, :next_token, :filters, :details) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
(Optional) The command execution details for a specific managed node ID.
11927 11928 11929 11930 11931 11932 11933 11934 11935 11936 |
# File 'lib/aws-sdk-ssm/types.rb', line 11927 class ListCommandInvocationsRequest < Struct.new( :command_id, :instance_id, :max_results, :next_token, :filters, :details) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
(Optional) The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
11927 11928 11929 11930 11931 11932 11933 11934 11935 11936 |
# File 'lib/aws-sdk-ssm/types.rb', line 11927 class ListCommandInvocationsRequest < Struct.new( :command_id, :instance_id, :max_results, :next_token, :filters, :details) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
(Optional) The token for the next set of items to return. (You received this token from a previous call.)
11927 11928 11929 11930 11931 11932 11933 11934 11935 11936 |
# File 'lib/aws-sdk-ssm/types.rb', line 11927 class ListCommandInvocationsRequest < Struct.new( :command_id, :instance_id, :max_results, :next_token, :filters, :details) SENSITIVE = [] include Aws::Structure end |