Class: Aws::SSM::Types::ListResourceDataSyncRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ListResourceDataSyncRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return for this call.
-
#next_token ⇒ String
A token to start the list.
-
#sync_type ⇒ String
View a list of resource data syncs according to the sync type.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
12700 12701 12702 12703 12704 12705 12706 |
# File 'lib/aws-sdk-ssm/types.rb', line 12700 class ListResourceDataSyncRequest < Struct.new( :sync_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to start the list. Use this token to get the next set of results.
12700 12701 12702 12703 12704 12705 12706 |
# File 'lib/aws-sdk-ssm/types.rb', line 12700 class ListResourceDataSyncRequest < Struct.new( :sync_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sync_type ⇒ String
View a list of resource data syncs according to the sync type. Specify SyncToDestination to view resource data syncs that synchronize data to an Amazon S3 bucket. Specify SyncFromSource to view resource data syncs from Organizations or from multiple Amazon Web Services Regions.
12700 12701 12702 12703 12704 12705 12706 |
# File 'lib/aws-sdk-ssm/types.rb', line 12700 class ListResourceDataSyncRequest < Struct.new( :sync_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |