Class: Aws::SSM::Types::MaintenanceWindowTarget

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

The target registered with the maintenance window.

Constant Summary collapse

SENSITIVE =
[:owner_information, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description for the target.



12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-ssm/types.rb', line 12705

class MaintenanceWindowTarget < Struct.new(
  :window_id,
  :window_target_id,
  :resource_type,
  :targets,
  :owner_information,
  :name,
  :description)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#nameString

The name for the maintenance window target.



12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-ssm/types.rb', line 12705

class MaintenanceWindowTarget < Struct.new(
  :window_id,
  :window_target_id,
  :resource_type,
  :targets,
  :owner_information,
  :name,
  :description)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#owner_informationString

A user-provided value that will be included in any Amazon CloudWatch Events events that are raised while running tasks for these targets in this maintenance window.



12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-ssm/types.rb', line 12705

class MaintenanceWindowTarget < Struct.new(
  :window_id,
  :window_target_id,
  :resource_type,
  :targets,
  :owner_information,
  :name,
  :description)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#resource_typeString

The type of target that is being registered with the maintenance window.



12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-ssm/types.rb', line 12705

class MaintenanceWindowTarget < Struct.new(
  :window_id,
  :window_target_id,
  :resource_type,
  :targets,
  :owner_information,
  :name,
  :description)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#targetsArray<Types::Target>

The targets, either managed nodes or tags.

Specify managed nodes using the following format:

‘Key=instanceids,Values=<instanceid1>,<instanceid2>`

Tags are specified using the following format:

‘Key=<tag name>,Values=<tag value>`.



12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-ssm/types.rb', line 12705

class MaintenanceWindowTarget < Struct.new(
  :window_id,
  :window_target_id,
  :resource_type,
  :targets,
  :owner_information,
  :name,
  :description)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#window_idString

The ID of the maintenance window to register the target with.



12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-ssm/types.rb', line 12705

class MaintenanceWindowTarget < Struct.new(
  :window_id,
  :window_target_id,
  :resource_type,
  :targets,
  :owner_information,
  :name,
  :description)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#window_target_idString

The ID of the target.



12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
# File 'lib/aws-sdk-ssm/types.rb', line 12705

class MaintenanceWindowTarget < Struct.new(
  :window_id,
  :window_target_id,
  :resource_type,
  :targets,
  :owner_information,
  :name,
  :description)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end