Class: Aws::SSM::Types::NodeOwnerInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::NodeOwnerInfo
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about ownership of a managed node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account that owns the managed node.
-
#organizational_unit_id ⇒ String
The ID of the organization unit (OU) that the account is part of.
-
#organizational_unit_path ⇒ String
The path for the organizational unit (OU) that owns the managed node.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account that owns the managed node.
14273 14274 14275 14276 14277 14278 14279 |
# File 'lib/aws-sdk-ssm/types.rb', line 14273 class NodeOwnerInfo < Struct.new( :account_id, :organizational_unit_id, :organizational_unit_path) SENSITIVE = [] include Aws::Structure end |
#organizational_unit_id ⇒ String
The ID of the organization unit (OU) that the account is part of.
14273 14274 14275 14276 14277 14278 14279 |
# File 'lib/aws-sdk-ssm/types.rb', line 14273 class NodeOwnerInfo < Struct.new( :account_id, :organizational_unit_id, :organizational_unit_path) SENSITIVE = [] include Aws::Structure end |
#organizational_unit_path ⇒ String
The path for the organizational unit (OU) that owns the managed node. The path for the OU is built using the IDs of the organization, root, and all OUs in the path down to and including the OU. For example:
o-a1b2c3d4e5/r-f6g7h8i9j0example/ou-ghi0-awsccccc/ou-jkl0-awsddddd/
14273 14274 14275 14276 14277 14278 14279 |
# File 'lib/aws-sdk-ssm/types.rb', line 14273 class NodeOwnerInfo < Struct.new( :account_id, :organizational_unit_id, :organizational_unit_path) SENSITIVE = [] include Aws::Structure end |