Class: Aws::SSM::Types::NotificationConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Configurations for sending notifications.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#notification_arnString

An Amazon Resource Name (ARN) for an Amazon Simple Notification Service (Amazon SNS) topic. Run Command pushes notifications about command status changes to this topic.

Returns:

  • (String)


14354
14355
14356
14357
14358
14359
14360
# File 'lib/aws-sdk-ssm/types.rb', line 14354

class NotificationConfig < Struct.new(
  :notification_arn,
  :notification_events,
  :notification_type)
  SENSITIVE = []
  include Aws::Structure
end

#notification_eventsArray<String>

The different events for which you can receive notifications. To learn more about these events, see Monitoring Systems Manager status changes using Amazon SNS notifications in the Amazon Web Services Systems Manager User Guide.

Returns:

  • (Array<String>)


14354
14355
14356
14357
14358
14359
14360
# File 'lib/aws-sdk-ssm/types.rb', line 14354

class NotificationConfig < Struct.new(
  :notification_arn,
  :notification_events,
  :notification_type)
  SENSITIVE = []
  include Aws::Structure
end

#notification_typeString

The type of notification.

  • Command: Receive notification when the status of a command changes.

  • Invocation: For commands sent to multiple managed nodes, receive notification on a per-node basis when the status of a command changes.

Returns:

  • (String)


14354
14355
14356
14357
14358
14359
14360
# File 'lib/aws-sdk-ssm/types.rb', line 14354

class NotificationConfig < Struct.new(
  :notification_arn,
  :notification_events,
  :notification_type)
  SENSITIVE = []
  include Aws::Structure
end