Class: Aws::SSM::Types::NotificationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::NotificationConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Configurations for sending notifications.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#notification_arn ⇒ String
An Amazon Resource Name (ARN) for an Amazon Simple Notification Service (Amazon SNS) topic.
-
#notification_events ⇒ Array<String>
The different events for which you can receive notifications.
-
#notification_type ⇒ String
The type of notification.
Instance Attribute Details
#notification_arn ⇒ String
An Amazon Resource Name (ARN) for an Amazon Simple Notification Service (Amazon SNS) topic. Run Command pushes notifications about command status changes to this topic.
14341 14342 14343 14344 14345 14346 14347 |
# File 'lib/aws-sdk-ssm/types.rb', line 14341 class NotificationConfig < Struct.new( :notification_arn, :notification_events, :notification_type) SENSITIVE = [] include Aws::Structure end |
#notification_events ⇒ Array<String>
The different events for which you can receive notifications. To learn more about these events, see Monitoring Systems Manager status changes using Amazon SNS notifications in the Amazon Web Services Systems Manager User Guide.
14341 14342 14343 14344 14345 14346 14347 |
# File 'lib/aws-sdk-ssm/types.rb', line 14341 class NotificationConfig < Struct.new( :notification_arn, :notification_events, :notification_type) SENSITIVE = [] include Aws::Structure end |
#notification_type ⇒ String
The type of notification.
-
Command: Receive notification when the status of a command changes. -
Invocation: For commands sent to multiple managed nodes, receive notification on a per-node basis when the status of a command changes.
14341 14342 14343 14344 14345 14346 14347 |
# File 'lib/aws-sdk-ssm/types.rb', line 14341 class NotificationConfig < Struct.new( :notification_arn, :notification_events, :notification_type) SENSITIVE = [] include Aws::Structure end |