Class: Aws::SSM::Types::ParameterHistory
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ParameterHistory
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about parameter usage.
Constant Summary collapse
- SENSITIVE =
[:value]
Instance Attribute Summary collapse
-
#allowed_pattern ⇒ String
Parameter names can include the following letters and symbols.
-
#data_type ⇒ String
The data type of the parameter, such as
textoraws:ec2:image. -
#description ⇒ String
Information about the parameter.
-
#key_id ⇒ String
The alias of the Key Management Service (KMS) key used to encrypt the parameter.
-
#labels ⇒ Array<String>
Labels assigned to the parameter version.
-
#last_modified_date ⇒ Time
Date the parameter was last changed or updated.
-
#last_modified_user ⇒ String
Amazon Resource Name (ARN) of the Amazon Web Services user who last changed the parameter.
-
#name ⇒ String
The name of the parameter.
-
#policies ⇒ Array<Types::ParameterInlinePolicy>
Information about the policies assigned to a parameter.
-
#tier ⇒ String
The parameter tier.
-
#type ⇒ String
The type of parameter used.
-
#value ⇒ String
The parameter value.
-
#version ⇒ Integer
The parameter version.
Instance Attribute Details
#allowed_pattern ⇒ String
Parameter names can include the following letters and symbols.
a-zA-Z0-9_.-
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#data_type ⇒ String
The data type of the parameter, such as text or aws:ec2:image. The default is text.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#description ⇒ String
Information about the parameter.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#key_id ⇒ String
The alias of the Key Management Service (KMS) key used to encrypt the parameter. Applies to SecureString parameters only
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#labels ⇒ Array<String>
Labels assigned to the parameter version.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#last_modified_date ⇒ Time
Date the parameter was last changed or updated.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#last_modified_user ⇒ String
Amazon Resource Name (ARN) of the Amazon Web Services user who last changed the parameter.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#name ⇒ String
The name of the parameter.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#policies ⇒ Array<Types::ParameterInlinePolicy>
Information about the policies assigned to a parameter.
- Assigning parameter policies][1
-
in the *Amazon Web Services
Systems Manager User Guide*.
[1]: docs.aws.amazon.com/systems-manager/latest/userguide/parameter-store-policies.html
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#tier ⇒ String
The parameter tier.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#type ⇒ String
The type of parameter used.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#value ⇒ String
The parameter value.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |
#version ⇒ Integer
The parameter version.
15053 15054 15055 15056 15057 15058 15059 15060 15061 15062 15063 15064 15065 15066 15067 15068 15069 |
# File 'lib/aws-sdk-ssm/types.rb', line 15053 class ParameterHistory < Struct.new( :name, :type, :key_id, :last_modified_date, :last_modified_user, :description, :value, :allowed_pattern, :version, :labels, :tier, :policies, :data_type) SENSITIVE = [:value] include Aws::Structure end |