Class: Aws::SSM::Types::ParameterMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Metadata includes information like the Amazon Resource Name (ARN) of the last user to update the parameter and the date and time the parameter was last used.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_patternString

A parameter name can include only the following letters and symbols.

a-zA-Z0-9_.-

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the parameter.

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#data_typeString

The data type of the parameter, such as text or aws:ec2:image. The default is text.

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description of the parameter actions.

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

The alias of the Key Management Service (KMS) key used to encrypt the parameter. Applies to SecureString parameters only.

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

Date the parameter was last changed or updated.

Returns:

  • (Time)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_userString

Amazon Resource Name (ARN) of the Amazon Web Services user who last changed the parameter.

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The parameter name.

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#policiesArray<Types::ParameterInlinePolicy>

A list of policies associated with a parameter.

Returns:



15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

The parameter tier.

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of parameter. Valid parameter types include the following: String, StringList, and SecureString.

Returns:

  • (String)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The parameter version.

Returns:

  • (Integer)


15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
# File 'lib/aws-sdk-ssm/types.rb', line 15639

class ParameterMetadata < Struct.new(
  :name,
  :arn,
  :type,
  :key_id,
  :last_modified_date,
  :last_modified_user,
  :description,
  :allowed_pattern,
  :version,
  :tier,
  :policies,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end