Class: Aws::SSM::Types::ParameterMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ParameterMetadata
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Metadata includes information like the Amazon Resource Name (ARN) of the last user to update the parameter and the date and time the parameter was last used.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_pattern ⇒ String
A parameter name can include only the following letters and symbols.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the parameter.
-
#data_type ⇒ String
The data type of the parameter, such as
textoraws:ec2:image. -
#description ⇒ String
Description of the parameter actions.
-
#key_id ⇒ String
The alias of the Key Management Service (KMS) key used to encrypt the parameter.
-
#last_modified_date ⇒ Time
Date the parameter was last changed or updated.
-
#last_modified_user ⇒ String
Amazon Resource Name (ARN) of the Amazon Web Services user who last changed the parameter.
-
#name ⇒ String
The parameter name.
-
#policies ⇒ Array<Types::ParameterInlinePolicy>
A list of policies associated with a parameter.
-
#tier ⇒ String
The parameter tier.
-
#type ⇒ String
The type of parameter.
-
#version ⇒ Integer
The parameter version.
Instance Attribute Details
#allowed_pattern ⇒ String
A parameter name can include only the following letters and symbols.
a-zA-Z0-9_.-
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the parameter.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ String
The data type of the parameter, such as text or aws:ec2:image. The default is text.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the parameter actions.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The alias of the Key Management Service (KMS) key used to encrypt the parameter. Applies to SecureString parameters only.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
Date the parameter was last changed or updated.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#last_modified_user ⇒ String
Amazon Resource Name (ARN) of the Amazon Web Services user who last changed the parameter.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The parameter name.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#policies ⇒ Array<Types::ParameterInlinePolicy>
A list of policies associated with a parameter.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The parameter tier.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of parameter. Valid parameter types include the following: String, StringList, and SecureString.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The parameter version.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 |
# File 'lib/aws-sdk-ssm/types.rb', line 15211 class ParameterMetadata < Struct.new( :name, :arn, :type, :key_id, :last_modified_date, :last_modified_user, :description, :allowed_pattern, :version, :tier, :policies, :data_type) SENSITIVE = [] include Aws::Structure end |