Class: Aws::SSM::Types::Patch
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::Patch
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Represents metadata about a patch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advisory_ids ⇒ Array<String>
The Advisory ID of the patch.
-
#arch ⇒ String
The architecture of the patch.
-
#bugzilla_ids ⇒ Array<String>
The Bugzilla ID of the patch.
-
#classification ⇒ String
The classification of the patch.
-
#content_url ⇒ String
The URL where more information can be obtained about the patch.
-
#cve_ids ⇒ Array<String>
The Common Vulnerabilities and Exposures (CVE) ID of the patch.
-
#description ⇒ String
The description of the patch.
-
#epoch ⇒ Integer
The epoch of the patch.
-
#id ⇒ String
The ID of the patch.
-
#kb_number ⇒ String
The Microsoft Knowledge Base ID of the patch.
-
#language ⇒ String
The language of the patch if it’s language-specific.
-
#msrc_number ⇒ String
The ID of the Microsoft Security Response Center (MSRC) bulletin the patch is related to.
-
#msrc_severity ⇒ String
The severity of the patch, such as
Critical,Important, orModerate. -
#name ⇒ String
The name of the patch.
-
#product ⇒ String
The specific product the patch is applicable for.
-
#product_family ⇒ String
The product family the patch is applicable for.
-
#release ⇒ String
The particular release of a patch.
-
#release_date ⇒ Time
The date the patch was released.
-
#repository ⇒ String
The source patch repository for the operating system and version, such as
trusty-securityfor Ubuntu Server 14.04 LTE andfocal-securityfor Ubuntu Server 20.04 LTE. -
#severity ⇒ String
The severity level of the patch.
-
#title ⇒ String
The title of the patch.
-
#vendor ⇒ String
The name of the vendor providing the patch.
-
#version ⇒ String
The version number of the patch.
Instance Attribute Details
#advisory_ids ⇒ Array<String>
The Advisory ID of the patch. For example, RHSA-2020:3779. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#arch ⇒ String
The architecture of the patch. For example, in example-pkg-0.710.10-2.7.abcd.x86_64, the architecture is indicated by x86_64. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#bugzilla_ids ⇒ Array<String>
The Bugzilla ID of the patch. For example, 1600646. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#classification ⇒ String
The classification of the patch. For example, SecurityUpdates, Updates, or CriticalUpdates.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#content_url ⇒ String
The URL where more information can be obtained about the patch.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#cve_ids ⇒ Array<String>
The Common Vulnerabilities and Exposures (CVE) ID of the patch. For example, CVE-2011-3192. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the patch.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#epoch ⇒ Integer
The epoch of the patch. For example in pkg-example-EE-20180914-2.2.amzn1.noarch, the epoch value is 20180914-2. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the patch. Applies to Windows patches only.
<note markdown=“1”> This ID isn’t the same as the Microsoft Knowledge Base ID.
</note>
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#kb_number ⇒ String
The Microsoft Knowledge Base ID of the patch. Applies to Windows patches only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The language of the patch if it’s language-specific.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#msrc_number ⇒ String
The ID of the Microsoft Security Response Center (MSRC) bulletin the patch is related to. For example, MS14-045. Applies to Windows patches only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#msrc_severity ⇒ String
The severity of the patch, such as Critical, Important, or Moderate. Applies to Windows patches only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the patch. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#product ⇒ String
The specific product the patch is applicable for. For example, WindowsServer2016 or AmazonLinux2018.03.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#product_family ⇒ String
The product family the patch is applicable for. For example, Windows or ‘Amazon Linux 2`.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#release ⇒ String
The particular release of a patch. For example, in pkg-example-EE-20180914-2.2.amzn1.noarch, the release is 2.amaz1. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#release_date ⇒ Time
The date the patch was released.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#repository ⇒ String
The source patch repository for the operating system and version, such as trusty-security for Ubuntu Server 14.04 LTE and focal-security for Ubuntu Server 20.04 LTE. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity level of the patch. For example, CRITICAL or MODERATE.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the patch.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#vendor ⇒ String
The name of the vendor providing the patch.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version number of the patch. For example, in example-pkg-1.710.10-2.7.abcd.x86_64, the version number is indicated by -1. Applies to Linux-based managed nodes only.
15514 15515 15516 15517 15518 15519 15520 15521 15522 15523 15524 15525 15526 15527 15528 15529 15530 15531 15532 15533 15534 15535 15536 15537 15538 15539 15540 |
# File 'lib/aws-sdk-ssm/types.rb', line 15514 class Patch < Struct.new( :id, :release_date, :title, :description, :content_url, :vendor, :product_family, :product, :classification, :msrc_severity, :kb_number, :msrc_number, :language, :advisory_ids, :bugzilla_ids, :cve_ids, :name, :epoch, :version, :release, :arch, :severity, :repository) SENSITIVE = [] include Aws::Structure end |