Class: Aws::SSM::Types::PatchComplianceData
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::PatchComplianceData
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about the state of a patch on a particular managed node as it relates to the patch baseline used to patch the node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#classification ⇒ String
The classification of the patch, such as
SecurityUpdates,Updates, andCriticalUpdates. -
#cve_ids ⇒ String
The IDs of one or more Common Vulnerabilities and Exposure (CVE) issues that are resolved by the patch.
-
#installed_time ⇒ Time
The date/time the patch was installed on the managed node.
-
#kb_id ⇒ String
The operating system-specific ID of the patch.
-
#severity ⇒ String
The severity of the patch such as
Critical,Important, andModerate. -
#state ⇒ String
The state of the patch on the managed node, such as INSTALLED or FAILED.
-
#title ⇒ String
The title of the patch.
Instance Attribute Details
#classification ⇒ String
The classification of the patch, such as SecurityUpdates,
Updates, and CriticalUpdates.
16059 16060 16061 16062 16063 16064 16065 16066 16067 16068 16069 |
# File 'lib/aws-sdk-ssm/types.rb', line 16059 class PatchComplianceData < Struct.new( :title, :kb_id, :classification, :severity, :state, :installed_time, :cve_ids) SENSITIVE = [] include Aws::Structure end |
#cve_ids ⇒ String
The IDs of one or more Common Vulnerabilities and Exposure (CVE) issues that are resolved by the patch.
Missing or Failed.
16059 16060 16061 16062 16063 16064 16065 16066 16067 16068 16069 |
# File 'lib/aws-sdk-ssm/types.rb', line 16059 class PatchComplianceData < Struct.new( :title, :kb_id, :classification, :severity, :state, :installed_time, :cve_ids) SENSITIVE = [] include Aws::Structure end |
#installed_time ⇒ Time
The date/time the patch was installed on the managed node. Not all operating systems provide this level of information.
16059 16060 16061 16062 16063 16064 16065 16066 16067 16068 16069 |
# File 'lib/aws-sdk-ssm/types.rb', line 16059 class PatchComplianceData < Struct.new( :title, :kb_id, :classification, :severity, :state, :installed_time, :cve_ids) SENSITIVE = [] include Aws::Structure end |
#kb_id ⇒ String
The operating system-specific ID of the patch.
16059 16060 16061 16062 16063 16064 16065 16066 16067 16068 16069 |
# File 'lib/aws-sdk-ssm/types.rb', line 16059 class PatchComplianceData < Struct.new( :title, :kb_id, :classification, :severity, :state, :installed_time, :cve_ids) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity of the patch such as Critical, Important, and
Moderate.
16059 16060 16061 16062 16063 16064 16065 16066 16067 16068 16069 |
# File 'lib/aws-sdk-ssm/types.rb', line 16059 class PatchComplianceData < Struct.new( :title, :kb_id, :classification, :severity, :state, :installed_time, :cve_ids) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the patch on the managed node, such as INSTALLED or FAILED.
For descriptions of each patch state, see About patch compliance in the Amazon Web Services Systems Manager User Guide.
16059 16060 16061 16062 16063 16064 16065 16066 16067 16068 16069 |
# File 'lib/aws-sdk-ssm/types.rb', line 16059 class PatchComplianceData < Struct.new( :title, :kb_id, :classification, :severity, :state, :installed_time, :cve_ids) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the patch.
16059 16060 16061 16062 16063 16064 16065 16066 16067 16068 16069 |
# File 'lib/aws-sdk-ssm/types.rb', line 16059 class PatchComplianceData < Struct.new( :title, :kb_id, :classification, :severity, :state, :installed_time, :cve_ids) SENSITIVE = [] include Aws::Structure end |