Class: Aws::SSM::Types::ProgressCounters
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ProgressCounters
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
An aggregate of step execution statuses displayed in the Amazon Web Services Systems Manager console for a multi-Region and multi-account Automation execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cancelled_steps ⇒ Integer
The total number of steps that the system cancelled in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
-
#failed_steps ⇒ Integer
The total number of steps that failed to run in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
-
#success_steps ⇒ Integer
The total number of steps that successfully completed in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
-
#timed_out_steps ⇒ Integer
The total number of steps that timed out in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
-
#total_steps ⇒ Integer
The total number of steps run in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
Instance Attribute Details
#cancelled_steps ⇒ Integer
The total number of steps that the system cancelled in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
16416 16417 16418 16419 16420 16421 16422 16423 16424 |
# File 'lib/aws-sdk-ssm/types.rb', line 16416 class ProgressCounters < Struct.new( :total_steps, :success_steps, :failed_steps, :cancelled_steps, :timed_out_steps) SENSITIVE = [] include Aws::Structure end |
#failed_steps ⇒ Integer
The total number of steps that failed to run in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
16416 16417 16418 16419 16420 16421 16422 16423 16424 |
# File 'lib/aws-sdk-ssm/types.rb', line 16416 class ProgressCounters < Struct.new( :total_steps, :success_steps, :failed_steps, :cancelled_steps, :timed_out_steps) SENSITIVE = [] include Aws::Structure end |
#success_steps ⇒ Integer
The total number of steps that successfully completed in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
16416 16417 16418 16419 16420 16421 16422 16423 16424 |
# File 'lib/aws-sdk-ssm/types.rb', line 16416 class ProgressCounters < Struct.new( :total_steps, :success_steps, :failed_steps, :cancelled_steps, :timed_out_steps) SENSITIVE = [] include Aws::Structure end |
#timed_out_steps ⇒ Integer
The total number of steps that timed out in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
16416 16417 16418 16419 16420 16421 16422 16423 16424 |
# File 'lib/aws-sdk-ssm/types.rb', line 16416 class ProgressCounters < Struct.new( :total_steps, :success_steps, :failed_steps, :cancelled_steps, :timed_out_steps) SENSITIVE = [] include Aws::Structure end |
#total_steps ⇒ Integer
The total number of steps run in all specified Amazon Web Services Regions and Amazon Web Services accounts for the current Automation execution.
16416 16417 16418 16419 16420 16421 16422 16423 16424 |
# File 'lib/aws-sdk-ssm/types.rb', line 16416 class ProgressCounters < Struct.new( :total_steps, :success_steps, :failed_steps, :cancelled_steps, :timed_out_steps) SENSITIVE = [] include Aws::Structure end |