Class: Aws::SSM::Types::RelatedOpsItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::RelatedOpsItem
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
An OpsItems that shares something in common with the current OpsItem. For example, related OpsItems can include OpsItems with similar error messages, impacted resources, or statuses for the impacted resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ops_item_id ⇒ String
The ID of an OpsItem related to the current OpsItem.
Instance Attribute Details
#ops_item_id ⇒ String
The ID of an OpsItem related to the current OpsItem.
16892 16893 16894 16895 16896 |
# File 'lib/aws-sdk-ssm/types.rb', line 16892 class < Struct.new( :ops_item_id) SENSITIVE = [] include Aws::Structure end |