Class: Aws::SSM::Types::ResourceDataSyncItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ResourceDataSyncItem
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about a resource data sync configuration, including its current status and last successful sync.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_status ⇒ String
The status reported by the last sync.
-
#last_successful_sync_time ⇒ Time
The last time the sync operations returned a status of
SUCCESSFUL(UTC). -
#last_sync_status_message ⇒ String
The status message details reported by the last sync.
-
#last_sync_time ⇒ Time
The last time the configuration attempted to sync (UTC).
-
#s3_destination ⇒ Types::ResourceDataSyncS3Destination
Configuration information for the target S3 bucket.
-
#sync_created_time ⇒ Time
The date and time the configuration was created (UTC).
-
#sync_last_modified_time ⇒ Time
The date and time the resource data sync was changed.
-
#sync_name ⇒ String
The name of the resource data sync.
-
#sync_source ⇒ Types::ResourceDataSyncSourceWithState
Information about the source where the data was synchronized.
-
#sync_type ⇒ String
The type of resource data sync.
Instance Attribute Details
#last_status ⇒ String
The status reported by the last sync.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#last_successful_sync_time ⇒ Time
The last time the sync operations returned a status of SUCCESSFUL
(UTC).
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#last_sync_status_message ⇒ String
The status message details reported by the last sync.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#last_sync_time ⇒ Time
The last time the configuration attempted to sync (UTC).
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#s3_destination ⇒ Types::ResourceDataSyncS3Destination
Configuration information for the target S3 bucket.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#sync_created_time ⇒ Time
The date and time the configuration was created (UTC).
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#sync_last_modified_time ⇒ Time
The date and time the resource data sync was changed.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#sync_name ⇒ String
The name of the resource data sync.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#sync_source ⇒ Types::ResourceDataSyncSourceWithState
Information about the source where the data was synchronized.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |
#sync_type ⇒ String
The type of resource data sync. If SyncType is
SyncToDestination, then the resource data sync synchronizes data
to an S3 bucket. If the SyncType is SyncFromSource then the
resource data sync synchronizes data from Organizations or from
multiple Amazon Web Services Regions.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 |
# File 'lib/aws-sdk-ssm/types.rb', line 17654 class ResourceDataSyncItem < Struct.new( :sync_name, :sync_type, :sync_source, :s3_destination, :last_sync_time, :last_successful_sync_time, :sync_last_modified_time, :last_status, :sync_created_time, :last_sync_status_message) SENSITIVE = [] include Aws::Structure end |