Class: Aws::SSM::Types::ResourceLimitExceededException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Error returned when the caller has exceeded the default resource quotas. For example, too many maintenance windows or patch baselines have been created.

For information about resource quotas in Systems Manager, see Systems Manager service quotas in the Amazon Web Services General Reference.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


17908
17909
17910
17911
17912
# File 'lib/aws-sdk-ssm/types.rb', line 17908

class ResourceLimitExceededException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end