Class: Aws::SSM::Types::Runbook
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::Runbook
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Information about an Automation runbook used in a runbook workflow in Change Manager.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document_name ⇒ String
The name of the Automation runbook used in a runbook workflow.
-
#document_version ⇒ String
The version of the Automation runbook used in a runbook workflow.
-
#max_concurrency ⇒ String
The
MaxConcurrencyvalue specified by the user when the operation started, indicating the maximum number of resources that the runbook operation can run on at the same time. -
#max_errors ⇒ String
The
MaxErrorsvalue specified by the user when the execution started, indicating the maximum number of errors that can occur during the operation before the updates are stopped or rolled back. -
#parameters ⇒ Hash<String,Array<String>>
The key-value map of execution parameters, which were supplied when calling
StartChangeRequestExecution. -
#target_locations ⇒ Array<Types::TargetLocation>
Information about the Amazon Web Services Regions and Amazon Web Services accounts targeted by the current Runbook operation.
-
#target_maps ⇒ Array<Hash<String,Array<String>>>
A key-value mapping of runbook parameters to target resources.
-
#target_parameter_name ⇒ String
The name of the parameter used as the target resource for the rate-controlled runbook workflow.
-
#targets ⇒ Array<Types::Target>
A key-value mapping to target resources that the runbook operation performs tasks on.
Instance Attribute Details
#document_name ⇒ String
The name of the Automation runbook used in a runbook workflow.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The version of the Automation runbook used in a runbook workflow.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |
#max_concurrency ⇒ String
The MaxConcurrency value specified by the user when the operation
started, indicating the maximum number of resources that the runbook
operation can run on at the same time.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |
#max_errors ⇒ String
The MaxErrors value specified by the user when the execution
started, indicating the maximum number of errors that can occur
during the operation before the updates are stopped or rolled back.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Array<String>>
The key-value map of execution parameters, which were supplied when
calling StartChangeRequestExecution.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |
#target_locations ⇒ Array<Types::TargetLocation>
Information about the Amazon Web Services Regions and Amazon Web Services accounts targeted by the current Runbook operation.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |
#target_maps ⇒ Array<Hash<String,Array<String>>>
A key-value mapping of runbook parameters to target resources. Both Targets and TargetMaps can't be specified together.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |
#target_parameter_name ⇒ String
The name of the parameter used as the target resource for the
rate-controlled runbook workflow. Required if you specify Targets.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<Types::Target>
A key-value mapping to target resources that the runbook operation
performs tasks on. Required if you specify TargetParameterName.
18144 18145 18146 18147 18148 18149 18150 18151 18152 18153 18154 18155 18156 |
# File 'lib/aws-sdk-ssm/types.rb', line 18144 class Runbook < Struct.new( :document_name, :document_version, :parameters, :target_parameter_name, :targets, :target_maps, :max_concurrency, :max_errors, :target_locations) SENSITIVE = [] include Aws::Structure end |