Method: Aws::SSM::Types::SendCommandRequest#instance_ids
- Defined in:
- lib/aws-sdk-ssm/types.rb
#instance_ids ⇒ Array<String>
The instance IDs where the command should run. You can specify a maximum of 50 IDs. If you prefer not to list individual instance IDs, you can instead send commands to a fleet of instances using the Targets parameter, which accepts EC2 tags. For more information about how to use targets, see [Sending Commands to a Fleet] in the *AWS Systems Manager User Guide*.
[1]: docs.aws.amazon.com/systems-manager/latest/userguide/send-commands-multiple.html
14807 14808 14809 14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-ssm/types.rb', line 14807 class SendCommandRequest < Struct.new( :instance_ids, :targets, :document_name, :document_version, :document_hash, :document_hash_type, :timeout_seconds, :comment, :parameters, :output_s3_region, :output_s3_bucket_name, :output_s3_key_prefix, :max_concurrency, :max_errors, :service_role_arn, :notification_config, :cloud_watch_output_config) include Aws::Structure end |