Class: Aws::SSM::Types::StartExecutionPreviewRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#document_nameString

The name of the Automation runbook to run. The result of the execution preview indicates what the impact would be of running this runbook.

Returns:

  • (String)


19173
19174
19175
19176
19177
19178
19179
# File 'lib/aws-sdk-ssm/types.rb', line 19173

class StartExecutionPreviewRequest < Struct.new(
  :document_name,
  :document_version,
  :execution_inputs)
  SENSITIVE = []
  include Aws::Structure
end

#document_versionString

The version of the Automation runbook to run. The default value is $DEFAULT.

Returns:

  • (String)


19173
19174
19175
19176
19177
19178
19179
# File 'lib/aws-sdk-ssm/types.rb', line 19173

class StartExecutionPreviewRequest < Struct.new(
  :document_name,
  :document_version,
  :execution_inputs)
  SENSITIVE = []
  include Aws::Structure
end

#execution_inputsTypes::ExecutionInputs

Information about the inputs that can be specified for the preview operation.



19173
19174
19175
19176
19177
19178
19179
# File 'lib/aws-sdk-ssm/types.rb', line 19173

class StartExecutionPreviewRequest < Struct.new(
  :document_name,
  :document_version,
  :execution_inputs)
  SENSITIVE = []
  include Aws::Structure
end