Class: Aws::SSM::Types::StartExecutionPreviewRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::StartExecutionPreviewRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document_name ⇒ String
The name of the Automation runbook to run.
-
#document_version ⇒ String
The version of the Automation runbook to run.
-
#execution_inputs ⇒ Types::ExecutionInputs
Information about the inputs that can be specified for the preview operation.
Instance Attribute Details
#document_name ⇒ String
The name of the Automation runbook to run. The result of the execution preview indicates what the impact would be of running this runbook.
19173 19174 19175 19176 19177 19178 19179 |
# File 'lib/aws-sdk-ssm/types.rb', line 19173 class StartExecutionPreviewRequest < Struct.new( :document_name, :document_version, :execution_inputs) SENSITIVE = [] include Aws::Structure end |
#document_version ⇒ String
The version of the Automation runbook to run. The default value is
$DEFAULT.
19173 19174 19175 19176 19177 19178 19179 |
# File 'lib/aws-sdk-ssm/types.rb', line 19173 class StartExecutionPreviewRequest < Struct.new( :document_name, :document_version, :execution_inputs) SENSITIVE = [] include Aws::Structure end |
#execution_inputs ⇒ Types::ExecutionInputs
Information about the inputs that can be specified for the preview operation.
19173 19174 19175 19176 19177 19178 19179 |
# File 'lib/aws-sdk-ssm/types.rb', line 19173 class StartExecutionPreviewRequest < Struct.new( :document_name, :document_version, :execution_inputs) SENSITIVE = [] include Aws::Structure end |