Class: Aws::SSM::Types::StartSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#document_nameString

The name of the SSM document you want to use to define the type of session, input parameters, or preferences for the session. For example, SSM-SessionManagerRunShell. You can call the GetDocument API to verify the document exists before attempting to start a session. If no document name is provided, a shell to the managed node is launched by default. For more information, see [Start a session][1] in the *Amazon Web Services Systems Manager User Guide*.

[1]: docs.aws.amazon.com/systems-manager/latest/userguide/session-manager-working-with-sessions-start.html



17755
17756
17757
17758
17759
17760
17761
17762
# File 'lib/aws-sdk-ssm/types.rb', line 17755

class StartSessionRequest < Struct.new(
  :target,
  :document_name,
  :reason,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Array<String>>

The values you want to specify for the parameters defined in the Session document.



17755
17756
17757
17758
17759
17760
17761
17762
# File 'lib/aws-sdk-ssm/types.rb', line 17755

class StartSessionRequest < Struct.new(
  :target,
  :document_name,
  :reason,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason for connecting to the instance. This value is included in the details for the Amazon CloudWatch Events event created when you start the session.



17755
17756
17757
17758
17759
17760
17761
17762
# File 'lib/aws-sdk-ssm/types.rb', line 17755

class StartSessionRequest < Struct.new(
  :target,
  :document_name,
  :reason,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#targetString

The managed node to connect to for the session.



17755
17756
17757
17758
17759
17760
17761
17762
# File 'lib/aws-sdk-ssm/types.rb', line 17755

class StartSessionRequest < Struct.new(
  :target,
  :document_name,
  :reason,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end