Class: Aws::SSM::Types::TargetLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::TargetLocation
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
The combination of Amazon Web Services Regions and Amazon Web Services accounts targeted by the current Automation execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accounts ⇒ Array<String>
The Amazon Web Services accounts targeted by the current Automation execution.
-
#exclude_accounts ⇒ Array<String>
Amazon Web Services accounts or organizational units to exclude as expanded targets.
-
#execution_role_name ⇒ String
The Automation execution role used by the currently running Automation.
-
#include_child_organization_units ⇒ Boolean
Indicates whether to include child organizational units (OUs) that are children of the targeted OUs.
-
#regions ⇒ Array<String>
The Amazon Web Services Regions targeted by the current Automation execution.
-
#target_location_alarm_configuration ⇒ Types::AlarmConfiguration
The details for the CloudWatch alarm you want to apply to an automation or command.
-
#target_location_max_concurrency ⇒ String
The maximum number of Amazon Web Services Regions and Amazon Web Services accounts allowed to run the Automation concurrently.
-
#target_location_max_errors ⇒ String
The maximum number of errors allowed before the system stops queueing additional Automation executions for the currently running Automation.
-
#targets ⇒ Array<Types::Target>
A list of key-value mappings to target resources.
-
#targets_max_concurrency ⇒ String
The maximum number of targets allowed to run this task in parallel.
-
#targets_max_errors ⇒ String
The maximum number of errors that are allowed before the system stops running the automation on additional targets.
Instance Attribute Details
#accounts ⇒ Array<String>
The Amazon Web Services accounts targeted by the current Automation execution.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#exclude_accounts ⇒ Array<String>
Amazon Web Services accounts or organizational units to exclude as expanded targets.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#execution_role_name ⇒ String
The Automation execution role used by the currently running
Automation. If not specified, the default value is
AWS-SystemsManager-AutomationExecutionRole.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#include_child_organization_units ⇒ Boolean
Indicates whether to include child organizational units (OUs) that
are children of the targeted OUs. The default is false.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
The Amazon Web Services Regions targeted by the current Automation execution.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#target_location_alarm_configuration ⇒ Types::AlarmConfiguration
The details for the CloudWatch alarm you want to apply to an automation or command.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#target_location_max_concurrency ⇒ String
The maximum number of Amazon Web Services Regions and Amazon Web
Services accounts allowed to run the Automation concurrently.
TargetLocationMaxConcurrency has a default value of 1.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#target_location_max_errors ⇒ String
The maximum number of errors allowed before the system stops
queueing additional Automation executions for the currently running
Automation. TargetLocationMaxErrors has a default value of 0.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Array<Types::Target>
A list of key-value mappings to target resources. If you specify
values for this data type, you must also specify a value for
TargetParameterName.
This Targets parameter takes precedence over the
StartAutomationExecution:Targets parameter if both are supplied.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#targets_max_concurrency ⇒ String
The maximum number of targets allowed to run this task in parallel.
This TargetsMaxConcurrency takes precedence over the
StartAutomationExecution:MaxConcurrency parameter if both are
supplied.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |
#targets_max_errors ⇒ String
The maximum number of errors that are allowed before the system
stops running the automation on additional targets. This
TargetsMaxErrors parameter takes precedence over the
StartAutomationExecution:MaxErrors parameter if both are supplied.
19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 |
# File 'lib/aws-sdk-ssm/types.rb', line 19675 class TargetLocation < Struct.new( :accounts, :regions, :target_location_max_concurrency, :target_location_max_errors, :execution_role_name, :target_location_alarm_configuration, :include_child_organization_units, :exclude_accounts, :targets, :targets_max_concurrency, :targets_max_errors) SENSITIVE = [] include Aws::Structure end |