Class: Aws::SSM::Types::UnsupportedInventorySchemaVersionException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Inventory item type schema version has to match supported versions in the service. Check output of GetInventorySchema to see the available schema version for each type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


19504
19505
19506
19507
19508
# File 'lib/aws-sdk-ssm/types.rb', line 19504

class UnsupportedInventorySchemaVersionException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end