Class: Aws::SSM::Types::UpdateMaintenanceWindowRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_unassociated_targetsBoolean

Whether targets must be registered with the maintenance window before tasks can be defined for those targets.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#cutoffInteger

The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

An optional description for the update request.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#durationInteger

The duration of the maintenance window in hours.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#enabledBoolean

Whether the maintenance window is enabled.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#end_dateString

The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become inactive. EndDate allows you to set a date and time in the future when the maintenance window will no longer run.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the maintenance window.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#replaceBoolean

If True, then all fields that are required by the CreateMaintenanceWindow operation are also required for this API request. Optional fields that aren’t specified are set to null.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#scheduleString

The schedule of the maintenance window in the form of a cron or rate expression.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#schedule_offsetInteger

The number of days to wait after the date and time specified by a cron expression before running the maintenance window.

For example, the following cron expression schedules a maintenance window to run the third Tuesday of every month at 11:30 PM.

‘cron(30 23 ? * TUE#3 *)`

If the schedule offset is 2, the maintenance window won’t run until two days later.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#schedule_timezoneString

The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format. For example: “America/Los_Angeles”, “UTC”, or “Asia/Seoul”. For more information, see the [Time Zone Database][1] on the IANA website.

[1]: www.iana.org/time-zones



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#start_dateString

The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become active. StartDate allows you to delay activation of the maintenance window until the specified future date.

<note markdown=“1”> When using a rate schedule, if you provide a start date that occurs in the past, the current date and time are used as the start date.

</note>


18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end

#window_idString

The ID of the maintenance window to update.



18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
# File 'lib/aws-sdk-ssm/types.rb', line 18988

class UpdateMaintenanceWindowRequest < Struct.new(
  :window_id,
  :name,
  :description,
  :start_date,
  :end_date,
  :schedule,
  :schedule_timezone,
  :schedule_offset,
  :duration,
  :cutoff,
  :allow_unassociated_targets,
  :enabled,
  :replace)
  SENSITIVE = [:description]
  include Aws::Structure
end