Class: Aws::SSM::Types::UpdateMaintenanceWindowTargetRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:owner_information, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

An optional description for the update.



19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
# File 'lib/aws-sdk-ssm/types.rb', line 19125

class UpdateMaintenanceWindowTargetRequest < Struct.new(
  :window_id,
  :window_target_id,
  :targets,
  :owner_information,
  :name,
  :description,
  :replace)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#nameString

A name for the update.



19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
# File 'lib/aws-sdk-ssm/types.rb', line 19125

class UpdateMaintenanceWindowTargetRequest < Struct.new(
  :window_id,
  :window_target_id,
  :targets,
  :owner_information,
  :name,
  :description,
  :replace)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#owner_informationString

User-provided value that will be included in any Amazon CloudWatch Events events raised while running tasks for these targets in this maintenance window.



19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
# File 'lib/aws-sdk-ssm/types.rb', line 19125

class UpdateMaintenanceWindowTargetRequest < Struct.new(
  :window_id,
  :window_target_id,
  :targets,
  :owner_information,
  :name,
  :description,
  :replace)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#replaceBoolean

If True, then all fields that are required by the RegisterTargetWithMaintenanceWindow operation are also required for this API request. Optional fields that aren’t specified are set to null.



19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
# File 'lib/aws-sdk-ssm/types.rb', line 19125

class UpdateMaintenanceWindowTargetRequest < Struct.new(
  :window_id,
  :window_target_id,
  :targets,
  :owner_information,
  :name,
  :description,
  :replace)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#targetsArray<Types::Target>

The targets to add or replace.



19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
# File 'lib/aws-sdk-ssm/types.rb', line 19125

class UpdateMaintenanceWindowTargetRequest < Struct.new(
  :window_id,
  :window_target_id,
  :targets,
  :owner_information,
  :name,
  :description,
  :replace)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#window_idString

The maintenance window ID with which to modify the target.



19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
# File 'lib/aws-sdk-ssm/types.rb', line 19125

class UpdateMaintenanceWindowTargetRequest < Struct.new(
  :window_id,
  :window_target_id,
  :targets,
  :owner_information,
  :name,
  :description,
  :replace)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end

#window_target_idString

The target ID to modify.



19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
# File 'lib/aws-sdk-ssm/types.rb', line 19125

class UpdateMaintenanceWindowTargetRequest < Struct.new(
  :window_id,
  :window_target_id,
  :targets,
  :owner_information,
  :name,
  :description,
  :replace)
  SENSITIVE = [:owner_information, :description]
  include Aws::Structure
end