Class: Aws::SSM::Types::ValidationFinding

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssm/types.rb

Overview

A validation finding from a cloud connector validation check.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

A code that identifies the specific validation finding.

Returns:

  • (String)


21759
21760
21761
21762
21763
21764
21765
21766
21767
# File 'lib/aws-sdk-ssm/types.rb', line 21759

class ValidationFinding < Struct.new(
  :type,
  :code,
  :message,
  :provider_message,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message that describes the validation finding.

Returns:

  • (String)


21759
21760
21761
21762
21763
21764
21765
21766
21767
# File 'lib/aws-sdk-ssm/types.rb', line 21759

class ValidationFinding < Struct.new(
  :type,
  :code,
  :message,
  :provider_message,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#provider_messageString

A message from the third-party cloud provider related to the validation finding.

Returns:

  • (String)


21759
21760
21761
21762
21763
21764
21765
21766
21767
# File 'lib/aws-sdk-ssm/types.rb', line 21759

class ValidationFinding < Struct.new(
  :type,
  :code,
  :message,
  :provider_message,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#scopeTypes::ValidationFindingScope

The scope of the validation finding, identifying the specific resource affected.



21759
21760
21761
21762
21763
21764
21765
21766
21767
# File 'lib/aws-sdk-ssm/types.rb', line 21759

class ValidationFinding < Struct.new(
  :type,
  :code,
  :message,
  :provider_message,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the validation finding.

Returns:

  • (String)


21759
21760
21761
21762
21763
21764
21765
21766
21767
# File 'lib/aws-sdk-ssm/types.rb', line 21759

class ValidationFinding < Struct.new(
  :type,
  :code,
  :message,
  :provider_message,
  :scope)
  SENSITIVE = []
  include Aws::Structure
end