Class: Aws::SSM::Types::ValidationFinding
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSM::Types::ValidationFinding
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssm/types.rb
Overview
A validation finding from a cloud connector validation check.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
A code that identifies the specific validation finding.
-
#message ⇒ String
A message that describes the validation finding.
-
#provider_message ⇒ String
A message from the third-party cloud provider related to the validation finding.
-
#scope ⇒ Types::ValidationFindingScope
The scope of the validation finding, identifying the specific resource affected.
-
#type ⇒ String
The type of the validation finding.
Instance Attribute Details
#code ⇒ String
A code that identifies the specific validation finding.
21759 21760 21761 21762 21763 21764 21765 21766 21767 |
# File 'lib/aws-sdk-ssm/types.rb', line 21759 class ValidationFinding < Struct.new( :type, :code, :message, :provider_message, :scope) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message that describes the validation finding.
21759 21760 21761 21762 21763 21764 21765 21766 21767 |
# File 'lib/aws-sdk-ssm/types.rb', line 21759 class ValidationFinding < Struct.new( :type, :code, :message, :provider_message, :scope) SENSITIVE = [] include Aws::Structure end |
#provider_message ⇒ String
A message from the third-party cloud provider related to the validation finding.
21759 21760 21761 21762 21763 21764 21765 21766 21767 |
# File 'lib/aws-sdk-ssm/types.rb', line 21759 class ValidationFinding < Struct.new( :type, :code, :message, :provider_message, :scope) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ Types::ValidationFindingScope
The scope of the validation finding, identifying the specific resource affected.
21759 21760 21761 21762 21763 21764 21765 21766 21767 |
# File 'lib/aws-sdk-ssm/types.rb', line 21759 class ValidationFinding < Struct.new( :type, :code, :message, :provider_message, :scope) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the validation finding.
21759 21760 21761 21762 21763 21764 21765 21766 21767 |
# File 'lib/aws-sdk-ssm/types.rb', line 21759 class ValidationFinding < Struct.new( :type, :code, :message, :provider_message, :scope) SENSITIVE = [] include Aws::Structure end |