Class: Aws::SSM::Waiters::CommandExecuted
- Inherits:
-
Object
- Object
- Aws::SSM::Waiters::CommandExecuted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ssm/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CommandExecuted
constructor
A new instance of CommandExecuted.
-
#wait(params = {}) ⇒ Types::GetCommandInvocationResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CommandExecuted
Returns a new instance of CommandExecuted.
84 85 |
# File 'lib/aws-sdk-ssm/waiters.rb', line 84
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
157 158 159 |
# File 'lib/aws-sdk-ssm/waiters.rb', line 157 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetCommandInvocationResult
Returns a response object which responds to the following methods:
- #command_id => String
- #instance_id => String
- #comment => String
- #document_name => String
- #document_version => String
- #plugin_name => String
- #response_code => Integer
- #execution_start_date_time => String
- #execution_elapsed_time => String
- #execution_end_date_time => String
- #status => String
- #status_details => String
- #standard_output_content => String
- #standard_output_url => String
- #standard_error_content => String
- #standard_error_url => String
- #cloud_watch_output_config => Types::CloudWatchOutputConfig
152 |
# File 'lib/aws-sdk-ssm/waiters.rb', line 152
def wait: (
|